package Admin::Adminlogs;
use strict;
#################################################################################
# Ikonboard v3 by Jarvis Entertainment Group, Inc.
#
# No part of this script can be used outside Ikonboard without prior consent.
#
# More information available from <ib-license@jarvisgroup.net>
# (c)2001 Jarvis Entertainment Group, Inc.
# 
# http://www.ikonboard.com | http://www.jarvisgroup.net
#
# Please read the license for more information
#
# 
# Script Author: Matthew Mecham <matt@ikonboard.com>
#
#################################################################################

BEGIN {
    require 'Lib/FUNC.pm';
    require 'Lib/ADMIN.pm';
    require 'Admin/SKIN.pm';
    require 'Boardinfo.pm' or die "Cannot load Module: $!";
}

my $SKIN  = Admin::SKIN->new();
my $std   = FUNC::STD->new();
my $ADMIN = FUNC::ADMIN->new();
my $INFO  = Boardinfo->new();

sub new {
    my $pkg = shift;
    my $obj = {};
    bless $obj, $pkg;
    return $obj;
}

sub splash {
    my ($obj, $db) = @_;

    $ADMIN->Error( DB => $db, STD => $std, MSG => "You do not have permission for this action") unless $iB::MEMBER_GROUP->{'READ_AD_LOGS'};

    $obj->print_list( CODE   => 'view',
                      BUTTON => 'View Log Entry',
                      TYPE   => 'radio',
                      TEXT   => 'Please choose an administration log to view',
                      DB     => $db
                    );
}


sub delete {
    my ($obj, $db) = @_;
    $ADMIN->Error( DB => $db, STD => $std, MSG => "You do not have permission for this action") unless $iB::MEMBER_GROUP->{'READ_AD_LOGS'};
    $ADMIN->Error( DB => $db, STD => $std, MSG => "You do not have permission for this action") unless $iB::MEMBER_GROUP->{'DELETE_AD_LOGS'};
    $obj->print_list( CODE   => 'dodel',
                      BUTTON => 'Delete Selected Logs',
                      TYPE   => 'checkbox',
                      TEXT   => 'Choose which logs you wish to delete',
                      DB     => $db
                    );
}

sub print_list {
    my $obj = shift;

    my %IN = ( CODE    => "",
               BUTTON  => "",
               TYPE    => "",
               TEXT    => "",
               DB      => "",
               @_,
              );

    my $db = $IN{'DB'};

    opendir (DIR, $INFO->{'DB_DIR'}.'admin_logs');
    my @list = grep { !/\A\.{1,2}\Z/ } readdir(DIR);
    closedir(DIR);

    my $html = qq~

    <table cellspacing='0' cellpadding='5' border='0' width='100%' border='0'>
    <tr>
    <td>
    <font class='large'>&gt;&gt; Admin Logs</font><br>
    <font class='t'>&nbsp;&nbsp;$IN{'TEXT'}</font>
    
    <form action='$INFO->{'BOARD_URL'}/ikonboard.$iB::INFO->{'CGI_EXT'}?AD=1&s=$iB::SESSION&CODE=view' method='post'>
    <input type='hidden' name='AD' value='1'>
    <input type='hidden' name='act' value='logs'>
    <input type='hidden' name='s' value='$iB::SESSION'>
    <input type='hidden' name='CODE' value='$IN{'CODE'}'>

    <table cellspacing='1' cellpadding='0' width='100%' align='center' border='0' bgcolor='#333366'>
        <tr>
            <td>
            <table cellspacing='1' cellpadding='2' width='100%' align='center' border='0'>
            <tr>
            <td bgcolor='#666699' width='5%' align='center'>&nbsp;</td>
            <td bgcolor='#666699' width='95%'><font class='t'><b>Time of Entry</b></font></td>
            </tr>
    ~;


    for my $log (sort { $a <=> $b } @list) {

        if ($log =~ m#\Alog\-(.+?)\.txt\Z#i) {
            my $date = $std->get_date( TIME => $1, METHOD => 'LONG');
            my $id   = $1;

            $html .= qq~
            <tr>
            <td bgcolor='#FFFFFF' align='center'><input type='$IN{'TYPE'}' name='ID' value='$id' style='border:none'></td>
            <td bgcolor='#FFFFFF'><font class='t'>&gt;&gt;&nbsp;<b>$date</b></font></td>
            </tr>
            ~;
        } else {
            next;
        }
      
    }

   
    $html .= qq~
            
            <tr>
            <td colspan='2' align='center' bgcolor='#FFFFFF'><br><input type='submit' value='$IN{'BUTTON'}'></td>
            </tr>
            </table>
         </td>
        </tr>
      </table>
     </form>
    </td>
    </tr>
    </table>
    ~;


    $ADMIN->Output( WHERE => 'MAINTAIN', NAV_ONE => 'Administration Logging Control', PRINT => $html);

}

sub view {
    my ($obj, $db) = @_;

    $ADMIN->Error( DB => $db, STD => $std, MSG => "You do not have permission for this action") unless $iB::MEMBER_GROUP->{'READ_AD_LOGS'};


    $ADMIN->Error( DB => $db, STD => $std, MSG => "You must choose a valid Log ID to view") unless $iB::IN{'ID'};

    unless (-e $INFO->{'DB_DIR'}.'admin_logs/log-'.$iB::IN{'ID'}.'.txt') {
        $ADMIN->Error( DB => $db, STD => $std, MSG => "You must choose a valid Log ID to view");
    }

    local $/ = undef;
    open LOG, $INFO->{'DB_DIR'}.'admin_logs/log-'.$iB::IN{'ID'}.'.txt' or die "Cannot open file: $!";
    my $log = <LOG>;
    close LOG;

    unless (length ($log) > 0) {
        $ADMIN->Error( DB => $db, STD => $std, MSG => "The log file is empty! Weird or what?");
    }
    
    $log =~ s!\n!<br>!g;
    $log =~ s!\t!\t\t!g;

    my $html = qq~

    <table cellspacing='0' cellpadding='5' border='0' width='100%' border='0'>
    <tr>
    <td>
    <font class='large'>&gt;&gt; Admin Log Entry</font>
    
    <table cellspacing='1' cellpadding='0' width='100%' align='center' border='0' bgcolor='#333366'>
        <tr>
            <td>
            <table cellspacing='1' cellpadding='2' width='100%' align='center' border='0'>
            <tr>
            <td bgcolor='#FFFFFF' colspan='2' align='left'><font face='Monaco, Courier, Courier New' size='3' color='#000000'>$log
            <br><br>&gt;&gt;<a href='$INFO->{'BOARD_URL'}/ikonboard.$iB::INFO->{'CGI_EXT'}?AD=1&s=$iB::SESSION&act=logs&CODE=dodel&ID=$iB::IN{'ID'}' target='BODY'>Delete This Log Entry</a>
            </font></td>
            </tr>
        </table>
       </td>
      </tr>
     </table>
    ~;

    $ADMIN->Output( WHERE => 'MAINTAIN', NAV_ONE => qq[<a href='$INFO->{'BOARD_URL'}/ikonboard.$iB::INFO->{'CGI_EXT'}?AD=1&s=$iB::SESSION&act=logs' target='BODY'>Administration Logging Control</a>], NAV_TWO => "Viewing Log", PRINT => $html);

}



sub do_delete {
    my ($obj, $db) = @_;
    $ADMIN->Error( DB => $db, STD => $std, MSG => "You do not have permission for this action") unless $iB::MEMBER_GROUP->{'DELETE_AD_LOGS'};

    my $skip = 0;
    my $done = 0;

    my @to_delete = $iB::CGI->param('ID');

    $ADMIN->Error( DB => $db, STD => $std, MSG => "You must choose a valid Log ID to delete") unless scalar (@to_delete) > 0;

    for my $l (@to_delete) {
    
        unless (-e $INFO->{'DB_DIR'}.'admin_logs/log-'.$l.'.txt') {
            ++$skip;
            next;
        }
        ++$done;
        unlink ($INFO->{'DB_DIR'}.'admin_logs/log-'.$l.'.txt');
    }

    $ADMIN->static_screen( URL   => "act=logs",
                           TITLE => "Administration Logs Deleted",
                           TEXT  => "The changes were successful<br><br>$skip files skipped, $done files removed"
                         );

}





sub process {
    my ($obj, $db) = @_;

    my $CodeNo = $iB::IN{'CODE'};

    my %Mode = ( 'del'        => \&delete,
                 'view'       => \&view,
                 'dodel'      => \&do_delete,


               );
    $Mode{$CodeNo} ? $Mode{$CodeNo}->($obj,$db) : splash($obj,$db);
} 






sub DESTROY { }


1;
__END__
