package Admin::Backup;
use strict;
#################################################################################
# Ikonboard v3 by Jarvis Entertainment Group, Inc.
#
# No part of this script can be used outside Ikonboard without prior consent.
#
# More information available from <ib-license@jarvisgroup.net>
# (c)2001 Jarvis Entertainment Group, Inc.
# 
# http://www.ikonboard.com | http://www.jarvisgroup.net
#
# Please read the license for more information
#
# 
# Script Author: Matthew Mecham <matt@ikonboard.com>
#
#################################################################################

BEGIN {
    require 'Lib/FUNC.pm';
    require 'Lib/ADMIN.pm';
    require 'Admin/SKIN.pm';
    require 'Boardinfo.pm' or die "Cannot load Module: $!";
}

use File::Path;
use File::Copy;
use Cwd;
use Archive::Tar;

my $SKIN  = Admin::SKIN->new();
my $std   = FUNC::STD->new();
my $ADMIN = FUNC::ADMIN->new();
my $INFO  = Boardinfo->new();

sub new {
    my $pkg = shift;
    my $obj = {};
    bless $obj, $pkg;
    return $obj;
}


sub splash {
    my ($obj, $db) = @_;

    my $html  = $SKIN->title( TITLE => 'Back Up Settings', TEXT => 'Please double check all the data before submitting the changes.' );
       $html .= $SKIN->begin_table();
       $html .= $SKIN->form_start();
       $html .= $SKIN->hidden_fields( { act   => 'bak',
                                        CODE  => 'dobak'
                                      } );

    $html .= $SKIN->section_header( TITLE => "Back Up Settings", TEXT => "Please specify your preferences");

    $html .= $SKIN->td_select( TEXT     => "Create '.tar' file?",
                               NAME     => 'pack',
                               REQ      => 1,
                               VALUES   => 'gz',
                               DATA     => [ { NAME => 'Create .tar file (Uncompressed)'      , VALUE => 'tar' },
                                             { NAME => 'Leave unarchived files'               , VALUE => 'none' },
                                             { NAME => 'Create .tar file with .GZ compression', VALUE => 'gz' }
                                           ],
                             );


    $html .= $SKIN->td_submit(   NAME => '', VALUE => 'Back Up NOW!' );

    $html .= $SKIN->form_end();
    $html .= $SKIN->end_table();

    $ADMIN->Output( WHERE => 'MAINTAIN', NAV_ONE => "Back-up Options", PRINT => $html);

}


sub do_back {
    my ($obj, $db) = @_;

    $obj->{'time'}     = time;
    $obj->{'this_dir'} = $INFO->{'BACKUP_DIR'}.'/'.'ib-'.$obj->{'time'};

    open BACKLOG, ">".$obj.{'this_dir'}.'.txt';
    my $my_time = $std->get_date( TIME => time, METHOD => 'LONG');
    print BACKLOG "$my_time\t:Beginning Back-up\n---------------------------------------\n\n";

    unless ( mkdir (0777, $obj->{'this_dir'}) ) {
        $ADMIN->Error( DB=>$db, STD=>$std, MSG=>"I don't have permissions to create a new directory inside the back-ups directory. Please ensure that the Back-Ups directory has a sufficient CHMOD value to enable me to create a new directory");
    }
    chmod (0777, $obj->{'this_dir'});

    print BACKLOG "+".time - $obj->{'time'}."seconds\t:New Directory Created";

    $obj->backup( DB     => $db,
                  TABLE  => 'member_profiles',
                );

    $obj->backup( DB     => $db,
                  TABLE  => 'address_books',
                );

    $obj->backup( DB     => $db,
                  TABLE  => 'authorisation',
                );

    $obj->backup( DB     => $db,
                  TABLE  => 'board_statistics',
                );

    $obj->backup( DB     => $db,
                  TABLE  => 'categories',
                );

    $obj->backup( DB     => $db,
                  TABLE  => 'forum_authorised',
                );

    $obj->backup( DB     => $db,
                  TABLE  => 'forum_info',
                );

    $obj->backup( DB     => $db,
                  TABLE  => 'forum_moderators',
                );
}


sub backup {
    my $obj = shift;
    my %IN = ( DB => "", TABLE => "", DBID => "", @_, );
    close BACKLOG;

}










sub process {
    my ($obj, $db) = @_;

    my $CodeNo = $iB::IN{'CODE'};

    my %Mode = ( 'dobak'        => \&do_back,


               );
    $Mode{$CodeNo} ? $Mode{$CodeNo}->($obj,$db) : splash($obj,$db);
} 



sub do_tar {
    my ($obj, $file_path) = @_;
    my $cwd  = cwd;

    chdir $INFO->{'BACKUP_DIR'};

    my $tar      = Archive::Tar->new();
    my @filelist = $obj->Find_Files($file_path);

    $tar->add_files(@filelist)    or ($obj->{'ERROR'} = $Archive::Tar::error and chdir $cwd and return);
    $tar->write("$file_path.tar") or ($obj->{'ERROR'} = $Archive::Tar::error and chdir $cwd and return);
    chdir $cwd;
    return 1;
}

sub Find_Files {
    my ($obj, $file_path) = @_;

    my @filelist;

    opendir (DIR, $INFO->{'BACKUP_DIR'}.$file_path);
    my @list = readdir(DIR);
    closedir(DIR);

    foreach my $file (@list) {
        next if ($file =~ /^\.\.?$/);
        if (-d $INFO->{'BACKUP_DIR'}.$file_path.'/'.$file) {
            push(@filelist, $obj->Find_Files($file_path.'/'.$file) );
        } else {
            push(@filelist, $file_path.'/'.$file);
        }
    }
    return @filelist;
}



sub DESTROY { }


1;
__END__
