package Admin::Functions;
use strict;
#################################################################################
# Ikonboard v3 by Jarvis Entertainment Group, Inc.
#
# No part of this script can be used outside Ikonboard without prior consent.
#
# More information available from <ib-license@jarvisgroup.net>
# (c)2001 Jarvis Entertainment Group, Inc.
# 
# http://www.ikonboard.com | http://www.jarvisgroup.net
#
# Please read the license for more information
#
# Admin/Functions: Administration Functions.
# Script Author: Matthew Mecham <matt@ikonboard.com>
#
#################################################################################

BEGIN {
    require 'Lib/FUNC.pm';
    require 'Lib/ADMIN.pm';
    require 'Admin/SKIN.pm';
    require 'Boardinfo.pm' or die "Cannot load Module: $!";
}

my $SKIN  = Admin::SKIN->new();
my $std   = FUNC::STD->new();
my $mem   = FUNC::Member->new();
my $ADMIN = FUNC::ADMIN->new();
my $INFO  = Boardinfo->new();


sub new {
    my $pkg = shift;
    my $obj = {};
    bless $obj, $pkg;
    return $obj;
}


sub process {
    my ($obj, $db) = @_;

    $obj->dologin($db) if $iB::IN{'act'} eq 'dologin';

    unless ($iB::MEMBER->{'MEMBER_ID'}) {
           $ADMIN->Print( DB     => $db,
                       STD    => $std,
                       OUTPUT => $SKIN->log_in("You are not logged in")
                     );
    }


    unless ($iB::MEMBER_GROUP->{'ACCESS_CP'}) {
        open LOG, ">>".$INFO->{'DB_DIR'}."Temp/log-$iB::IN{'IP_ADDRESS'}.cgi" or die $!;
        print LOG time."\n";
        close LOG or die $!;
        
        $db->update( TABLE   => 'member_profiles',
                     ID      => $iB::MEMBER->{'MEMBER_ID'},
                     KEY     => $iB::MEMBER->{'MEMBER_ID'},
                     VALUES  => { ALLOW_POST => 0 }
                   );

        $ADMIN->Error( DB      => $db,
                       LEVEL   => 5,
                       MSG     => 'not_admin'
                     );
    }
    if (-e $INFO->{'DB_DIR'}."Temp/admin-$iB::IN{'IP_ADDRESS'}.cgi") {
        open ADMIN, "<".$INFO->{'DB_DIR'}."Temp/admin-$iB::IN{'IP_ADDRESS'}.cgi" or die $!;
        my $admin_time = <ADMIN>;
        close ADMIN or die $!;
        chomp $admin_time;
        unless ($admin_time > (time - 60*120)) {
            unlink $INFO->{'DB_DIR'}."Temp/admin-$iB::IN{'IP_ADDRESS'}.cgi";
            $ADMIN->Error( DB=> $db, LEVEL => 5, MSG => 'inactive_admin_session');
        }
    } else {
        $ADMIN->Print( DB     => $db,
                       STD    => $std,
                       OUTPUT => $SKIN->log_in("No admin session found")
                     );
    }

    my %Mode = ( dologin  => \&dologin,
                 top      => \&top,
                 menu     => \&menu,
                 body     => \&body,
                 cat      => \&cat,
                 ops      => \&Ops,
                 bak      => \&back,
                 group    => \&group,
                 forum    => \&forum,
                 member   => \&member,
                 mods     => \&mods,
                 logs     => \&logs,
                 temps    => \&temps,
                 emoticon => \&emoticon,
                 template => \&template,
                 sess     => \&session,
                 online   => \&online,
                 stats    => \&stats,
                 styles   => \&styles,
    
               );
    
    $Mode{ $iB::IN{'act'} } ? $Mode{ $iB::IN{'act'} }->($obj, $db) : Frames($obj, $db);   
}



######################################################################################


sub dologin {
    my ($obj, $db) = @_;

    open ADMIN, ">".$INFO->{'DB_DIR'}."Temp/admin-$iB::IN{'IP_ADDRESS'}.cgi" or die $!;
    print ADMIN time;
    close ADMIN or die $!;

    unlink $INFO->{'DB_DIR'}."Temp/log-$iB::IN{'IP_ADDRESS'}.cgi";

    $ADMIN->redirect( TEXT => "Log in Successful, $iB::MEMBER->{'MEMBER_NAME'} - taking you to your CP", URL => "");
  
}

sub top {
    my ($obj, $db) = @_;
    
    $ADMIN->Print( DB     => $db,
                   STD    => $std,
                   OUTPUT => $SKIN->top()
                 );
}


sub menu {
    my ($obj, $db) = @_;
    
    $ADMIN->Print( DB     => $db,
                   STD    => $std,
                   OUTPUT => $SKIN->menu()
                 );
}


sub body {
    my ($obj, $db) = @_;
    require 'Admin/Index.pm';
    my $idx = Admin::Index->new()->process($db);
}
sub logs {
    my ($obj, $db) = @_;
    require 'Admin/Adminlogs.pm';
    my $idx = Admin::Adminlogs->new()->process($db);
}
sub styles {
    my ($obj, $db) = @_;
    require 'Admin/SkinControl.pm';
    my $idx = Admin::SkinControl->new()->process($db);
}
sub stats {
    my ($obj, $db) = @_;
    require 'Admin/Stats.pm';
    my $idx = Admin::Stats->new()->process($db);
}
sub session {
    my ($obj, $db) = @_;
    require 'Admin/Session.pm';
    my $idx = Admin::Session->new()->process($db);
}
sub online {
    my ($obj, $db) = @_;
    require 'Admin/Online.pm';
    my $idx = Admin::Online->new()->process($db);
}
sub template {
    my ($obj, $db) = @_;
    require 'Admin/Templates.pm';
    my $idx = Admin::Templates->new()->process($db);
}
sub emoticon {
    my ($obj, $db) = @_;
    require 'Admin/EmoticonControl.pm';
    my $idx = Admin::EmoticonControl->new()->process($db);
}
sub temps {
    my ($obj, $db) = @_;
    require 'Admin/Tempfiles.pm';
    my $idx = Admin::Tempfiles->new()->process($db);
}
sub cat {
    my ($obj, $db) = @_;
    require 'Admin/Category.pm';
    my $idx = Admin::Category->new()->process($db);
}
sub mods {
    my ($obj, $db) = @_;
    require 'Admin/ModControl.pm';
    my $idx = Admin::ModControl->new()->process($db);
}
sub member {
    my ($obj, $db) = @_;
    require 'Admin/MemberControl.pm';
    my $idx = Admin::MemberControl->new()->process($db);
}
sub forum {
    my ($obj, $db) = @_;
    require 'Admin/ForumControl.pm';
    my $idx = Admin::ForumControl->new()->process($db);
}

sub back {
    my ($obj, $db) = @_;
    require 'Admin/Backup.pm';
    my $idx = Admin::Backup->new()->process($db);
}
sub group {
    my ($obj, $db) = @_;
    require 'Admin/MemberGroups.pm';
    my $idx = Admin::MemberGroups->new()->process($db);
}

sub Ops {
    my ($obj, $db) = @_;
    require 'Admin/Options.pm';
    my $idx = Admin::Options->new()->process($db);
}

sub Frames {
    my ($obj, $db) = @_;
    
    $ADMIN->Print( DB     => $db,
                   STD    => $std,
                   OUTPUT => $SKIN->do_frames()
                 );
}




#########

sub get_session {
    my $obj = shift;

    my $IN  = { DB     => "",
                ID     => "",
                @_,
              };

    my $session = $IN->{'DB'}->select( TABLE => 'active_sessions', KEY => $IN->{'ID'} );

    return unless $session->{'ID'};
    
    if ($session->{'MEMBER_ID'}) {

        my $real_ip = join ".", (split/\./,$iB::IN{'IP_ADDRESS'})[0 .. 2];
        my $this_ip = join ".", (split/\./,$session->{'THIS_IP'})[0 .. 2];

        if ($real_ip ne $this_ip) {
            return 0;
        }
       
        if ($iB::INFO->{'CHECK_USER_AGENT'}) {
            return 0 unless $ENV{'HTTP_USER_AGENT'} eq $session->{'USER_AGENT'};
        }
    }

    return $session;

}



sub create_session {
    my $obj = shift;

    my $IN  = { DB     => "",
                MEMBER => "",
                DELETE => "",
                @_,
              };

    my $db         = $IN->{'DB'};
    my $member     = $IN->{'MEMBER'};
    $iB::SESSION   = $obj->my_gen_id();

    my $logstate   = $member->{'MEMBER_ID'} ? 1 : 0;

    $obj->clean_sessions( DB => $db, DELETE => $IN->{'DELETE'});

    $db->insert( TABLE   => 'active_sessions',
                 VALUES  =>  { ID               =>  $iB::SESSION,
                               MEMBER_NAME      =>  $member->{'MEMBER_NAME'},
                               MEMBER_PASSWORD  =>  $member->{'MEMBER_PASSWORD'},
                               MEMBER_ID        =>  $member->{'MEMBER_ID'},
                               THIS_IP          =>  $iB::IN{'IP_ADDRESS'},
                               LAST_LOG_IN      =>  time,
                               USER_AGENT       =>  $ENV{'HTTP_USER_AGENT'},
                               SESSION_START    =>  time,
                               MEMBER_LOGSTATE  =>  $logstate,
                               LOCATION         =>  $iB::IN{'act'}."|&|".$ENV{'QUERY_STRING'},
                               LOG_IN_TYPE      =>  $iB::IN{'Privacy'}
                             }
                );

    $member->{'LAST_LOG_IN'} = time;
    $mem->UpdateMember( DB => $db, MEMBER=> $member) if $member->{'MEMBER_ID'};
    
}


sub clean_sessions {
    my $obj = shift;
    my $IN  = { DB => "", DELETE => "", @_, };

    my $db = $IN->{'DB'};

    $IN->{'DELETE'} = " or THIS_IP eq '$iB::IN{'IP_ADDRESS'}'" if $IN->{'DELETE'} == 1;

    my $delete_keys = $db->query( TABLE    => 'active_sessions',
                                  COLUMNS  => ['SESSION_START', 'ID', 'THIS_IP'],
                                  WHERE    => "SESSION_START < (time - $iB::INFO->{'SESSION_EXPIRATION'})$IN->{'DELETE'}",
                                  SORT_KEY => 'SESSION_START',
                                );

    my @delete_ids = map { $_->{'ID'} } @{ $delete_keys };

    $db->delete( TABLE  => 'active_sessions',
                 KEY    => \@delete_ids
               );
    return 1;
}

sub my_gen_id {
    my $obj = shift;
    srand($$|time);
    my $session = int(rand(60000000));
    return unpack("H*", pack("Nnn", time, $$, $session));

}
#########
1;
__END__
