package Admin::MemberControl;
use strict;
#################################################################################
# Ikonboard v3 by Jarvis Entertainment Group, Inc.
#
# No part of this script can be used outside Ikonboard without prior consent.
#
# More information available from <ib-license@jarvisgroup.net>
# (c)2001 Jarvis Entertainment Group, Inc.
# 
# http://www.ikonboard.com | http://www.jarvisgroup.net
#
# Please read the license for more information
#
# 
# Script Author: Matthew Mecham <matt@ikonboard.com>
#
#################################################################################

BEGIN {
    require 'Lib/FUNC.pm';
    require 'Lib/ADMIN.pm';
    require 'Admin/SKIN.pm';
    require 'Boardinfo.pm' or die "Cannot load Module: $!";
}


my $SKIN  = Admin::SKIN->new();
my $std   = FUNC::STD->new();
my $mem   = FUNC::Member->new();
my $ADMIN = FUNC::ADMIN->new();
my $INFO  = Boardinfo->new();

sub new {
    my $pkg = shift;
    my $obj = {};
    bless $obj, $pkg;
    return $obj;
}


sub splash {
    my ($obj, $db) = @_;

    my $html  = $SKIN->title( TITLE => 'Member Control' );
       $html .= $SKIN->begin_table();
       $html .= $SKIN->form_start();
       $html .= $SKIN->hidden_fields( { act   => 'member',
                                        CODE  => 'edit',
                                      } );

    $html .= $SKIN->section_header( TITLE => "Choose a member to edit");

    $html .= qq~
        <tr>
        <td colspan='2' bgcolor='#EEEEEEF'><font class='t'>Find user <input type='text' size='30' name='USER_KEY' class='forminput' style="width:200px"> by
        <select name='KEY_TYPE' class='forminput' style="width:100px"><option value='NAME'>name<option value='ID'>member ID</select>
        &nbsp;&nbsp;<input type='submit' class='forminput' style="width:50px" value='Go!'>
        ~;

    $html .= $SKIN->form_end();
    $html .= $SKIN->end_table();

    $ADMIN->Output( WHERE => 'MEMBERS', NAV_ONE => 'Member Control', PRINT => $html);


}



sub edit {
    my ($obj, $db) = @_;
    my $html;

    $ADMIN->Error( DB=>,"", STD=>"", MSG => "You must specify a name or user ID to look for!") unless defined $iB::IN{'USER_KEY'};

    my $method = $iB::IN{'KEY_TYPE'} eq 'NAME' ? 'by name' : 'by id';

    my $member = $mem->LoadMember( DB => $db, KEY => $iB::IN{'USER_KEY'}, METHOD => $method );

    my $mem_groups = $db->query( TABLE      => 'mem_groups',
                                 COLUMNS    => ['ID', 'TITLE'],
                                 SORT_KEY   => 'TITLE',
                                 SORT_BY    => 'A-Z',
                               );
    my @groups;

    for (@{$mem_groups}) {
        next if ( ($_->{'ID'} == $INFO->{'SUPAD_GROUP'}) and ($iB::MEMBER->{'MEMBER_GROUP'} != $INFO->{'SUPAD_GROUP'}) );
        push @groups, { NAME => $_->{'TITLE'}, VALUE => $_->{'ID'} };
    }

    my $size   = scalar (@groups) + 1;


    #XXX No member found? Lets query the DB to find a near match

    unless ($member->{'MEMBER_ID'}) {

        my $query_stm = $iB::IN{'KEY_TYPE'} eq 'NAME' ? "MEMBER_NAME =~ /\\A$iB::IN{'USER_KEY'}/i"
                                                      : "MEMBER_ID =~ /$iB::IN{'USER_KEY'}/";

        my $member_query = $db->query( TABLE    => 'member_profiles',
                                       COLUMNS  => ['MEMBER_NAME', 'MEMBER_ID', 'MEMBER_GROUP', 'MEMBER_EMAIL', 'MEMBER_POSTS'],
                                       WHERE    => $query_stm,
                                       SORT_KEY => 'MEMBER_NAME'
                                     );


        unless (scalar (@{$member_query}) > 0) {
            $ADMIN->Error( DB=>"", STD=>"", MSG => "No matches found for that member data");
        }



        my $html = qq~

        <table cellspacing='0' cellpadding='5' border='0' width='100%' border='0'>
        <tr>
        <td>
        <font class='large'>&gt;&gt; Possible Member Matches</font>
    
        <form action='$INFO->{'BOARD_URL'}/ikonboard.$iB::INFO->{'CGI_EXT'}?AD=1&act=cat&s=$iB::SESSION&CODE=00' method='post'>
        <input type='hidden' name='AD' value='1'>
        <input type='hidden' name='act' value='member'>
        <input type='hidden' name='s' value='$iB::SESSION'>
        <input type='hidden' name='CODE' value='edit'>
        <input type='hidden' name='KEY_TYPE' value='ID'>

        <table cellspacing='1' cellpadding='0' width='100%' align='center' border='0' bgcolor='#333366'>
        <tr>
            <td>
            <table cellspacing='1' cellpadding='2' width='100%' align='center' border='0'>
            <tr>
            <td bgcolor='#666699' width='10%' align='center'>&nbsp;</td>
            <td bgcolor='#666699' width='30%'><font class='t'><b>Member Name</b></font></td>
            <td bgcolor='#666699' width='15%' align='center'><font class='t'><b>Member Group</b></font></td>
            <td bgcolor='#666699' width='8%' align='center'><font class='t'><b>Member Email</b></font></td>
            <td bgcolor='#666699' width='8%' align='center'><font class='t'><b>Member Posts</b></font></td>

            </tr>
        ~;


        for my $this_mem (@{$member_query}) {

            my $this_mem_g = {} ;
            for (@{$mem_groups}) {
                next if ( ($_->{'ID'} == $INFO->{'SUPAD_GROUP'}) and ($iB::MEMBER->{'MEMBER_GROUP'} != $INFO->{'SUPAD_GROUP'}) );
                $this_mem_g = $_ if $_->{'ID'} == $this_mem->{'MEMBER_GROUP'};
            }

            $html .= qq~
                <tr>
                <td bgcolor='#FFFFFF' align='center'><input type='radio' name='USER_KEY' value='$this_mem->{'MEMBER_ID'}' style='border:none'></td>
                <td bgcolor='#FFFFFF'><font class='t'>$this_mem->{'MEMBER_NAME'}</font></td>
                <td bgcolor='#FFFFFF' align='center'><font class='t'>$this_mem_g->{'TITLE'}</font></td>
                <td bgcolor='#FFFFFF' align='center'><font class='t'>$this_mem->{'MEMBER_EMAIL'}</font></td>
                <td bgcolor='#FFFFFF' align='center'><font class='t'>$this_mem->{'MEMBER_POSTS'}</font></td>
                </tr>
                ~;
        }


        $html .= qq~
            
                <tr>
                <td colspan='6' align='center' bgcolor='#FFFFFF'><br><input type='submit' value='Edit Selected Member'></td>
                </tr>
                </table>
            </td>
            </tr>
        </table>
        </form>
        </td>
        </tr>
        </table>
        ~;

        $ADMIN->Output( WHERE => 'MEMBERS', NAV_ONE => 'Member Control', PRINT => $html);
    }


    if ( ($member->{'MEMBER_GROUP'} == $INFO->{'SUPAD_GROUP'}) and ($iB::MEMBER->{'MEMBER_GROUP'} != $INFO->{'SUPAD_GROUP'}) ) {
        $ADMIN->Error( DB=>"", STD=>"", MSG => "You do not have permission to edit that member");
    }

    #XXX If we get here, we must have found an exact match.

    $member->{'SIGNATURE'} = $SKIN->formalize($member->{'SIGNATURE'});
    $member->{'INTERESTS'} = $SKIN->formalize($member->{'INTERESTS'});

    my ($width, $height) = split "x", $member->{'AVATAR_DIMS'};

    $member->{'ALLOW_POST'} ||= 0;

    $html  = $SKIN->title( TITLE => "Member Settings for $member->{'MEMBER_NAME'}<br>IP Address: $member->{'MEMBER_IP'}", TEXT => 'Please double check all the data before submitting the changes.' );
    $html .= $SKIN->begin_table();
    $html .= $SKIN->form_start();
    $html .= $SKIN->hidden_fields( {    act   => 'member',
                                        CODE  => 'doedit',
                                        ID    => $member->{'MEMBER_ID'},
                                        NAME  => $member->{'MEMBER_NAME'},
                                      } );

    $html .= $SKIN->section_header( TITLE => "Main Settings");

    $html .= $SKIN->td_select( TEXT     => "Allow this member to post where allowed?",
                               NAME     => 'ALLOW_POST',
                               REQ      => 1,
                               VALUES   => $member->{'ALLOW_POST'},
                               DATA     => [ { NAME => 'Yes', VALUE => 1 },
                                             { NAME => 'No' , VALUE => 0 } ],
                             );


    $html .= $SKIN->td_select( TEXT     => 'Member Group:',
                               NAME     => 'MEMBER_GROUP',
                               SIZE     => $size,
                               VALUES   => $member->{'MEMBER_GROUP'},
                               DATA     => \@groups
                             );

    $html .= $SKIN->td_input ( TEXT     => 'Title',         NAME => 'MEMBER_TITLE',  VALUE=> "$member->{'MEMBER_TITLE'}");

    $html .= $SKIN->td_input ( TEXT     => 'Email Address', NAME => 'MEMBER_EMAIL',  VALUE=> "$member->{'MEMBER_EMAIL'}",  REQ => 1 );

    $html .= $SKIN->td_input ( TEXT     => 'Avatar',        NAME => 'MEMBER_AVATAR', VALUE=> "$member->{'MEMBER_AVATAR'}");

    $html .= $SKIN->td_input ( TEXT     => 'Avatar Width',  NAME => 'AVATAR_W',      VALUE=> $width);

    $html .= $SKIN->td_input ( TEXT     => 'Avatar Height', NAME => 'AVATAR_H',      VALUE=> $height);

    $html .= $SKIN->td_input ( TEXT     => 'Posts',         NAME => 'MEMBER_POSTS',  VALUE=> "$member->{'MEMBER_POSTS'}");

    $html .= $SKIN->td_input ( TEXT     => 'Photo',         NAME => 'PHOTO',         VALUE=> "$member->{'PHOTO'}");

    $html .= $SKIN->td_input ( TEXT     => 'AIM Name',      NAME => 'AOLNAME',       VALUE=> "$member->{'AOLNAME'}");

    $html .= $SKIN->td_input ( TEXT     => 'ICQ No.',       NAME => 'ICQNUMBER',     VALUE=> "$member->{'ICQNUMBER'}");

    $html .= $SKIN->td_input ( TEXT     => 'Yahoo Name',    NAME => 'YAHOONAME',     VALUE=> "$member->{'YAHOONAME'}");

    $html .= $SKIN->td_input ( TEXT     => 'MSN Name',      NAME => 'MSN_NAME',      VALUE=> "$member->{'MSN_NAME'}");

    $html .= $SKIN->td_input ( TEXT     => 'Location',      NAME => 'LOCATION',      VALUE=> "$member->{'LOCATION'}");

    $html .= $SKIN->td_input ( TEXT     => 'Website',       NAME => 'WEBSITE',       VALUE=> "$member->{'WEBSITE'}");

    $html .= $SKIN->td_textarea( TEXT => "Signature",       NAME => 'SIGNATURE',     VALUE => "$member->{'SIGNATURE'}");

    $html .= $SKIN->td_textarea( TEXT => "Interests",       NAME => 'INTERESTS',     VALUE => "$member->{'INTERESTS'}");

    $html .= $SKIN->td_select( TEXT     => "Email HIdden?",
                               NAME     => 'HIDE_EMAIL',
                               REQ      => 1,
                               VALUES   => $member->{'HIDE_EMAIL'},
                               DATA     => [ { NAME => 'Yes', VALUE => 1 },
                                             { NAME => 'No' , VALUE => 0 } ],
                             );


    $html .= $SKIN->td_submit(   NAME => '', VALUE => 'Apply Changes' );

    $html .= $SKIN->form_end();
    $html .= $SKIN->end_table();

    $ADMIN->Output( WHERE => 'MEMBERS', NAV_ONE => "Member Preferences", PRINT => $html);

}


sub do_edit {
    my ($obj, $db) = @_;

    $ADMIN->Error( DB=>,"", STD=>"", MSG => "You must specify a member to edit!") unless defined $iB::IN{'ID'};

    $iB::IN{'SIGNATURE'}     = $SKIN->htmlalize($iB::IN{'SIGNATURE'});
    $iB::IN{'INTERESTS'}     = $SKIN->htmlalize($iB::IN{'INTERESTS'});
    $iB::IN{'AVATAR_DIMS'}   = $iB::IN{'AVATAR_W'}.'x'.$iB::IN{'AVATAR_H'};

    $db->update( TABLE   => 'member_profiles',
                 KEY     => $iB::IN{'ID'},
                 ID      => $iB::IN{'ID'},
                 VALUES  => {   MEMBER_GROUP   => $iB::IN{'MEMBER_GROUP'},
                                MEMBER_EMAIL   => $iB::IN{'MEMBER_EMAIL'},
                                MEMBER_TITLE   => $iB::IN{'MEMBER_TITLE'},
                                MEMBER_AVATAR  => $iB::IN{'MEMBER_AVATAR'},
                                AVATAR_DIMS    => $iB::IN{'AVATAR_DIMS'},
                                MEMBER_POSTS   => $iB::IN{'MEMBER_POSTS'},
                                PHOTO          => $iB::IN{'PHOTO'},
                                AOLNAME        => $iB::IN{'AOLNAME'},
                                ICQNUMBER      => $iB::IN{'ICQNUMBER'},
                                YAHOONAME      => $iB::IN{'YAHOO_NAME'},
                                MSN_NAME       => $iB::IN{'MSN_NAME'},
                                LOCATION       => $iB::IN{'LOCATION'},
                                WEBSITE        => $iB::IN{'WEBSITE'},
                                SIGNATURE      => $iB::IN{'SIGNATURE'},
                                INTERESTS      => $iB::IN{'INTERESTS'},
                                ALLOW_POST     => $iB::IN{'ALLOW_POST'},
                           },
              );

    $ADMIN->write_log( TITLE => 'Member Changed', EXTRA => "MemberName: $iB::IN{'NAME'}");

    $ADMIN->static_screen( URL   => "act=member&CODE=edit&USER_KEY=$iB::IN{'ID'}",
                           TITLE => "Member edited",
                           TEXT  => "The changes were successful"
                         );

}

sub ban {
    my ($obj, $db) = @_;

    my @bans = split /\|\&\|/, $INFO->{'IP_FILTER'};
    my $banned = join "\n", @bans;

    my @email = split /\|\&\|/, $INFO->{'EMAIL_FILTER'};
    my $emails = join "\n", @email;

    my $html  = $SKIN->title( TITLE => 'Ban Filter Control');
       $html .= $SKIN->begin_table();
       $html .= $SKIN->form_start();
       $html .= $SKIN->hidden_fields( { act   => 'member',
                                        CODE  => 'doban'
                                      } );

    #+-----------------------------------

    $html .= $SKIN->section_header( TITLE => "Please edit your IP filters", TEXT => "You may use '*' as a wildcard. For example: 212.234.* will ban any user with an IP that starts with 212.234" );


    $html .= $SKIN->td_textarea( TEXT  => "Banned IP's<br>&nbsp;&nbsp;&nbsp;&nbsp;Add,edit or remove<br>&nbsp;&nbsp;&nbsp;&nbsp;One per line",
                                 NAME  => 'IP_FILTER',
                                 VALUE => $banned,
                                );

    $html .= $SKIN->section_header( TITLE => "Please edit your Email filters", TEXT => "You may use '*' as a wildcard. For example: '*\@yahoo.com' will ban any user with a 'yahoo' email address, and/or not let the register" );

    $html .= $SKIN->td_textarea( TEXT  => "Banned Email Addresses<br>&nbsp;&nbsp;&nbsp;&nbsp;Add,edit or remove<br>&nbsp;&nbsp;&nbsp;&nbsp;One per line",
                                 NAME  => 'EMAIL_FILTER',
                                 VALUE => $emails,
                                );

    $html .= $SKIN->td_submit(   NAME => '', VALUE => 'Apply Changes' );

    $html .= $SKIN->form_end();
    $html .= $SKIN->end_table();

    #+-----------------------------------

    $ADMIN->Output( WHERE => 'MEMBERS', NAV_ONE => 'Ban Control', PRINT => $html);

}

sub doban {
    my ($obj, $db) = @_;

    my $OLD = Boardinfo->new();

    $iB::IN{'EMAIL_FILTER'} =~ s!<br>!\|\&\|!g;
    $iB::IN{'IP_FILTER'}    =~ s!<br>!\|\&\|!g;


    $OLD->{'EMAIL_FILTER'}  = $iB::IN{'EMAIL_FILTER'};
    $OLD->{'IP_FILTER'}     = $iB::IN{'IP_FILTER'} ;

    $ADMIN->make_module( FILE     => "Boardinfo.pm",
                         PKG_NAME => 'Boardinfo',
                         VALUES   => $OLD
                       );

    $ADMIN->write_log( TITLE => 'Board Control Changed');

    $ADMIN->static_screen( URL   => "act=member",
                           TITLE => "Ban Filters Changed",
                           TEXT  => "The changes were successful<br>"
                         );
}


sub reg {
    my ($obj, $db) = @_;

    my $mem_groups = $db->query( TABLE      => 'mem_groups',
                                 COLUMNS    => ['ID', 'TITLE'],
                                 SORT_KEY   => 'TITLE',
                                 SORT_BY    => 'A-Z',
                               );
    my @groups;

    for (@{$mem_groups}) {
        next if ( ($_->{'ID'} == $INFO->{'SUPAD_GROUP'}) and ($iB::MEMBER->{'MEMBER_GROUP'} != $INFO->{'SUPAD_GROUP'}) );
        push @groups, { NAME => $_->{'TITLE'}, VALUE => $_->{'ID'} };
    }


    my $html  = $SKIN->title( TITLE => "Member pre-registration", TEXT => 'Please double check all the data before submitting.' );
    $html .= $SKIN->begin_table();
    $html .= $SKIN->form_start();
    $html .= $SKIN->hidden_fields( {    act   => 'member',
                                        CODE  => 'doreg',
                                      } );

    $html .= $SKIN->section_header( TITLE => "Member Settings");

    $html .= $SKIN->td_input ( TEXT => 'Member Name',          NAME => 'MEMBER_NAME',  VALUE=> '', REQ => 1);

    $html .= $SKIN->td_input ( TEXT => 'Member Password',       NAME => 'MEMBER_PASS',  VALUE=> '', REQ => 1);

    $html .= $SKIN->td_input ( TEXT => 'Member Email Address',  NAME => 'EMAIL',  VALUE=> '', REQ => 1);

    $html .= $SKIN->td_input ( TEXT => 'Member Post count',     NAME => 'POSTS',  VALUE=> '0', REQ => 1);

    $html .= $SKIN->td_select( TEXT     => 'Member Group:',
                               NAME     => 'MEMBER_GROUP',
                               VALUES   => "$INFO->{'MEMBER_GROUP'}",
                               DATA     => \@groups
                             );

    $html .= $SKIN->td_select( TEXT     => "Allow this member to post where allowed?",
                               NAME     => 'ALLOW_POST',
                               REQ      => 1,
                               VALUES   => '',
                               DATA     => [ { NAME => 'Yes', VALUE => 1 },
                                             { NAME => 'No' , VALUE => 0 } ],
                             );

    $html .= $SKIN->td_submit(   NAME => '', VALUE => 'Pre Register this Member' );

    $html .= $SKIN->form_end();
    $html .= $SKIN->end_table();

    #+-----------------------------------

    $ADMIN->Output( WHERE => 'MEMBERS', NAV_ONE => 'Member Control', PRINT => $html);

}


sub doreg {
    my ($obj, $db) = @_;

    $ADMIN->Error( DB=>,"", STD=>"", MSG => "You must enter a membername") unless defined $iB::IN{'MEMBER_NAME'};
    $ADMIN->Error( DB=>,"", STD=>"", MSG => "You must enter a password")   unless defined $iB::IN{'MEMBER_PASS'};
    $ADMIN->Error( DB=>,"", STD=>"", MSG => "You must enter an email address") unless defined $iB::IN{'EMAIL'};

    unless ($std->CheckEmail($iB::IN{'EMAIL'})) {
        $ADMIN->Error( DB=>,"", STD=>"", MSG => "Invalid email address");
    }

    my $name = $mem->CheckName( DB => $db, NAME => $iB::IN{'MEMBER_NAME'} );
    
    if ($name->{'MEMBER_NAME'}) {
        $ADMIN->Error( DB=>,"", STD=>"", MSG => "$iB::IN{'MEMBER_NAME'} already exists!");
    }

    my $new_id = $mem->AddMember( DB     => $db,
                                  STD    => $std,
                                  MEMBER => {
                                               MEMBER_NAME      => $iB::IN{'MEMBER_NAME'},
                                               MEMBER_PASSWORD  => $iB::IN{'MEMBER_PASS'},
                                               MEMBER_EMAIL     => $iB::IN{'EMAIL'},
                                               MEMBER_GROUP     => $iB::IN{'MEMBER_GROUP'},
                                               ALLOW_POST       => $iB::IN{'ALLOW_POST'},
                                               MEMBER_POSTS     => $iB::IN{'POSTS'},
                                               MEMBER_LEVEL     => 1,
                                               MEMBER_AVATAR    => 'noavatar',
                                               MEMBER_IP        => $ENV{'REMOTE_ADDR'},
                                               TIME_ADJUST      => 0,
                                               LANGUAGE         => 'en',
                                               MEMBER_SKIN      => 'Default',
                                               MEMBER_JOINED    => time,
                                               VIEW_SIGS        => 1,
                                               VIEW_IMG         => 1,
                                               VIEW_AVS         => 1,
                                            }
                                 );

    my $num = $db->count( TABLE => 'member_profiles' );

    $num++;

    $db->update( TABLE  => 'board_statistics',
                 KEY    => 'MAIN',
                 VALUES => {  TOTAL_MEMBERS      => $num,
                              LAST_REG_MEMBER_N  => $iB::IN{'MEMBER_NAME'},
                              LAST_REG_MEMBER_ID => $new_id
                           }
               );

    my $pass = $iB::IN{'MEMBER_PASS'};

    $iB::IN{'MEMBER_PASS'} = 'xxxxxxxxxxx';

    $ADMIN->write_log( TITLE => 'Member Pre-registered', EXTRA => "New Name: $iB::IN{'MEMBER_NAME'}");

    $ADMIN->static_screen( URL   => "act=member",
                           TITLE => "$iB::IN{'MEMBER_NAME'} has been registered",
                           TEXT  => "Member Name: $iB::IN{'MEMBER_NAME'}<br>Member Email: $iB::IN{'EMAIL'}<br>Member Password: $pass"
                         );
}



sub process {
    my ($obj, $db) = @_;

    my $CodeNo = $iB::IN{'CODE'};

    my %Mode = ( 'edit'        => \&edit,
                 'doedit'      => \&do_edit,
                 'ban'         => \&ban,
                 'doban'       => \&doban,
                 'reg'         => \&reg,
                 'doreg'       => \&doreg,


               );
    $Mode{$CodeNo} ? $Mode{$CodeNo}->($obj,$db) : splash($obj,$db);
} 




1;
__END__
