package Admin::SkinControl;
use strict;
#################################################################################
# Ikonboard v3 by Jarvis Entertainment Group, Inc.
#
# No part of this script can be used outside Ikonboard without prior consent.
#
# More information available from <ib-license@jarvisgroup.net>
# (c)2001 Jarvis Entertainment Group, Inc.
# 
# http://www.ikonboard.com | http://www.jarvisgroup.net
#
# Please read the license for more information
#
# 
# Script Author: Matthew Mecham <matt@ikonboard.com>
#
#################################################################################

BEGIN {
    require 'Lib/FUNC.pm';
    require 'Lib/ADMIN.pm';
    require 'Admin/SKIN.pm';
    require 'Boardinfo.pm' or die "Cannot load Module: $!";
}

my $SKIN  = Admin::SKIN->new();
my $std   = FUNC::STD->new();
my $ADMIN = FUNC::ADMIN->new();
my $INFO  = Boardinfo->new();

sub new {
    my $pkg = shift;
    my $obj = {};
    bless $obj, $pkg;
    return $obj;
}

#########################################################################################################
#
# Splash
#
#########################################################################################################


sub splash {
    my ($obj, $db) = @_;

    my @editable; 
    my @skins = split( /\|\&\|/, $INFO->{'SKINS'} );
    for my $s (@skins) {
        @_ = split /\:/, $s;
        push @editable, { NAME => $_[1], VALUE => $_[0] };
    }

    my $size = scalar @editable + 1;

    my $html  = $SKIN->title( TITLE => 'Styles/Skin Control', TEXT => "Partial Skin Support for BETA" );
       $html .= $SKIN->begin_table();
       $html .= $SKIN->form_start();
       $html .= $SKIN->hidden_fields( { act   => 'styles',
                                        CODE  => 'edit'
                                      } );

    #+-----------------------------------

    $html .= $SKIN->section_header( TITLE => "Please Choose 'Skin' to edit" );

    $html .= $SKIN->td_select( TEXT     => 'Installed Skins',
                               NAME     => 'SKIN',
                               SIZE     => $size,
                               VALUES   => 'Default',
                               DATA     => \@editable,
                             );

    $html .= $SKIN->section_header( TITLE => "Skin Sections", TEXT => "Please note, the actual skin HTML will have to be edited by hand in this BETA" );

    $html .= $SKIN->td_select( TEXT     => 'Skin Section',
                               NAME     => 'SECTION',
                               SIZE     => 3,
                               VALUES   => '',
                               DATA     => [ { NAME => 'CSS (Style Sheets)', VALUE => 'CSS'   },
                                             { NAME => 'Javascript',         VALUE => 'JS'    },
                                             { NAME => 'Global Colours',     VALUE => 'COLOR' },
                                           ]
                             );




    $html .= $SKIN->td_submit(   NAME => '', VALUE => 'Edit this Skin' );


    $html .= $SKIN->form_end();
    $html .= $SKIN->end_table();

    #+-----------------------------------

    $ADMIN->Output( WHERE => 'STYLES', NAV_ONE => 'Styles/Skin Control', PRINT => $html);

}

#########################################################################################################
#
# Edit / Do Edit Jumpers
#
#########################################################################################################

sub edit {
    my ($obj, $db) = @_;

    $ADMIN->Error( DB=>,"", STD=>"", MSG => "You must specify which skin to edit")    unless defined $iB::IN{'SKIN'};
    $ADMIN->Error( DB=>,"", STD=>"", MSG => "You must specify which section to edit") unless defined $iB::IN{'SECTION'};

    my %ist_gut = ( 'CSS'   => \&CSS,
                    'JS'    => \&JS,
                    'COLOR' => \&COLOR
                  );

    $ist_gut{ $iB::IN{'SECTION'} }->($obj, $db); #ja?
}

sub doedit {
    my ($obj, $db) = @_;

    $ADMIN->Error( DB=>,"", STD=>"", MSG => "You must specify which skin to edit")    unless defined $iB::IN{'SKIN'};
    $ADMIN->Error( DB=>,"", STD=>"", MSG => "You must specify which section to edit") unless defined $iB::IN{'SECTION'};

    my %ist_gut = ( 'CSS'   => \&do_CSS,
                    'JS'    => \&do_JS,
                    'COLOR' => \&do_COLOR
                  );

    $ist_gut{ $iB::IN{'SECTION'} }->($obj, $db); #ja?
}

#########################################################################################################
#
# CSS Routines
#
#########################################################################################################


sub CSS {
    my ($obj, $db) = @_;

    my $file = $iB::INFO->{'HTML_DIR'}.'Skin/'.$iB::IN{'SKIN'}.'/ikonboard.css';

    unless (-e $file) {
        $ADMIN->Error( DB=>,"", STD=>"", MSG => "Cannot locate the CSS file at ".$file);
    }
   
    if ($^O ne 'MacOS' && ($^O ne 'MSWin32' || !Win32::IsWin95())) {
        unless (-w $file) {
            chmod (0777, $file) || $ADMIN->Error( DB=>"",STD=>"",MSG=>"I do not have write permissions to change the CHMOD value on :$file. Please use FTP to change the CHMOD value on the file $file");
            chmod (0777, $iB::INFO->{'HTML_DIR'}.'Skin/'.$iB::IN{'SKIN'}) || $ADMIN->Error( DB=>"",STD=>"",MSG=>"I do not have write permissions to change the CHMOD value on the path :$file. Please use FTP to change the CHMOD value on skins directory");
        }
    } else {
        unless (-w $file) {
            $ADMIN->Error( DB=>"",STD=>"",MSG=>"I do not have write permissions to $file");
        }
    }

    local $/ = undef;
    open CSS, "<".$file or die $!;
    my $css = <CSS>;
    close CSS;
    my $html  = $SKIN->title( TITLE => 'Editing CSS', TEXT => "Partial Skin Support for BETA" );
       $html .= $SKIN->begin_table();
       $html .= $SKIN->form_start();
       $html .= $SKIN->hidden_fields( { act     => 'styles',
                                        CODE    => 'doedit',
                                        SECTION => 'CSS',
                                        SKIN    => $iB::IN{'SKIN'}
                                      } );

    #+-----------------------------------

    $html .= $SKIN->section_header( TITLE => "Edit the CSS file" );

    $html .= $SKIN->td_textarea( TEXT  => "CSS Information",
                                 NAME  => 'CSS_INFO',
                                 VALUE => $css,
                                 SPAN  => 1,
                                 ROWS  => 30
                                );
    $html .= $SKIN->td_submit(   NAME => '', VALUE => 'Apply this Edit' );


    $html .= $SKIN->form_end();
    $html .= $SKIN->end_table();

    #+-----------------------------------

    $ADMIN->Output( WHERE => 'STYLES', NAV_ONE => 'Styles/Skin Control', PRINT => $html);

}


#+----------------------------------------------------------------------------------------

sub do_CSS {
    my ($obj, $db) = @_;

    $ADMIN->Error( DB=>,"", STD=>"", MSG => "No CSS Information to save")  unless $iB::CGI->param('CSS_INFO');

    my $file = $iB::INFO->{'HTML_DIR'}.'Skin/'.$iB::IN{'SKIN'}.'/ikonboard.css';

    open FILE, ">".$file or die $!;
    print FILE $iB::CGI->param('CSS_INFO');
    close FILE;

    $ADMIN->write_log( TITLE => 'CSS Edited');

    $ADMIN->static_screen( URL   => "act=styles&CODE=edit&SECTION=$iB::IN{'SECTION'}&SKIN=$iB::IN{'SKIN'}",
                           TITLE => "CSS Information edited",
                           TEXT  => "The changes were successful"
                         );
}

#########################################################################################################
#
# Javascript routines
#
#########################################################################################################



sub JS {
    my ($obj, $db) = @_;

    my $file = $iB::INFO->{'HTML_DIR'}.'Skin/'.$iB::IN{'SKIN'}.'/ikonboard.js';

    unless (-e $file) {
        $ADMIN->Error( DB=>,"", STD=>"", MSG => "Cannot locate the CSS file at ".$file);
    }
   
    if ($^O ne 'MacOS' && ($^O ne 'MSWin32' || !Win32::IsWin95())) {
        unless (-w $file) {
            chmod (0777, $file) || $ADMIN->Error( DB=>"",STD=>"",MSG=>"I do not have write permissions to change the CHMOD value on :$file. Please use FTP to change the CHMOD value on the file $file");
            chmod (0777, $iB::INFO->{'HTML_DIR'}.'Skin/'.$iB::IN{'SKIN'}) || $ADMIN->Error( DB=>"",STD=>"",MSG=>"I do not have write permissions to change the CHMOD value on the path :$file. Please use FTP to change the CHMOD value on skins directory");
        }
    } else {
        unless (-w $file) {
            $ADMIN->Error( DB=>"",STD=>"",MSG=>"I do not have write permissions to $file");
        }
    }

    local $/ = undef;
    open JAVA, "<".$file or die $!;
    my $js = <JAVA>;
    close JAVA;
    my $html  = $SKIN->title( TITLE => 'Editing iB Javascript', TEXT => "Partial Skin Support for BETA" );
       $html .= $SKIN->begin_table();
       $html .= $SKIN->form_start();
       $html .= $SKIN->hidden_fields( { act     => 'styles',
                                        CODE    => 'doedit',
                                        SECTION => 'JS',
                                        SKIN    => $iB::IN{'SKIN'}
                                      } );

    #+-----------------------------------

    $html .= $SKIN->section_header( TITLE => "Edit the JS file" );

    $html .= $SKIN->td_textarea( TEXT  => "JS Information",
                                 NAME  => 'JS_INFO',
                                 VALUE => $js,
                                 SPAN  => 1,
                                 ROWS  => 30
                                );
    $html .= $SKIN->td_submit(   NAME => '', VALUE => 'Apply this Edit' );


    $html .= $SKIN->form_end();
    $html .= $SKIN->end_table();

    #+-----------------------------------

    $ADMIN->Output( WHERE => 'STYLES', NAV_ONE => 'Styles/Skin Control', PRINT => $html);

}

#+----------------------------------------------------------------------------------------

sub do_JS {
    my ($obj, $db) = @_;

    $ADMIN->Error( DB=>,"", STD=>"", MSG => "No CSS Information to save")  unless $iB::CGI->param('CSS_INFO');

    my $file = $iB::INFO->{'HTML_DIR'}.'Skin/'.$iB::IN{'SKIN'}.'/ikonboard.js';

    open  JFILE, ">".$file or die $!;
    print JFILE $iB::CGI->param('JS_INFO');
    close JFILE;

    $ADMIN->write_log( TITLE => 'Javascript Edited');

    $ADMIN->static_screen( URL   => "act=styles&CODE=edit&SECTION=$iB::IN{'SECTION'}&SKIN=$iB::IN{'SKIN'}",
                           TITLE => "Javascript Information edited",
                           TEXT  => "The changes were successful"
                         );
}

#########################################################################################################
#
# Global Colours routines
#
#########################################################################################################

sub COLOR {
    my ($obj, $db) = @_;

    require $iB::INFO->{'IKON_DIR'}.'Skin/'.$iB::IN{'SKIN'}.'/Styles.pm';

    my $r_skin = Styles->new();

    $r_skin->{'EDIT_FONT_SIZE'} ||= 7;

    my $html  = $SKIN->title( TITLE => 'Editing Global Colours', TEXT => "Partial Skin Support for BETA" );
       $html .= $SKIN->begin_table();
       $html .= $SKIN->form_start();
       $html .= $SKIN->hidden_fields( { act     => 'styles',
                                        CODE    => 'doedit',
                                        SECTION => 'COLOR',
                                        SKIN    => $iB::IN{'SKIN'}
                                      } );

    $html .= $SKIN->section_header( TITLE => "Table Information" );

    $html .= $SKIN->td_input ( TEXT  => 'Table Width',
                               NAME  => 'TABLE_WIDTH',
                               VALUE => $r_skin->{'TABLE_WIDTH'},
                               REQ   => 1
                             );

    $html .= $SKIN->td_input ( TEXT  => 'Table Border Colour',
                               NAME  => 'TABLE_BORDER_COL',
                               VALUE => $r_skin->{'TABLE_BORDER_COL'},
                               REQ   => 1
                             );

    $html .= $SKIN->section_header( TITLE => "Logo Information", TEXT=>"Please make sure the logo is in the Images directory in the skin directory you are editing. There is no need to add the full URL");

    $html .= $SKIN->td_input ( TEXT  => 'Board Logo',
                               NAME  => 'BOARD_LOGO',
                               VALUE => $r_skin->{'BOARD_LOGO'},
                               REQ   => 1
                             );

    $html .= $SKIN->td_input ( TEXT  => 'Logo Alignment',
                               NAME  => 'LOGO_ALIGN',
                               VALUE => $r_skin->{'LOGO_ALIGN'},
                               REQ   => 1
                             );

    $html .= $SKIN->section_header( TITLE => "Miscellaneous Colours", TEXT => "For posting screens, logging in screens, registration screens, etc");

    $html .= $SKIN->td_input ( TEXT  => 'Board HTML Background Colour',
                               NAME  => 'HTML_BACK_COL',
                               VALUE => $r_skin->{'HTML_BACK_COL'},
                               REQ   => 1
                             );

    $html .= $SKIN->td_input ( TEXT  => 'Misc. Table Cell Colour #1 (Light)',
                               NAME  => 'MISCBACK_ONE',
                               VALUE => $r_skin->{'MISCBACK_ONE'},
                               REQ   => 1
                             );

    $html .= $SKIN->td_input ( TEXT  => 'Misc. Table Cell Colour #2 (Dark)',
                               NAME  => 'MISCBACK_TWO',
                               VALUE => $r_skin->{'MISCBACK_TWO'},
                               REQ   => 1
                             );

    $html .= $SKIN->td_input ( TEXT  => 'Misc. Header Table Cell Colour',
                               NAME  => 'MISCBACK_TITLE',
                               VALUE => $r_skin->{'MISCBACK_TITLE'},
                               REQ   => 1
                             );

    $html .= $SKIN->section_header( TITLE => "Table Title Colours", TEXT => "For posting screens, logging in screens, registration screens, etc");

    $html .= $SKIN->td_input ( TEXT  => 'Title Background Colour',
                               NAME  => 'TITLEBACK',
                               VALUE => $r_skin->{'TITLEBACK'},
                               REQ   => 1
                             );

    $html .= $SKIN->td_input ( TEXT  => 'Title Table Border Colour',
                               NAME  => 'TITLEBORDER',
                               VALUE => $r_skin->{'TITLEBORDER'},
                               REQ   => 1
                             );

    $html .= $SKIN->section_header( TITLE => "Forum Column Colours");

    $html .= $SKIN->td_input ( TEXT  => 'Forum Table Cell Colour #1',
                               NAME  => 'FORUM_COL_ONE',
                               VALUE => $r_skin->{'FORUM_COL_ONE'},
                               REQ   => 1
                             );

    $html .= $SKIN->td_input ( TEXT  => 'Forum Table Cell Colour #2',
                               NAME  => 'FORUM_COL_TWO',
                               VALUE => $r_skin->{'FORUM_COL_TWO'},
                               REQ   => 1
                             );

    $html .= $SKIN->td_input ( TEXT  => 'Pinned Topic Table Cell Colour #1',
                               NAME  => 'PIN_COL_ONE',
                               VALUE => $r_skin->{'PIN_COL_ONE'},
                               REQ   => 1
                             );

    $html .= $SKIN->td_input ( TEXT  => 'Pinned Topic Table Cell Colour #2',
                               NAME  => 'PIN_COL_TWO',
                               VALUE => $r_skin->{'PIN_COL_TWO'},
                               REQ   => 1
                             );

    $html .= $SKIN->section_header( TITLE => "Category Colours");

    $html .= $SKIN->td_input ( TEXT  => 'Category Title Background Colour',
                               NAME  => 'CAT_BACK',
                               VALUE => $r_skin->{'CAT_BACK'},
                               REQ   => 1
                             );

    $html .= $SKIN->td_input ( TEXT  => 'Nested Category (Expanded) Col. #1',
                               NAME  => 'EXP_CAT_ONE',
                               VALUE => $r_skin->{'EXP_CAT_ONE'},
                               REQ   => 1
                             );

    $html .= $SKIN->td_input ( TEXT  => 'Nested Category (Expanded) Col. #2',
                               NAME  => 'EXP_CAT_TWO',
                               VALUE => $r_skin->{'EXP_CAT_TWO'},
                               REQ   => 1
                             );

    $html .= $SKIN->section_header( TITLE => "Thread View Row Colours");

    $html .= $SKIN->td_input ( TEXT  => 'Thread Entry Colour #1',
                               NAME  => 'POST_COL_ONE',
                               VALUE => $r_skin->{'POST_COL_ONE'},
                               REQ   => 1
                             );

    $html .= $SKIN->td_input ( TEXT  => 'Thread Entry Colour #2',
                               NAME  => 'POST_COL_TWO',
                               VALUE => $r_skin->{'POST_COL_TWO'},
                               REQ   => 1
                             );

    $html .= $SKIN->td_input ( TEXT  => 'Edited by font size (in pt)',
                               NAME  => 'EDIT_FONT_SIZE',
                               VALUE => $r_skin->{'EDIT_FONT_SIZE'},
                               REQ   => 1
                             );

    $html .= $SKIN->section_header( TITLE => "User CP, User Bar Colours");

    $html .= $SKIN->td_input ( TEXT  => 'User Strip Background Colour',
                               NAME  => 'USER_BAR_BACK',
                               VALUE => $r_skin->{'USER_BAR_BACK'},
                               REQ   => 1
                             );

    $html .= $SKIN->td_input ( TEXT  => 'User CP Navigation Tabs: Active',
                               NAME  => 'USERNAV_ON',
                               VALUE => $r_skin->{'USERNAV_ON'},
                               REQ   => 1
                             );

    $html .= $SKIN->td_input ( TEXT  => 'User CP Navigation Tabs: Inactive',
                               NAME  => 'USERNAV_OFF',
                               VALUE => $r_skin->{'USERNAV_OFF'},
                               REQ   => 1
                             );

    $html .= $SKIN->section_header( TITLE => "Navigation Strip Colours");

    $html .= $SKIN->td_input ( TEXT  => 'Navigation Border Colour',
                               NAME  => 'NAV_BORDER',
                               VALUE => $r_skin->{'NAV_BORDER'},
                               REQ   => 1
                             );

    $html .= $SKIN->td_input ( TEXT  => 'Navigation Border Colour',
                               NAME  => 'NAV_BACK',
                               VALUE => $r_skin->{'NAV_BACK'},
                               REQ   => 1
                             );

    $html .= $SKIN->td_submit(   NAME => '', VALUE => 'Apply this Edit' );


    $html .= $SKIN->form_end();
    $html .= $SKIN->end_table();

    #+-----------------------------------

    $ADMIN->Output( WHERE => 'STYLES', NAV_ONE => 'Styles/Skin Control', PRINT => $html);

}

sub do_COLOR {
    my ($obj, $db) = @_;

    my $data = {    HTML_BACK_COL   => $iB::IN{'HTML_BACK_COL'},
                    TITLEBACK       => $iB::IN{'TITLEBACK'},
                    TITLEBORDER     => $iB::IN{'TITLEBORDER'},
                    USER_BAR_BACK   => $iB::IN{'USER_BAR_BACK'},
                    NAV_BORDER      => $iB::IN{'NAV_BORDER'},
                    NAV_BACK        => $iB::IN{'NAV_BACK'},
                    USERNAV_OFF     => $iB::IN{'USERNAV_OFF'},
                    USERNAV_ON      => $iB::IN{'USERNAV_ON'},
                    MISCBACK_ONE    => $iB::IN{'MISCBACK_ONE'},
                    MISCBACK_TWO    => $iB::IN{'MISCBACK_TWO'},
                    MISCBACK_TITLE  => $iB::IN{'MISCBACK_TITLE'},
                    CAT_BACK        => $iB::IN{'CAT_BACK'},
                    TABLE_BORDER_COL=> $iB::IN{'TABLE_BORDER_COL'},
                    TABLE_WIDTH     => $iB::IN{'TABLE_WIDTH'},
                    FORUM_COL_ONE   => $iB::IN{'FORUM_COL_ONE'},
                    FORUM_COL_TWO   => $iB::IN{'FORUM_COL_TWO'},
                    PIN_COL_ONE     => $iB::IN{'PIN_COL_ONE'},
                    PIN_COL_TWO     => $iB::IN{'PIN_COL_TWO'},
                    EXP_CAT_ONE     => $iB::IN{'EXP_CAT_ONE'},
                    EXP_CAT_TWO     => $iB::IN{'EXP_CAT_TWO'},
                    POST_COL_ONE    => $iB::IN{'POST_COL_ONE'},
                    POST_COL_TWO    => $iB::IN{'POST_COL_TWO'},
                    BOARD_LOGO      => $iB::IN{'BOARD_LOGO'},
                    LOGO_ALIGN      => $iB::IN{'LOGO_ALIGN'},
                    EDIT_FONT_SIZE  => $iB::IN{'EDIT_FONT_SIZE'},
                };

    $ADMIN->make_module( FILE     => 'Styles.pm',
                         PKG_NAME => 'Styles',
                         VALUES   => $data,
                         PATH     => $iB::INFO->{'IKON_DIR'}.'Skin/'.$iB::IN{'SKIN'}.'/'
                       );

    $ADMIN->write_log( TITLE => 'Global Colours Edited');

    $ADMIN->static_screen( URL   => "act=styles&CODE=edit&SECTION=$iB::IN{'SECTION'}&SKIN=$iB::IN{'SKIN'}",
                           TITLE => "Colour Information edited",
                           TEXT  => "The changes were successful"
                         );
}



#########################################################################################################
#
# Process Jumper
#
#########################################################################################################


sub process {
    my ($obj, $db) = @_;

    my $CodeNo = $iB::IN{'CODE'};

    my %Mode = ( 'edit'          => \&edit,
                 'doedit'        => \&doedit,
               );
    $Mode{$CodeNo} ? $Mode{$CodeNo}->($obj,$db) : splash($obj,$db);
} 






sub DESTROY { }


1;
__END__
