package Admin::Templates;
use strict;
#################################################################################
# Ikonboard v3 by Jarvis Entertainment Group, Inc.
#
# No part of this script can be used outside Ikonboard without prior consent.
#
# More information available from <ib-license@jarvisgroup.net>
# (c)2001 Jarvis Entertainment Group, Inc.
# 
# http://www.ikonboard.com | http://www.jarvisgroup.net
#
# Please read the license for more information
#
# 
# Script Author: Matthew Mecham <matt@ikonboard.com>
#
#################################################################################

BEGIN {
    require 'Lib/FUNC.pm';
    require 'Lib/ADMIN.pm';
    require 'Admin/SKIN.pm';
    require 'Boardinfo.pm' or die "Cannot load Module: $!";
}

my $SKIN  = Admin::SKIN->new();
my $std   = FUNC::STD->new();
my $ADMIN = FUNC::ADMIN->new();
my $INFO  = Boardinfo->new();

sub new {
    my $pkg = shift;
    my $obj = {};
    bless $obj, $pkg;
    return $obj;
}

sub splash {
    my ($obj, $db) = @_;

    my $html  = $SKIN->title( TITLE => 'Template Control');
       $html .= $SKIN->begin_table();
       $html .= $SKIN->form_start();
       $html .= $SKIN->hidden_fields( { act   => 'template',
                                        CODE  => 'choose'
                                      } );

    #+-----------------------------------

    $html .= $SKIN->section_header( TITLE => "Please Choose Which Templates to edit" );

    $html .= $SKIN->td_select( TEXT     => 'Editable Templates',
                               NAME     => 'TYPE',
                               SIZE     => 3,
                               VALUES   => 'GLOBAL',
                               DATA     => [ { VALUE => 'GLOBAL'   , NAME => 'Global Board Template'  },
                                             { VALUE => 'EMAIL_TXT', NAME => 'Email Templates (TEXT)' },
                                             { VALUE => 'EMAIL_HTM', NAME => 'Email Templates (HTML)' },
                                           ]
                             );


    $html .= $SKIN->td_submit(   NAME => '', VALUE => 'Edit this Template' );


    $html .= $SKIN->form_end();
    $html .= $SKIN->end_table();

    #+-----------------------------------

    $ADMIN->Output( WHERE => 'STYLES', NAV_ONE => 'Template Control', PRINT => $html);

}

##########################################################################################
#
# Method Jumpers
#
##########################################################################################



sub choose {
    my ($obj, $db) = @_;
    
    $iB::IN{'TYPE'} eq 'GLOBAL' ? $obj->do_global($db)
                                : (
                                    $iB::IN{'TYPE'} eq 'EMAIL_TXT'
                                    ? $obj->txt_email($db)
                                    : $obj->htm_email($db)
                                  );
}


sub doedit {
    my ($obj, $db) = @_;
    
    $iB::IN{'TYPE'} eq 'GLOBAL' ? $obj->save_global($db)
                                : (
                                    $iB::IN{'TYPE'} eq 'EMAIL_TXT'
                                    ? $obj->txt_save($db)
                                    : $obj->htm_save($db)
                                  );
}


##########################################################################################
#
# Email (TEXT) Templates
#
##########################################################################################

sub txt_email {
    my ($obj, $db) = @_;

    my $temps = {};

    my $templates = $db->query( TABLE    => 'email_templates',
                                WHERE    => "TYPE eq 't'",
                              );

    for my $t (@{$templates}) {
        $temps->{ $t->{'ID'} } = $t->{'TEMPLATE'};
    }



    my $html  = $SKIN->title( TITLE => 'Email Template Control', TEXT => 'Editing Text Email Templates');

    $html .= $SKIN->begin_table();
    $html .= $SKIN->form_start();
    $html .= $SKIN->hidden_fields( { act   => 'template',
                                     CODE  => 'doedit',
                                     TYPE  => 'EMAIL_TXT',
                                   } );

    $html .= $SKIN->section_header( TITLE => "Email Templates",
                                    TEXT => "Please do not remove, or edit the &lt;# TAG #&gt; tags. You may rearrange, or move them
                                             <br>&nbsp;&nbsp;&nbsp;&nbsp;The following tags are always available:
                                             <br>&nbsp;&nbsp;&nbsp;&nbsp;<#BOARD_ADDRESS#> converts to your boards URL (http://www.domain.com/ikonboard/ikonboard.cgi)
                                             <br>&nbsp;&nbsp;&nbsp;&nbsp;<#WEB_ADDRESS#> converts to your websites URL (http://www.domain.com/)
                                             <br>&nbsp;&nbsp;&nbsp;&nbsp;<#BOARD_NAME#> converts to your board name (\"My Website Forums\")
                                             <br>&nbsp;&nbsp;&nbsp;&nbsp;<#SIGNATURE#> converts to the signature you defined in Email Options"
                                    );

    $html .= $SKIN->td_textarea( TEXT  => "Invite a Friend Template",
                                 NAME  => 'INVITE_FRIEND',
                                 VALUE => $temps->{'INVITE_FRIEND'},
                                 ROWS  => 20
                                );

    $html .= $SKIN->td_textarea( TEXT  => "Lost Password: Step 1",
                                 NAME  => 'LOST_PASS_ONE',
                                 VALUE => $temps->{'LOST_PASS_ONE'},
                                 ROWS  => 20
                                );

    $html .= $SKIN->td_textarea( TEXT  => "Lost Password: Step 2",
                                 NAME  => 'LOST_PASS_TWO',
                                 VALUE => $temps->{'LOST_PASS_TWO'},
                                 ROWS  => 20
                                );

    $html .= $SKIN->td_textarea( TEXT  => "Member to member emailing<br>&nbsp;&nbsp;&nbsp;&nbsp;(when 'use email form' is switched on)",
                                 NAME  => 'MEM_TO_MEM',
                                 VALUE => $temps->{'MEM_TO_MEM'},
                                 ROWS  => 20
                                );

    $html .= $SKIN->td_textarea( TEXT  => "Registration Validation",
                                 NAME  => 'REG',
                                 VALUE => $temps->{'REG'},
                                 ROWS  => 20
                                );

    $html .= $SKIN->td_textarea( TEXT  => "New Reply Notification",
                                 NAME  => 'SUBS',
                                 VALUE => $temps->{'SUBS'},
                                 ROWS  => 20
                                );

    $html .= $SKIN->td_textarea( TEXT  => "Email Address Change Request",
                                 NAME  => 'E_CH',
                                 VALUE => $temps->{'E_CH'},
                                 ROWS  => 20
                                );

    $html .= $SKIN->td_textarea( TEXT  => "Administrators New User Notification",
                                 NAME  => 'USER_NOTIFY',
                                 VALUE => $temps->{'USER_NOTIFY'},
                                 ROWS  => 20
                                );

    $html .= $SKIN->td_submit(   NAME => '', VALUE => 'Apply the edit to these templates' );

    $html .= $SKIN->form_end();
    $html .= $SKIN->end_table();

    #+-----------------------------------

    $ADMIN->Output( WHERE => 'STYLES', NAV_ONE => 'Editing Email (TEXT) Templates', PRINT => $html);

}

sub txt_save {
    my ($obj, $db) = @_;

    for (qw[INVITE_FRIEND LOST_PASS_ONE LOST_PASS_TWO MEM_TO_MEM REG SUBS E_CH USER_NOTIFY]) {

        #XXX Get the raw input, to ensure that it's not been regexed to death.

        unless ( $iB::CGI->param($_) ) {
            $ADMIN->Error( DB=>,"", STD=>"", MSG => "You must fill in all the templates");
        }

    }

#$db->insert( TABLE=>'email_templates', VALUES=> { ID=>'USER_NOTIFY', TYPE=>'t', TEMPLATE=>$iB::CGI->param('USER_NOTIFY') } );

    for (qw[INVITE_FRIEND LOST_PASS_ONE LOST_PASS_TWO MEM_TO_MEM REG SUBS E_CH USER_NOTIFY]) {

        $db->update( TABLE  => 'email_templates',
                     KEY    => $_,
                     VALUES => { 
                                 TYPE     => 't',
                                 TEMPLATE => $iB::CGI->param($_)
                               }
                   );
    }

    #XXX Print log and finish off

    $ADMIN->write_log( TITLE => 'Text Email Templates Edited');

    $ADMIN->static_screen( URL   => "act=template",
                           TITLE => "Email  (TEXT) Templates Edited",
                           TEXT  => "The changes were successful"
                         );
}


    






##########################################################################################
#
# Global Templates
#
##########################################################################################



sub do_global {
    my ($obj, $db) = @_;

    unless (-e $iB::INFO->{'TEMPLATE_DIR'}.'global_template.html') {
        $ADMIN->Error( DB=>,"", STD=>"", MSG => "Cannot locate the template file at ".$iB::INFO->{'TEMPLATE_DIR'}.'global_template.html');
    }
    
    my $file = $iB::INFO->{'TEMPLATE_DIR'}.'global_template.html';
    if ($^O ne 'MacOS' && ($^O ne 'MSWin32' || !Win32::IsWin95())) {
        unless (-w $file) {
            chmod (0777, $file) || $ADMIN->Error( DB=>"",STD=>"",MSG=>"I do not have write permissions to change the CHMOD value on :$file. Please use FTP to change the CHMOD value on the file $file");
            chmod (0777, $iB::INFO->{'IKON_DIR'}.'Data') || $ADMIN->Error( DB=>"",STD=>"",MSG=>"I do not have write permissions to change the CHMOD value on the path :$file. Please use FTP to change the CHMOD value on the directory 'Data'");
        }
    } else {
        unless (-w $file) {
            $ADMIN->Error( DB=>"",STD=>"",MSG=>"I do not have write permissions to $file");
        }
    }

    local $/ = undef;
    open FH, $iB::INFO->{'TEMPLATE_DIR'}.'global_template.html';
    my $it = <FH>;
    close FH or die "Could not close that file: $!";

    #XXX We use the ASCII values, so people can use &gt;, &lt; without it being converted when read back

    $it =~ s!<!&#60;!g;
    $it =~ s!>!&#62;!g;

    my $html  = $SKIN->title( TITLE => 'Template Control');

    $html .= qq~<script language='Javascript'>
                function Preview() {
                    var Template = document.TheForm.TEMPLATE.value;
                    var newWin = window.open( '', 'PREVIEW', 'width=500,height=500,top=0,left=0,resizable=1,scrollbars=1,location=no,directories=no,status=no,menubar=no,toolbar=no');
                    newWin.document.write(Template);
                }
                </script>
               ~;




    $html .= $SKIN->begin_table();
    $html .= $SKIN->form_start();
    $html .= $SKIN->hidden_fields( { act   => 'template',
                                     CODE  => 'doedit',
                                     TYPE  => 'GLOBAL',
                                   } );

    $html .= $SKIN->section_header( TITLE => "Global Template", TEXT => "Please do not remove, or edit the &lt;% TAG %&gt; tags. You may rearrange, or move them" );

    $html .= $SKIN->td_textarea( TEXT  => "Template",
                                 NAME  => 'TEMPLATE',
                                 VALUE => $it,
                                 SPAN  => 1,
                                 ROWS  => 30
                                );

    $html .= qq~<tr>
                <td colspan='2' bgcolor='#FFFFFF' align='center'><input type='button' value='PREVIEW' onClick='javascript:Preview();'></td>
                </tr>
                ~;

    $html .= $SKIN->td_submit(   NAME => '', VALUE => 'Edit this Template' );

    $html .= $SKIN->form_end();
    $html .= $SKIN->end_table();

    #+-----------------------------------

    $ADMIN->Output( WHERE => 'STYLES', NAV_ONE => 'Editing Global Template', PRINT => $html);

}

sub save_global {
    my ($obj, $db) = @_;

    $ADMIN->Error( DB=>,"", STD=>"", MSG => "I can't save an empty template!") unless length($iB::IN{'TEMPLATE'}) > 1;

    #XXX Grab the raw TEMPLATE param, so we know it's not been regexed to death by CleanValue

    my $template = $iB::CGI->param('TEMPLATE');
    
    #XXX Gimmie back my HTML

    $template =~ s!&#62;!>!g;
    $template =~ s!&#60;!<!g;

    #XXX No doubt someone will remove the <% IKONBOARD %> tag...
    #XXX Then post on the support board that their board has gone 'missing'.

    unless ($template =~ m#<% IKONBOARD %>#) {
        $ADMIN->Error( DB=>,"", STD=>"", MSG => "You need the &lt;% IKONBOARD %&gt; tag!");
    }
    unless ($template =~ m#<% COPYRIGHT %>#) {
        $ADMIN->Error( DB=>,"", STD=>"", MSG => "You need the &lt;% COPYRIGHT %&gt; tag!");
    }

    #XXX Here goes nothing...

    open FH, ">".$iB::INFO->{'TEMPLATE_DIR'}.'global_template.html';
    print FH $template;
    close FH or die "Could not close that file: $!";

    #XXX Print log and finish off

    $ADMIN->write_log( TITLE => 'Global Template Edited');

    $ADMIN->static_screen( URL   => "act=template",
                           TITLE => "Global Template Edited",
                           TEXT  => "The changes were successful"
                         );
}




##########################################################################################
#
# Process Sub
#
##########################################################################################


sub process {
    my ($obj, $db) = @_;

    my $CodeNo = $iB::IN{'CODE'};

    my %Mode = ( 'choose'        => \&choose,
                 'doedit'        => \&doedit,
               );
    $Mode{$CodeNo} ? $Mode{$CodeNo}->($obj,$db) : splash($obj,$db);
} 






sub DESTROY { }


1;
__END__
