package Boards;
use strict;
#################################################################################
# Ikonboard v3 by Jarvis Entertainment Group, Inc.
#
# No parts of this script can be used outside Ikonboard without prior consent.
#
# More information available from <ib-license@jarvisgroup.net>
# (c)2001 Jarvis Entertainment Group, Inc.
# 
# http://www.ikonboard.com
#
# Please Read the license for more information
#+-----------------------------------------------------------------+
#
# Boards: Display the board summary
#
#################################################################################

BEGIN { require 'Lib/FUNC.pm'; }

my $std    = FUNC::STD->new();
my $output = FUNC::Output->new();
my $print  = undef;


sub new {
    my $pkg = shift;
    my $obj = { '_output' => undef, 'nav' => [] };
    bless $obj, $pkg;
    return $obj;
}


sub ShowStart {
    my ($obj, $db) = @_;

    $Boards::lang = $std->LoadLanguage('BoardWords');
    require $iB::SKIN->{'DIR'} . '/BoardsView.pm' or die $!;

    $print = BoardsView::PageTop();

    $obj->{'TOTAL_CATS'}   = $db->query(TABLE     => 'categories',
                                        SORT_KEY  => 'CAT_POS',
                                        SORT_BY   => 'A-Z',
                                        MATCH     => 'ALL',
                                      ) || die $db->{'error'};

    $obj->{'MODERATORS'}   = $db->query(TABLE     => 'forum_moderators',
                                        SORT_KEY  => 'MEMBER_NAME',
                                        SORT_BY   => 'A-Z',
                                        MATCH     => 'ALL'
                                      ) || die $db->{'error'};

    
    $obj->{'TOTAL_FORUMS'} = $db->query(TABLE     => 'forum_info',
                                        SORT_KEY  => 'FORUM_POSITION',
                                        SORT_BY   => 'A-Z',
                                        MATCH     => 'ALL'
                                      ) || die $db->{'error'};

    unless (-e $iB::PTH.'/Data/ForumJump.pm') {
        $std->build_forumjump( DB     => $db,
                               CATS   => $obj->{'TOTAL_CATS'},
                               FORUMS => $obj->{'TOTAL_FORUMS'}
                             );
    }

    $iB::IN{'act'} eq 'SC' ? $obj->show_cat($db) : $obj->show_list($db);

    if ($iB::INFO->{'SHOW_ONLINE'}) {
        my $Names;
        foreach (@{ $iB::ACTIVE->{'NAMES'} }) {
            $Names .= qq! <font class='highlight'>&gt;</font><a href='$iB::INFO->{'BOARD_URL'}/ikonboard.cgi?act=Profile;CODE=03;MID=$_->{'ID'}' class='misc'>$_->{'NAME'}</a>!;
        }
    
        my $link = $iB::INFO->{'ALLOW_ONLINE_LIST'} ? qq|&nbsp;&nbsp;[ <a href="$iB::INFO->{'BOARD_URL'}/ikonboard.$iB::INFO->{'CGI_EXT'}?s=$iB::SESSION;act=Online;CODE=listall" class='misc'>$Boards::lang->{'browser_user_list'}</a> ]| : '';

        $print .= BoardsView::ActiveUsers($Names,
                                          $link,
                                          $iB::ACTIVE->{'MEMBERS'} || 0,
                                          $iB::ACTIVE->{'GUESTS'}  || 0,
                                          $iB::ACTIVE->{'ANON'}    || 0,
                                          $iB::ACTIVE->{'MEMBERS'} + $iB::ACTIVE->{'GUESTS'} + $iB::ACTIVE->{'ANON'} || 0
                                         );
    }
   
    if ($iB::INFO->{'SHOW_STATS'}) {
        my $Stats = $db->select( TABLE  => 'board_statistics', KEY  => 'MAIN');# || die $db->{'error'};
        $Stats->{'LAST_POST_DATE'} = $std->get_date( TIME => $Stats->{'LAST_POST_DATE'}, METHOD => 'LONG');
        $print .= BoardsView::ShowStats($Stats);
    }   
    
    $print .= BoardsView::Invite_Friend() if ($iB::INFO->{'INVITE_FRIEND'} and $iB::MEMBER_GROUP->{'INVITE_FRIEND'});
    $print .= BoardsView::BoardInformation();

    $output->print_ikonboard( DB => $db, STD => $std, OUTPUT  => $print, TITLE => $iB::INFO->{'BOARDNAME'}, NAV => $obj->{'nav'});
}




sub show_list {
    my ($obj, $db) = @_;

    my $cats_printed = {};
    
    for my $this_cat (@{ $obj->{'TOTAL_CATS'} }) {

        #XXX Skip it if the category has already been printed or we don't have permission to view the category

        next if exists $cats_printed->{ $this_cat->{'CAT_ID'} };

        if ($this_cat->{'VIEW'} ne '*') {
            next unless grep { $_ == $iB::MEMBER->{'MEMBER_GROUP'} } (split (/,/, $this_cat->{'VIEW'}) );
        }

        #XXX Grab all the forums in this main category
        
        my @these_cat_forums = grep { $_->{'CATEGORY'} == $this_cat->{'CAT_ID'} } @{ $obj->{'TOTAL_FORUMS'} };
        
        $print .= BoardsView::CatHeader_Expanded($this_cat);

        #XXX Grab any sub categories in this main category

        my @sub_cats = grep { $this_cat->{'CAT_ID'} == $_->{'SUB_CAT_ID'} && $_->{'SUB_CAT_ID'} ne '-' } @{ $obj->{'TOTAL_CATS'} };



        if (@sub_cats > 0) {

            for my $subcat (@sub_cats) {

                #XXX: Grab all the forums for this sub category

                my @these_sub_cat_forums = grep { $_->{'CATEGORY'} == $subcat->{'CAT_ID'} } @{ $obj->{'TOTAL_FORUMS'} };
                
                for my $forum (@these_sub_cat_forums) {
                    if ($forum->{'FORUM_VIEW_THREADS'} ne '*') {
                        next unless grep { $_ == $iB::MEMBER->{'MEMBER_GROUP'} } (split /,/,$forum->{'FORUM_VIEW_THREADS'});
                    }
                    $subcat->{'TOTAL_FORUMS'} += 1;
                    $subcat->{'POSTS'}        += $forum->{'FORUM_POSTS'};
                    $subcat->{'TOPICS'}       += $forum->{'FORUM_TOPICS'};
                    if ($forum->{'FORUM_LAST_POST'} > $subcat->{'LAST_POST'}) {
                        $subcat->{'LAST_POST'}         = $forum->{'FORUM_LAST_POST'};
                        $subcat->{'LAST_POSTER_N'}     = $forum->{'FORUM_LAST_POSTER_N'};
                        $subcat->{'TOPIC_TITLE'}       = $forum->{'L_TOPIC_TITLE'};
                        $subcat->{'FORUM_ID'}          = $forum->{'FORUM_ID'};
                        $subcat->{'TOPIC_ID'}          = $forum->{'L_TOPIC_ID'};
                        $subcat->{'NEW_POST_IMG'}      = $obj->new_cat_posts($forum);
                    }
                }
                $subcat->{'LAST_POST'}  = $std->get_date( TIME => $subcat->{'LAST_POST'}, METHOD => 'LONG');
                $subcat->{'N_LINK'}     = ($subcat->{'TOPIC_TITLE'} and defined $subcat->{'TOPIC_ID'})
                                          ? qq[<a href='$iB::INFO->{'BOARD_URL'}/ikonboard.$iB::INFO->{'CGI_EXT'}?s=$iB::SESSION;act=ST;f=$subcat->{'FORUM_ID'};t=$subcat->{'TOPIC_ID'}' class='misc'>$subcat->{'TOPIC_TITLE'}</a>]
                                          : $Boards::lang->{'f_none'};

                if ($subcat->{'LAST_POSTER_N'}) {
                    $subcat->{'P_LINK'} = $subcat->{'LAST_POSTER'} ? qq[<a href='$iB::INFO->{'BOARD_URL'}/ikonboard.$iB::INFO->{'CGI_EXT'}?s=$iB::SESSION;act=Profile;CODE=03;MID=$subcat->{'LAST_POSTER'}' class='misc'>$subcat->{'LAST_POSTER_N'}</a>]
                                                                       : $subcat->{'LAST_POSTER_N'};
                }
                $subcat->{'P_LINK'} = $Boards::lang->{'f_none'} unless $subcat->{'P_LINK'};

                #XXX Are there any forums in this category that we're allowed to see?
                #XXX If not, there's no point printing it...
            
                if ($subcat->{'TOTAL_FORUMS'} > 0) {
                    $print .= BoardsView::CatHeader_Collapsed($subcat);
                }

                $cats_printed->{ $subcat->{'CAT_ID'} } = 1;
               
            }
         
        }
    
        #XXX Print the rest of the forums (if there are any!)
        
        for my $this_forum (@these_cat_forums) {

            if ($this_forum->{'FORUM_VIEW_THREADS'} ne '*') {
                next unless grep { $_ == $iB::MEMBER->{'MEMBER_GROUP'} } (split /,/,$this_forum->{'FORUM_VIEW_THREADS'});
            }
        
            $this_forum->{'N_LINK'} = ($this_forum->{'L_TOPIC_TITLE'} and defined $this_forum->{'L_TOPIC_ID'})
                                    ? qq[<a href='$iB::INFO->{'BOARD_URL'}/ikonboard.$iB::INFO->{'CGI_EXT'}?s=$iB::SESSION;act=ST;f=$this_forum->{'FORUM_ID'};t=$this_forum->{'L_TOPIC_ID'}' class='misc'>$this_forum->{'L_TOPIC_TITLE'}</a>]
                                    : $Boards::lang->{'f_none'};

            if ($this_forum->{'FORUM_LAST_POSTER_N'}) {
                $this_forum->{'P_LINK'} = $this_forum->{'FORUM_LAST_POSTER'} ? qq[<a href='$iB::INFO->{'BOARD_URL'}/ikonboard.$iB::INFO->{'CGI_EXT'}?s=$iB::SESSION;act=Profile;CODE=03;MID=$this_forum->{'FORUM_LAST_POSTER'}' class='misc'>$this_forum->{'FORUM_LAST_POSTER_N'}</a>]
                                                                         : $this_forum->{'FORUM_LAST_POSTER_N'};
            } else {
                $this_forum->{'P_LINK'} = $Boards::lang->{'f_none'};
            }

            if ($this_forum->{'FORUM_PROTECT'}) {
                next unless $iB::MEMBER->{'MEMBER_ID'};
                $this_forum->{'N_LINK'} = qq[$Boards::lang->{'f_protected'}];
            }

            $this_forum->{'NEW_POST_IMG'}       = $obj->new_posts($this_forum);
            $this_forum->{'FORUM_LAST_POST'}    = $std->get_date( TIME => $this_forum->{'FORUM_LAST_POST'}, METHOD => 'LONG');
            $this_forum->{'FORUM_USERS'}        = $iB::ACTIVE->{'FORUMS'}->{ $this_forum->{'FORUM_ID'} } || 0;
                                            
            my @mods;
            for ( grep { $this_forum->{'FORUM_ID'} == $_->{'FORUM_ID'} } @{ $obj->{'MODERATORS'} }  ) {
                push @mods, "<a href='$iB::INFO->{'BOARD_URL'}/ikonboard.$iB::INFO->{'CGI_EXT'}?s=$iB::SESSION;act=Profile;CODE=03;MID=$_->{'MEMBER_ID'}' class='highlight'>$_->{'MEMBER_NAME'}</a>";
            }

            $this_forum->{'MODERATOR'} = $Boards::lang->{'forum_leader'} . join ", ", @mods if @mods > 0;

            $print .= BoardsView::ForumRow($this_forum);


        }
        
    }
}




sub show_cat {
    my ($obj, $db) = @_;

    $std->Error( DB => $db, STD => $std, MESSAGE => 'no_action') unless defined $iB::IN{'c'};

    my $this_cat = $db->select( TABLE => 'categories',
                                KEY   => $iB::IN{'c'}
                              );

    if ($this_cat->{'VIEW'} ne '*') {
        unless ( grep { $_ == $iB::MEMBER->{'MEMBER_GROUP'} } (split (/,/, $this_cat->{'VIEW'}) ) ) {
            $std->Error( DB => $db, STD => $std, MESSAGE => 'no_permission');
        }
    }

    my @these_cat_forums = grep { $_->{'CATEGORY'} == $this_cat->{'CAT_ID'} } @{ $obj->{'TOTAL_FORUMS'} };

    if ($this_cat->{'SUB_CAT_ID'} ne '-') {
        my $sub_cat = $db-> select( TABLE => 'categories',
                                    KEY   => $this_cat->{'SUB_CAT_ID'}
                                  );
        push @{ $obj->{'nav'} }, qq[<a href="$iB::INFO->{'BOARD_URL'}/ikonboard.$iB::INFO->{'CGI_EXT'}?s=$iB::SESSION;act=SC;c=$sub_cat->{'CAT_ID'}" class='nav'>$sub_cat->{'CAT_NAME'}</a>];
    }

    push @{ $obj->{'nav'} }, qq!$this_cat->{'CAT_NAME'}!;

    $print .= BoardsView::CatHeader_Expanded($this_cat);

        #XXX Grab any sub categories in this main category

        my @sub_cats = grep { $this_cat->{'CAT_ID'} == $_->{'SUB_CAT_ID'} && $_->{'SUB_CAT_ID'} ne '-' } @{ $obj->{'TOTAL_CATS'} };

        if (@sub_cats > 0) {

            for my $subcat (@sub_cats) {

                #XXX: Grab all the forums for this sub category

                my @these_sub_cat_forums = grep { $_->{'CATEGORY'} == $subcat->{'CAT_ID'} } @{ $obj->{'TOTAL_FORUMS'} };
                
                for my $forum (@these_sub_cat_forums) {
                    if ($forum->{'FORUM_VIEW_THREADS'} ne '*') {
                        next unless grep { $_ == $iB::MEMBER->{'MEMBER_GROUP'} } (split /,/,$forum->{'FORUM_VIEW_THREADS'});
                    }
                    $subcat->{'TOTAL_FORUMS'} += 1;
                    $subcat->{'POSTS'}        += $forum->{'FORUM_POSTS'};
                    $subcat->{'TOPICS'}       += $forum->{'FORUM_TOPICS'};
                    if ($forum->{'FORUM_LAST_POST'} > $subcat->{'LAST_POST'}) {
                        $subcat->{'LAST_POST'}         = $forum->{'FORUM_LAST_POST'};
                        $subcat->{'LAST_POSTER_N'}     = $forum->{'FORUM_LAST_POSTER_N'};
                        $subcat->{'TOPIC_TITLE'}       = $forum->{'L_TOPIC_TITLE'};
                        $subcat->{'FORUM_ID'}          = $forum->{'FORUM_ID'};
                        $subcat->{'TOPIC_ID'}          = $forum->{'L_TOPIC_ID'};
                        $subcat->{'NEW_POST_IMG'}      = $obj->new_cat_posts($forum);
                    }
                }
                $subcat->{'LAST_POST'}  = $std->get_date( TIME => $subcat->{'LAST_POST'}, METHOD => 'LONG');
                $subcat->{'LAST_POST'}  = '--' unless $subcat->{'LAST_POST'};
                $subcat->{'N_LINK'}     = ($subcat->{'TOPIC_TITLE'} and defined $subcat->{'TOPIC_ID'})
                                          ? qq[<a href='$iB::INFO->{'BOARD_URL'}/ikonboard.$iB::INFO->{'CGI_EXT'}?s=$iB::SESSION;act=ST;f=$subcat->{'FORUM_ID'};t=$subcat->{'TOPIC_ID'}' class='misc'>$subcat->{'TOPIC_TITLE'}</a>]
                                          : $Boards::lang->{'f_none'};

                if ($subcat->{'LAST_POSTER_N'}) {
                    $subcat->{'P_LINK'} = $subcat->{'LAST_POSTER'} ? qq[<a href='$iB::INFO->{'BOARD_URL'}/ikonboard.$iB::INFO->{'CGI_EXT'}?s=$iB::SESSION;act=Profile;CODE=03;MID=$subcat->{'LAST_POSTER'}' class='misc'>$subcat->{'LAST_POSTER_N'}</a>]
                                                                       : $subcat->{'LAST_POSTER_N'};
                }
                $subcat->{'P_LINK'} = $Boards::lang->{'f_none'} unless $subcat->{'P_LINK'};

                #XXX Are there any forums in this category that we're allowed to see?
                #XXX If not, there's no point printing it...
            
                if ($subcat->{'TOTAL_FORUMS'} > 0) {
                    $print .= BoardsView::CatHeader_Collapsed($subcat);
                }
               
            }
         
        }
    
    for my $this_forum (@these_cat_forums) {

        if ($this_forum->{'FORUM_VIEW_THREADS'} ne '*') {
            next unless grep { $_ == $iB::MEMBER->{'MEMBER_GROUP'} } (split /,/,$this_forum->{'FORUM_VIEW_THREADS'});
        }
        
        $this_forum->{'N_LINK'} = ($this_forum->{'L_TOPIC_TITLE'} and defined $this_forum->{'L_TOPIC_ID'})
                                    ? qq[<a href='$iB::INFO->{'BOARD_URL'}/ikonboard.$iB::INFO->{'CGI_EXT'}?s=$iB::SESSION;act=ST;f=$this_forum->{'FORUM_ID'};t=$this_forum->{'L_TOPIC_ID'}' class='misc'>$this_forum->{'L_TOPIC_TITLE'}</a>]
                                    : $Boards::lang->{'f_none'};

        if ($this_forum->{'FORUM_LAST_POSTER_N'}) {
            $this_forum->{'P_LINK'} = $this_forum->{'FORUM_LAST_POSTER'} ? qq[<a href='$iB::INFO->{'BOARD_URL'}/ikonboard.$iB::INFO->{'CGI_EXT'}?s=$iB::SESSION;act=Profile;CODE=03;MID=$this_forum->{'FORUM_LAST_POSTER'}' class='misc'>$this_forum->{'FORUM_LAST_POSTER_N'}</a>]
                                                                         : $this_forum->{'FORUM_LAST_POSTER_N'};
        } else {
                $this_forum->{'P_LINK'} = $Boards::lang->{'f_none'};
        }

        if ($this_forum->{'FORUM_PROTECT'}) {
            next unless $iB::MEMBER->{'MEMBER_ID'};
            $this_forum->{'N_LINK'} = qq[$Boards::lang->{'f_protected'}];
        }

        $this_forum->{'NEW_POST_IMG'}       = $obj->new_posts($this_forum);
        $this_forum->{'FORUM_LAST_POST'}    = $std->get_date( TIME => $this_forum->{'FORUM_LAST_POST'}, METHOD => 'LONG');
        $this_forum->{'FORUM_USERS'}        = $iB::ACTIVE->{'FORUMS'}->{ $this_forum->{'FORUM_ID'} } || 0;
                                            
        my @mods;
        for ( grep { $this_forum->{'FORUM_ID'} == $_->{'FORUM_ID'} } @{ $obj->{'MODERATORS'} }  ) {
            push @mods, "<a href='$iB::INFO->{'BOARD_URL'}/ikonboard.$iB::INFO->{'CGI_EXT'}?s=$iB::SESSION;act=Profile;CODE=03;MID=$_->{'MEMBER_ID'}' class='highlight'>$_->{'MEMBER_NAME'}</a>";
        }

        $this_forum->{'MODERATOR'} = $Boards::lang->{'forum_leader'} . join ", ", @mods if @mods > 0;
        $print .= BoardsView::ForumRow($this_forum);
    }
}


sub new_cat_posts {
    my ($obj, $this_forum) = @_;

    return qq[<img src="$iB::INFO->{'IMAGES_URL'}/images/off-cat.gif" border="0">] unless $iB::MEMBER->{'LAST_LOG_IN'};
    return $this_forum->{'FORUM_LAST_POST'} > $iB::MEMBER->{'LAST_LOG_IN'} ? qq[<img src="$iB::INFO->{'IMAGES_URL'}/images/on-cat.gif" border="0">]
                                                                           : qq[<img src="$iB::INFO->{'IMAGES_URL'}/images/off-cat.gif" border="0">];
}


sub new_posts ($) {
    my ($obj, $this_forum) = @_;
    return qq[<img src="$iB::INFO->{'IMAGES_URL'}/images/off_locked.gif" border="0">] unless $this_forum->{'FORUM_STATUS'};
    if ($this_forum->{'FORUM_PROTECT'}) {
        return $this_forum->{'FORUM_LAST_POST'} > $iB::MEMBER->{'LAST_LOG_IN'} ? qq[<img src="$iB::INFO->{'IMAGES_URL'}/images/on-restrict.gif" border="0">]
                                                                           : qq[<img src="$iB::INFO->{'IMAGES_URL'}/images/off-restrict.gif" border="0">];
    }
    return qq[<img src="$iB::INFO->{'IMAGES_URL'}/images/off.gif" border="0">] unless $iB::MEMBER->{'LAST_LOG_IN'};
    return $this_forum->{'FORUM_LAST_POST'} > $iB::MEMBER->{'LAST_LOG_IN'} ? qq[<img src="$iB::INFO->{'IMAGES_URL'}/images/on.gif" border="0">]
                                                                           : qq[<img src="$iB::INFO->{'IMAGES_URL'}/images/off.gif" border="0">];
}




1;

__END__
