package Forum;
use strict;
#################################################################################
# Ikonboard v3 by Jarvis Entertainment Group, Inc.
#
# No parts of this script can be used outside Ikonboard without prior consent.
#
# More information available from <ib-license@jarvisgroup.net>
# (c)2001 Jarvis Entertainment Group, Inc.
# 
# http://www.ikonboard.com
#
# Please Read the license for more information
#+-----------------------------------------------------------------+
#
# Forum: Display the topic summary for a chosen forum
#
#################################################################################

BEGIN { require 'Lib/FUNC.pm'; }

my $std      = FUNC::STD->new();
my $output   = FUNC::Output->new();
my $mem      = FUNC::Member->new();
my $print    = undef;
$Forum::lang = $std->LoadLanguage('ForumWords');


#+------------------------------------------------------------------------------------------------------

sub new {
    my $pkg = shift;
    my $obj = {};
    bless $obj, $pkg;
    return $obj;
}

#+------------------------------------------------------------------------------------------------------


sub ShowForum {
    my ($obj, $db) = @_;
    $obj->{'.forum_id'} = $std->IsNumber($iB::IN{'f'}) || 0;

    $obj->{'FORUM'} = $db->select( TABLE => 'forum_info',
                                   KEY   => $obj->{'.forum_id'},
                                 );
    
    $obj->{'FORUM'}->{'FORUM_JUMP'} = $std->ForumJump();

    $iB::IN{'L'} == 1 ? $obj->authenticate_user($db) : $obj->_show_forum($db);
}

#+------------------------------------------------------------------------------------------------------

sub ShowRules {
    my ($obj, $db) = @_;
    $obj->{'.forum_id'} = $std->IsNumber($iB::IN{'f'}) || 0;

    $obj->{'FORUM'} = $db->select( TABLE => 'forum_info',
                                   KEY   => $obj->{'.forum_id'},
                                 );

    $iB::IN{'L'} == 1 ? $obj->authenticate_user($db) : $obj->_show_rules($db);
}

#+------------------------------------------------------------------------------------------------------

sub _show_rules ($$) {
    my ($obj, $db) = @_;

    require $iB::SKIN->{'DIR'} . '/ForumView.pm' or die $!;

    my $check = $obj->Check_access($db);
    return if $check == 1;

    $std->Error( DB      => $db,
                 LEVEL   => 2,
                 MESSAGE => 'no_rules_show'
               ) unless $obj->{'FORUM'}->{'SHOW_RULES'};

    my $rules = $db->select(TABLE => 'forum_rules', KEY => $obj->{'FORUM'}->{'FORUM_ID'} );

    $std->Error( DB      => $db,
                 LEVEL   => 2,
                 MESSAGE => 'no_rules_show'
              ) unless $rules;

    $rules->{'RULES_TEXT'}  = $std->TextTidy($rules->{'RULES_TEXT'});

    $rules->{'LAST_UPDATE'} = $std->get_date( TIME   => $rules->{'LAST_UPDATE'},
                                              METHOD => 'LONG'
                                            );

    $output->print_ikonboard( DB       => $db,
                              STD      => $std,
                              OUTPUT   => &ForumView::show_rules($rules),
                              TITLE    => "iB::".$obj->{'FORUM'}->{'FORUM_NAME'},
                              NAV_ONE  => qq[<a href="$iB::INFO->{'BOARD_URL'}/ikonboard.$iB::INFO->{'CGI_EXT'}?s=$iB::SESSION;act=SF;f=$obj->{'FORUM'}->{'FORUM_ID'}" class='nav'>$obj->{'FORUM'}->{'FORUM_NAME'}</a>],
                              NAV_TWO  => $rules->{'RULES_TITLE'}
                            );
}

#+------------------------------------------------------------------------------------------------------

sub _show_forum ($$) {
    my ($obj, $db) = @_;
    my $First = $iB::IN{'st'} || 0;
    require $iB::SKIN->{'DIR'} . '/ForumView.pm' or die $!;

    my $check = $obj->Check_access($db);
    return if $check == 1;

    my $prune_value = $iB::IN{'prune_day'} || $obj->{'FORUM'}->{'PRUNE_DAYS'} || $iB::INFO->{'PRUNE_DAYS'};

    my $sort_key    = $iB::IN{'sort_key'}  || $obj->{'FORUM'}->{'SORT_KEY'}   || $iB::INFO->{'SORT_KEY'};

    my $sort_by     = $iB::IN{'sort_by'}   || $obj->{'FORUM'}->{'SORT_ORDER'} || $iB::INFO->{'FORUM_SORT_ORDER'};

    my $Prune = $prune_value != 100 ? (time - ($prune_value * 60 * 60 * 24)) : 0;

    my $sort_keys   =  { TOPIC_LAST_DATE    => 'sort_by_date',
                         TOPIC_TITLE        => 'sort_by_topic',
                         TOPIC_STARTER_N    => 'sort_by_poster',
                         TOPIC_POSTS        => 'sort_by_replies',
                         TOPIC_VIEWS        => 'sort_by_views',
                         TOPIC_START_DATE   => 'sort_by_start',
                         TOPIC_LASTP_N      => 'sort_by_last_poster',
                       };

    my $prune_by_day = { '1'    => 'show_today',
                         '5'    => 'show_5_days',
                         '7'    => 'show_7_days',
                         '10'   => 'show_10_days',
                         '15'   => 'show_15_days',
                         '20'   => 'show_20_days',
                         '25'   => 'show_25_days',
                         '30'   => 'show_30_days',
                         '60'   => 'show_60_days',
                         '90'   => 'show_90_days',
                         '100'  => 'show_all',
                       };

    my $sort_by_keys = { 'Z-A'  => 'descending_order',
                         'A-Z'  => 'ascending_order',
                       };

    $std->Error(DB => $db, LEVEL=>5, MESSAGE=>'incorrect_use')
        unless ((exists $sort_keys->{$sort_key}) and (exists $prune_by_day->{$prune_value}) and (exists $sort_by_keys->{$sort_by}));

    my $q_extra;
    unless ($iB::MEMBER_GROUP->{'OTHER_TOPICS'}) {
            $q_extra = qq! and TOPIC_STARTER eq "$iB::MEMBER->{'MEMBER_ID'}"!;
        }

    my $total_topics  = $db->query( TABLE    => 'forum_topics',
                                    ID       => $obj->{'.forum_id'},
                                    WHERE    => "TOPIC_STATE ne 'dead' and PIN_STATE == 1 or (TOPIC_LAST_DATE > $Prune and APPROVED == 1)$q_extra",
                                    RANGE    => $First." to ".( $iB::INFO->{'DISPLAY_MAX_TOPICS'} + ($First - 1) ),
                                    POP      => "PIN_STATE == '1'",
                                    SORT_KEY => $sort_key,
                                    SORT_BY  => $sort_by
                                  );


    #+------------------------------------------------------------------------------------------------------

    my $Pages = $std->ib_int( $obj->{'FORUM'}->{'FORUM_TOPICS'}, $iB::INFO->{'DISPLAY_MAX_TOPICS'});
    $obj->{'FORUM'}->{'TOTAL_PAGE'} = $Pages;
    $obj->{'CUR_PAGE'} = $iB::IN{'st'} > 0 ? ($iB::IN{'st'} / $iB::INFO->{'DISPLAY_MAX_TOPICS'}) + 1 : 1;
    if ($Pages > 1) {
        $obj->{'FORUM'}->{'FIRST_PAGE'} = qq[$Forum::lang->{'multi_page_forum'}:: <a href='$iB::INFO->{'BOARD_URL'}/ikonboard.$iB::INFO->{'CGI_EXT'}?s=$iB::SESSION;act=SF;f=$iB::IN{'f'};st=0' class='misc'>&lt;&lt;</a>];
        my $i = 0;
        my $end_dots;
        my $start_dots;
        for(0 .. $Pages-1) {
            my $RealNo = $i * $iB::INFO->{'DISPLAY_MAX_TOPICS'};
            my $PageNo = $i+1;
            if ($RealNo == $iB::IN{'st'}) {
                $obj->{'FORUM'}->{'PAGE_SPAN'} .= qq!&nbsp;&nbsp;&nbsp;<font class='misc'><b>[ $PageNo ]</b><font>!;
            } else {
                if ($PageNo < ($obj->{'CUR_PAGE'} - 5) and ($obj->{'CUR_PAGE'} >= 6))  { $start_dots = '&nbsp;&nbsp;&nbsp;...'; ++$i; next; }
                $obj->{'FORUM'}->{'PAGE_SPAN'} .= qq[&nbsp;&nbsp;&nbsp;<a href='$iB::INFO->{'BOARD_URL'}/ikonboard.$iB::INFO->{'CGI_EXT'}?s=$iB::SESSION;act=SF;f=$iB::IN{'f'};st=$RealNo' class='misc'>$PageNo</a> ];
                if ($PageNo == ($obj->{'CUR_PAGE'} + 5)) { $end_dots = '...&nbsp;&nbsp;&nbsp;'; last; }
            }
            ++$i;
        }
        $obj->{'FORUM'}->{'LAST_PAGE'} = qq[<a href='$iB::INFO->{'BOARD_URL'}/ikonboard.$iB::INFO->{'CGI_EXT'}?s=$iB::SESSION;act=SF;f=$iB::IN{'f'};st=].($Pages-1) * $iB::INFO->{'DISPLAY_MAX_TOPICS'}.qq[' class='misc'>&gt;&gt;</a>];
        $obj->{'FORUM'}->{'SHOW_PAGES'} = $obj->{'FORUM'}->{'FIRST_PAGE'} . $start_dots . $obj->{'FORUM'}->{'PAGE_SPAN'}. '&nbsp;&nbsp;&nbsp;' . $end_dots . $obj->{'FORUM'}->{'LAST_PAGE'};
    } else {
        $obj->{'FORUM'}->{'SHOW_PAGES'} = qq!<font class='misc'>$Forum::lang->{'single_page_forum'}</font>!;
    }


    $obj->{'FORUM'}->{'POLL_BUTTON'} = $iB::INFO->{'ALLOW_POLLS'}
                                     ? qq[<a href='$iB::INFO->{'BOARD_URL'}/ikonboard.$iB::INFO->{'CGI_EXT'}?s=$iB::SESSION;act=Poll;CODE=01;f=$iB::IN{'f'}'><img src="$iB::INFO->{'IMAGES_URL'}/images/t_poll.gif" border='0'></a>]
                                     : '';


    if ($obj->{'FORUM'}->{'SHOW_RULES'}) {
        if (my $rules = $db->select(TABLE => 'forum_rules', KEY => $obj->{'FORUM'}->{'FORUM_ID'} )) {
             $print = ForumView::show_rules_link($rules);
        }
    }
        
    $print .= ForumView::PageTop($obj->{'FORUM'});

    $print .= ForumView::show_no_matches() unless $total_topics;


    for (@{$total_topics}) {
        my $pin = $_->{'PIN_STATE'} == 1 ? 1 : 0;
        $print .= $obj->_do_row( DB => $db, DATA => $_, PIN => $pin );
    }


    $Forum::lang->{'showing_text'} =~ s{<#MATCHED_TOPICS#>}{$total_topics ? scalar @{$total_topics} : '0'}eg;
    $Forum::lang->{'showing_text'} =~ s!<#TOTAL_TOPICS#>!$obj->{'FORUM'}->{'FORUM_TOPICS'}!g;
    
    my $sort_key_html  = qq[<select name='sort_key' class='forminput'>\n];
    my $prune_day_html = qq[<select name='prune_day' class='forminput'>\n];
    my $sort_by_html   = qq[<select name='sort_by' class='forminput'>\n];
    

    for ( sort { $a cmp $b } keys %{$sort_by_keys}) {
        $sort_by_html .= $_ eq $sort_by  ? qq[<option value='$_' selected>$Forum::lang->{ $sort_by_keys->{$_} }\n]
                                         : qq[<option value='$_'>$Forum::lang->{ $sort_by_keys->{$_} }\n];
    }

    for ( sort { $a cmp $b } keys %{$sort_keys}) {
        $sort_key_html .= $_ eq $sort_key ? qq[<option value='$_' selected>$Forum::lang->{ $sort_keys->{$_} }\n]
                                          : qq[<option value='$_'>$Forum::lang->{ $sort_keys->{$_} }\n];
    }
    for ( sort { $a <=> $b } keys %{$prune_by_day}) {
        $prune_day_html .= $_ eq $prune_value ? qq[<option value='$_' selected>$Forum::lang->{ $prune_by_day->{$_} }\n]
                                              : qq[<option value='$_'>$Forum::lang->{ $prune_by_day->{$_} }\n];
    }

    $Forum::lang->{'sort_text'} =~ s!<#SORT_KEY_HTML#>!$sort_key_html</select>!;
    $Forum::lang->{'sort_text'} =~ s!<#ORDER_HTML#>!$sort_by_html</select>!;
    $Forum::lang->{'sort_text'} =~ s!<#PRUNE_HTML#>!$prune_day_html</select>!;

    $print .= ForumView::TableEnd($obj->{'FORUM'});

    my $cat = $db->select( TABLE   => 'categories',
                           KEY     => $obj->{'FORUM'}->{'CATEGORY'},
                           COLUMNS => ['CAT_ID', 'CAT_NAME']
                         );

    $output->print_ikonboard( DB       => $db,
                              STD      => $std,
                              OUTPUT   => $print,
                              TITLE    => "iB::".$obj->{'FORUM'}->{'FORUM_NAME'},
                              NAV      => [
                                            qq|<a href="$iB::INFO->{'BOARD_URL'}/ikonboard.$iB::INFO->{'CGI_EXT'}?s=$iB::SESSION;act=SC;c=$cat->{'CAT_ID'}" class='nav'>$cat->{'CAT_NAME'}</a>|,
                                            qq|<a href="$iB::INFO->{'BOARD_URL'}/ikonboard.$iB::INFO->{'CGI_EXT'}?s=$iB::SESSION;act=SF;f=$obj->{'FORUM'}->{'FORUM_ID'}" class='nav'>$obj->{'FORUM'}->{'FORUM_NAME'}</a>|
                                          ]
                            );
    
}

#+------------------------------------------------------------------------------------------------------

sub _do_row {
    my $obj = shift;
    my $IN  = { DB => "", DATA => "", PIN => "", @_,};
    my $db = $IN->{'DB'};

    $obj->{'.cur_topic'} = $IN->{'DATA'};

    $obj->{'.cur_topic'}->{'LAST_TEXT'}        = $Forum::lang->{'last_post_by'};

    $obj->{'.cur_topic'}->{'LAST_POSTER'}      = ($obj->{'.cur_topic'}->{'TOPIC_LAST_POSTER'} != 0)   ? qq[<b><a href='$iB::INFO->{'BOARD_URL'}/ikonboard.$iB::INFO->{'CGI_EXT'}?s=$iB::SESSION;act=Profile;CODE=03;MID=$obj->{'.cur_topic'}->{'TOPIC_LAST_POSTER'}' class='misc'>$obj->{'.cur_topic'}->{'TOPIC_LASTP_N'}</a></b>]
                                                                                                      : qq[<font class='misc'>-$obj->{'.cur_topic'}->{'TOPIC_LASTP_N'}-</font>];

    $obj->{'.cur_topic'}->{'STARTER'}          = $obj->{'.cur_topic'}->{'TOPIC_STARTER'}      != 0    ? qq[<a href="$iB::INFO->{'BOARD_URL'}/ikonboard.cgi?s=$iB::SESSION;act=Profile;CODE=03;MID=$obj->{'.cur_topic'}->{'TOPIC_STARTER'}" class='misc'>$obj->{'.cur_topic'}->{'TOPIC_STARTER_N'}]
                                                                                                      : qq[-$obj->{'.cur_topic'}->{'TOPIC_STARTER_N'}-];
 

    $obj->{'.cur_topic'}->{'FOLDER_ICON'}      = $obj->folder_icon();

    $obj->{'.cur_topic'}->{'TOPIC_LAST_DATE'}  = $obj->get_last_date();

    $obj->{'.cur_topic'}->{'TOPIC_ICON'}       = $obj->{'.cur_topic'}->{'TOPIC_ICON'} ? $iB::INFO->{'IMAGES_URL'} . '/PostIcons/icon' . $obj->{'.cur_topic'}->{'TOPIC_ICON'} . '.gif'
                                                                                      : $iB::INFO->{'IMAGES_URL'} . '/PostIcons/icon0.gif';

    $obj->{'.cur_topic'}->{'TOPIC_ICON'}       = qq[$iB::INFO->{'IMAGES_URL'}/images/f_pin.gif] if $IN->{'PIN'};

    $obj->{'.cur_topic'}->{'TOPIC_START_DATE'} = $std->get_date( TIME => $obj->{'.cur_topic'}->{'TOPIC_START_DATE'}, METHOD => 'LONG');

    my $Pages = ($obj->{'.cur_topic'}->{'TOPIC_POSTS'} + 1) / $iB::INFO->{'DISPLAY_MAX_POSTS'};
    my ($Int, $Dec) = split /\./,$Pages;
    $Dec > 0 ? ($Pages = $Int + 1) : ($Pages = $Int);
    $Pages = 1 if $Pages < 1;
    if ($Pages > 1) {
        $obj->{'.cur_topic'}->{'PAGES'} = qq[<font class='misc'>(Pages ];
        my $i = 0;
        for(0 .. $Pages-1) {
            my $RealNo = $i * $iB::INFO->{'DISPLAY_MAX_POSTS'}; my $PageNo = $i + 1;
            if ($PageNo == 4) { $obj->{'.cur_topic'}->{'PAGES'} .= qq[<a href='$iB::INFO->{'BOARD_URL'}/ikonboard.$iB::INFO->{'CGI_EXT'}?s=$iB::SESSION;act=ST;f=$iB::IN{'f'};t=$obj->{'.cur_topic'}->{'TOPIC_ID'};st=] . ($Pages - 1) * $iB::INFO->{'DISPLAY_MAX_POSTS'} . qq[' class='misc'>..$Pages </a>]; last; }
            $obj->{'.cur_topic'}->{'PAGES'} .= qq[<a href='$iB::INFO->{'BOARD_URL'}/ikonboard.$iB::INFO->{'CGI_EXT'}?s=$iB::SESSION;act=ST;f=$iB::IN{'f'};t=$obj->{'.cur_topic'}->{'TOPIC_ID'};st=$RealNo' class='misc'>$PageNo </a>];
            ++$i;
        }
        $obj->{'.cur_topic'}->{'PAGES'} .= qq[)</font>];
    }

    if ($obj->{'.cur_topic'}->{'MOVED_TO'}) {
        my ($forum, $topic) = split "&", $obj->{'.cur_topic'}->{'MOVED_TO'};
        $obj->{'.cur_topic'}->{'TOPIC_ID'}        = $topic;
        $obj->{'.cur_topic'}->{'FORUM_ID'}        = $forum;
        $obj->{'.cur_topic'}->{'TOPIC_VIEWS'}     = '--';
        $obj->{'.cur_topic'}->{'TOPIC_POSTS'}     = '--';
        $obj->{'.cur_topic'}->{'STARTER'}         = '--';
        $obj->{'.cur_topic'}->{'LAST_POSTER'}     = '--';
        $obj->{'.cur_topic'}->{'TOPIC_LAST_DATE'} = '--';
        $obj->{'.cur_topic'}->{'LAST_TEXT'}       = undef;
    }
    return $IN->{'PIN'} ? ForumView::Render_p_Row( $obj->{'.cur_topic'} ) : ForumView::RenderRow( $obj->{'.cur_topic'} );
}





sub Check_access ($) {
    my ($obj, $db) = @_;

    if ($obj->{'FORUM'}->{'FORUM_PROTECT'}) {
        if (exists $iB::COOKIES->{ $iB::INFO->{'COOKIE_ID'}.'iBForum' . $obj->{'FORUM'}->{'FORUM_ID'} }) {
            return if $iB::COOKIES->{ $iB::INFO->{'COOKIE_ID'}.'iBForum' . $obj->{'FORUM'}->{'FORUM_ID'} } eq $obj->{'FORUM'}->{'FORUM_PROTECT_T'};
        }
        $obj->Forum_login($db);
    }

    if ($obj->{'FORUM'}->{'FORUM_VIEW_THREADS'} ne '*') {
        unless (grep { $_ == $iB::MEMBER->{'MEMBER_GROUP'} } (split /,/,$obj->{'FORUM'}->{'FORUM_VIEW_THREADS'}) ) {
            $std->Error(     DB      => $db,
                             LEVEL   => '2',
                             MESSAGE =>'forum_no_access'
                       );
        }
    }
    return 0;
}



sub Forum_login {
    my ($obj, $db) = @_;
    $std->Error( DB      => $db,
                 LEVEL   => '5',
                 MESSAGE => 'no_guests') unless $iB::MEMBER->{'MEMBER_ID'};

    $print = ForumView::Forum_log_in($obj->{'FORUM'}->{'FORUM_ID'});

    $output->print_ikonboard( DB       => $db,
                              STD      => $std,
                              OUTPUT   => $print,
                              TITLE    => "iB::".$obj->{'FORUM'}->{'FORUM_NAME'},
                              NAV_ONE  => qq[<a href="$iB::INFO->{'BOARD_URL'}/ikonboard.$iB::INFO->{'CGI_EXT'}?s=$iB::SESSION;act=SF;f=$obj->{'FORUM'}->{'FORUM_ID'}" class='nav'>$obj->{'FORUM'}->{'FORUM_NAME'}</a>]
                            );
    return 1;
}

sub authenticate_user {
    my ($obj, $db) = @_;

    $std->Error( DB      => $db,
                 LEVEL   => 2,
                 MESSAGE => 'pass_blank'
               ) unless $iB::IN{'f_password'};


    $std->Error( DB      => $db,
                 LEVEL   => 2,
                 MESSAGE =>'wrong_pass'
               ) unless $iB::IN{'f_password'} eq $obj->{'FORUM'}->{'FORUM_PROTECT'};

    push @{$iB::SETCOOKIE},$iB::CGI->cookie( NAME  => $iB::INFO->{'COOKIE_ID'}.'iBForum'.$obj->{'FORUM'}->{'FORUM_ID'},
                                             VALUE => $iB::IN{'f_password'},
                                             PATH  => $iB::INFO->{'COOKIE_PATH'}
                                           );

    $output->redirect_screen( TEXT => "$Forum::lang->{'logged_in'}", URL => "?act=SF;f=$iB::IN{'f'}");

}


sub folder_icon ($) {
    my $obj = shift;
    return qq[$iB::INFO->{'IMAGES_URL'}/images/f_norm.gif]       unless $iB::MEMBER->{'MEMBER_ID'};
    return qq[$iB::INFO->{'IMAGES_URL'}/images/f_locked.gif]     if     $obj->{'.cur_topic'}->{'TOPIC_STATE'} eq 'closed';
    return qq[$iB::INFO->{'IMAGES_URL'}/images/f_poll.gif]       if     (($obj->{'.cur_topic'}->{'POLL_STATE'}) and ($iB::MEMBER->{'LAST_LOG_IN'} && ($obj->{'.cur_topic'}->{'LAST_VOTE'} > $iB::MEMBER->{'LAST_LOG_IN'})));
   #return qq[$iB::INFO->{'IMAGES_URL'}/images/f_poll_no_new.gif]if     $obj->{'.cur_topic'}->{'POLL_STATE'};
    return qq[$iB::INFO->{'IMAGES_URL'}/images/f_moved.gif]      if     $obj->{'.cur_topic'}->{'TOPIC_STATE'} eq 'moved';
    return qq[$iB::INFO->{'IMAGES_URL'}/images/f_hot_no_new.gif] if     (($obj->{'.cur_topic'}->{'TOPIC_POSTS'} + 1 >= $iB::INFO->{'HOT_TOPIC'}) and ($iB::MEMBER->{'LAST_LOG_IN'} && ($obj->{'.cur_topic'}->{'TOPIC_LAST_DATE'} < $iB::MEMBER->{'LAST_LOG_IN'})));
    return qq[$iB::INFO->{'IMAGES_URL'}/images/f_hot.gif]        if     $obj->{'.cur_topic'}->{'TOPIC_POSTS'} + 1 >= $iB::INFO->{'HOT_TOPIC'};
    return qq[$iB::INFO->{'IMAGES_URL'}/images/f_new.gif]        if     $iB::MEMBER->{'LAST_LOG_IN'} && ($obj->{'.cur_topic'}->{'TOPIC_LAST_DATE'} > $iB::MEMBER->{'LAST_LOG_IN'});
    return qq[$iB::INFO->{'IMAGES_URL'}/images/f_norm.gif];
}
        
sub get_last_date ($) {
    my $obj = shift;
    return $obj->{'.cur_topic'}->{'LAST_VOTE'} > $obj->{'.cur_topic'}->{'TOPIC_LAST_DATE'} ? $obj->is_vote() : $obj->is_post();
}

sub is_vote ($) {
    my $obj = shift;
    #$obj->{'.cur_topic'}->{'LAST_ICON'} = 'last_vote.gif';
    return $std->get_date( TIME => $obj->{'.cur_topic'}->{'LAST_VOTE'}, METHOD => 'LONG');
}

sub is_post ($) {
    my $obj = shift;
    #$obj->{'.cur_topic'}->{'LAST_ICON'} = 'last_post.gif';
    return $std->get_date( TIME => $obj->{'.cur_topic'}->{'TOPIC_LAST_DATE'}, METHOD => 'LONG');
}



#+------------------------------------------------------------------------------------------------------
#+------------------------------------------------------------------------------------------------------

1;
