package iCGI;


#+------------------------------------------------------------------------------------------------------
#| Ikonboard by Matthew Mecham [ v3.0 ]
#|
#| No parts of this script can be used outside Ikonboard without prior consent.
#| You must keep this header intact and all copyright links visable.
#| (c)2001 Ikonboard.com <http://www.ikonboard.com>
#|
#| Please Read the licence for more information.
#|
#| Simple CGI methods, see pod docs for more details
#+-----------------------------------------------------------------+

use strict;

use vars qw[$VERSION %GBL];

$VERSION = '0.09';

if ($ENV{'MOD_PERL'}) {
   $| = 1;
   require Apache;
}

sub init_globals {
  # Keep Mod Perl Happy
  
  # You can also set these up to how you see fit.
  
  # Escape HTML when decoding the form/GET data - make this 1

  $GBL{escape_html} = 0;

  # Post Max Data - default is 100k

  $GBL{post_max} = 1024 * 100;

  1; #Keep Mod Perl from complaining
}




&init_globals();



sub new {
  my $pkg = shift;
  my $obj = {};
  bless $obj, $pkg;
  $obj->_read_in();
  return $obj;
}




#------------------
# HTML Functions
#------------------

sub redirect {
    my $obj = shift;
    my %IN = ( URL => "", COOKIES => [], @_, );
    return unless $IN{'URL'};
    $IN{'URL'} =~ s!;!&!g;
    my $header = "Status: 302 Moved Temporarily\n";
    for (@{$IN{'COOKIES'}}) {
        $header .= $_;
    }
    ++$obj->{content_printed};
    return $header .= "Location: $IN{'URL'}\nContent-Type: text/html\n\n";
}

sub header {
   my $obj = shift;
   my %IN = ( COOKIES => [], @_, );
   my $header;
   for (@{$IN{'COOKIES'}}) {
      $header .= $_;
   }
   ++$obj->{content_printed};
   return $header .= "Content-Type: text/html\n\n";
}

sub end_html {
   my $obj = shift;
   return my $bottom = qq!</body></html>\n!;
}

sub start_html {
   my ($obj, $ptitle) = @_;
   return my $top = qq!<html>\n<head>\n<title>$ptitle</title>\n</head>\n<body>\n!;
}

#------------------
# Cookie Functions
#------------------

sub cookie {
  my $obj = shift;
  my %IN = (NAME=>"",VALUE=>"",EXPIRES=>"",PATH=>"",@_,);
  return $obj->_getcookies() if $IN{NAME} eq '';
  return $IN{VALUE} ne '' ? $obj->_setcookie(\%IN) : $obj->_getcookies($IN{NAME});
}


sub _setcookie {
    my ($obj, $IN) = @_;
    $IN->{PATH} = $IN->{PATH} ? $IN->{PATH} : '/';
    my $cookie = qq~Set-Cookie: $IN->{NAME}=$IN->{VALUE};~.qq~ path=$IN->{PATH}~;
    $IN->{EXPIRES} = $obj->expires($IN->{EXPIRES}) if $IN->{EXPIRES} ne '';
    $cookie .= qq~; expires=$IN->{EXPIRES}~ if $IN->{EXPIRES};
    return $cookie." \n";
    }
sub _getcookies {
    my ($obj, $name) = @_;
    my $rc = $ENV{HTTP_COOKIE} || $ENV{COOKIE};
    return unless $rc;
    local @_ = split("; ?",$rc);
    my %COOKIE = map { split("=") } @_;
    return $name ? $COOKIE{$name} : \%COOKIE;
}
sub expires {
    my ($obj,$time) = @_;
    my(@MON)=qw/Jan Feb Mar Apr May Jun Jul Aug Sep Oct Nov Dec/;
    my(@WDAY) = qw/Sun Mon Tue Wed Thu Fri Sat/;
    $time = $obj->calc_time($time);
    return $time unless $time =~ /^\d+$/;
    my $sc = '-';
    my($sec,$min,$hour,$mday,$mon,$year,$wday) = gmtime($time); $year += 1900;
    return sprintf("%s, %02d$sc%s$sc%04d %02d:%02d:%02d GMT",$WDAY[$wday],$mday,$MON[$mon],$year,$hour,$min,$sec);
    }
sub calc_time {
    my($obj,$time) = @_;
    my(%mult) = ('s'=>1,'m'=>60,'h'=>60*60,'d'=>60*60*24,'M'=>60*60*24*30,'y'=>60*60*24*365);
    my($offset);
    if (!$time || (lc($time) eq 'now')) { $offset = 0; }
    elsif ($time=~/^\d+/) { return $time; }
    elsif ($time=~/^([+-]?(?:\d+|\d*\.\d*))([mhdMy]?)/) { $offset = ($mult{$2} || 1)*$1; }
    else { return $time; }
    return (time+$offset);
    }


#------------------
# Return Parameters
#------------------


sub param {
   my ($obj,$pname) = @_;
   return $obj->_get_all() unless defined $pname;

   return unless defined($pname) && $obj->{$pname};
   return wantarray ? @{$obj->{$pname}} : $obj->{$pname}->[0];
}

#------------------
# Internal Functions
#------------------

sub _get_all {
   my $obj = shift;
   return () unless defined($obj) && $obj->{'parameters'};
   return () unless @{$obj->{'parameters'}};
   return @{$obj->{'parameters'}};
}


sub _read_in {
    my $obj = shift;
    return unless $ENV{'REQUEST_METHOD'}; 
    $ENV{'REQUEST_METHOD'} eq 'POST' ? $obj->_read_post() : $obj->_read_get();
}

sub _parse_params {
   my($obj,$line) = @_;
   return unless $line;
   my @p = map { split/[&;]/ } $line;
   for (@p) {
      @_ = split(/=/,$_,2);
      $_[0] = $obj->_decode($_[0]); $_[1] = $obj->_decode($_[1]);
      defined $_[1] ? push (@{$obj->{$_[0]}}, $_[1]) : push (@{$obj->{$_[0]}}, '');
                      push (@{$obj->{'parameters'}}, $_[0]) if $obj->{$_[0]};
   }
}


sub _read_post {
   my $obj = shift;
   my $buffer = undef;
   die "Error:413, Post Data too large" if $ENV{'CONTENT_LENGTH'} > $GBL{post_max};
   read(STDIN, $buffer, $ENV{'CONTENT_LENGTH'},0);
   $obj->_check($ENV{'CONTENT_TYPE'}) if defined $ENV{'CONTENT_TYPE'};
   $obj->_parse_params($buffer);
}

sub _read_get {
   my $obj = shift;
   my $buffer;
      $buffer = ($ENV{'MOD_PERL'}) ? Apache->request->args : $ENV{'QUERY_STRING'};
   $obj->_parse_params($buffer);
}



sub _check {
   my ($obj, $check) = @_;
   die "Not Supported yet" unless $check =~ m!^application/x-www-form-urlencoded$!oi
                                 || $check =~ m!^application/sgml-form-urlencoded$!oi;
}

sub _decode {
    my ($obj, $line) = @_;
    return unless defined $line;
    $line =~ s/\+/ /gos;
    $line =~ s/%([a-fA-F0-9][a-fA-F0-9])/pack("C", hex($1))/egos;
    return ($GBL{escape_html}) ? ($obj->escape_html($line)) : ($line);
}


sub escape_html {
  my ($obj, $tmp) = @_;
  $tmp =~ s!&!&amp;!g;
  $tmp =~ s!>!&gt;!g;
  $tmp =~ s!<!&lt;!g;
  return $tmp;
}


1;

__END__

#----------------------------------------------------------------------------

=pod

=head1 iCGI.pm

=head2 A lightweight alternative to the CGI.pm

=head2 Synopsis

  #!/usr/bin/perl -w

  use iCGI;

  my $q = new iCGI;

  my $action = param('action');

  my $Cookies = $q->cookie();
  my $PasswordCookie = $q->cookie(NAME=>'PassCookie');

  print $q->header();
  print $q->start_html('My iCGI test);

  print qq~Action is $action
           Password cookie: $PasswordCookie
           Other Cookies:
          ~;

  foreach (keys %$Cookies) { print $Cookies->{$_}, "\n" }

  # Set a cookie

  $q->cookie(NAME=>'action',VALUE=>$action,PATH=>'/cgi-bin/',EXPIRES=>'+1y');

  print $q->end_html();

=head1 Description

iCGI is a lightweight alternative to the CGI.pm perl module. The CGI module is great,
but it now weighs in at over 250k, whilst it is comprehensive, those of us who just
use it for printing a basic content line, using and saving cookies and parsing forms/GET
data - it's a little too heavy to drag around.

In use, iCGI is the same as using the CGI.pm, exept that cookies when 'got' altogether are a hash
reference. Getting a cookie by name will return it in a scalar context.

At the moment, you will have to use Object Orientated methods to use iCGI.pm

=head1 Author

Matt Mecham, author of Ikonboard (iBoard) <matt@ikonboard.com>

=head1 Bugs

Yep :)

=head1 TODO

Loads

=cut

#----------------------------------------------------------------------------


