package Online;
use strict;
#################################################################################
# Ikonboard v3 by Jarvis Entertainment Group, Inc.
#
# No parts of this script can be used outside Ikonboard without prior consent.
#
# More information available from <ib-license@jarvisgroup.net>
# (c)2001 Jarvis Entertainment Group, Inc.
# 
# http://www.ikonboard.com
#
# Please Read the license for more information
#+-----------------------------------------------------------------+
#
# Online: Display the online users.
#
#################################################################################

BEGIN {
    require 'Lib/FUNC.pm';
    require 'iTextparser.pm';
    require 'MemberTitles.pm';
}

my $std      = FUNC::STD->new();
my $mem      = FUNC::Member->new();
my $output   = FUNC::Output->new();
my $psr      = iTextparser->new();
my $Rank     = MemberTitles->new();
$Online::lang = $std->LoadLanguage('OnlineWords');

my $html = undef;
 

sub new {
    my $pkg = shift;
    my $obj = {};
    bless $obj, $pkg;
    return $obj;
}


#+------------------------------------------------------------------------------------------------------


sub list_all {
    my ($obj, $db) = @_;
  
    my $First   = $std->IsNumber($iB::IN{'st'}) || 0;
    my $perpage = 25;

    my $forums         = $db->query( TABLE     => 'forum_info',
                                     SORT_KEY  => 'FORUM_POSITION',
                                     COLUMNS   => ['FORUM_ID', 'FORUM_NAME', 'FORUM_PROTECT', 'FORUM_VIEW_THREADS'],
                                     SORT_BY   => 'A-Z',
                                     MATCH     => 'ALL'
                                   ) || die $db->{'error'};

    my $categories     = $db->query( TABLE     => 'categories',
                                     SORT_KEY  => 'CAT_POS',
                                     SORT_BY   => 'A-Z',
                                     WHERE     => 'CAT_STATE ne "0"',
                                     MATCH     => 'ALL',
                                   ) || die $db->{'error'};


    my $total_sessions = $db->query(  TABLE     => 'active_sessions',
                                      MATCH     => 'ALL',
                                      SORT_KEY  => 'RUNNING_TIME',
                                      SORT_BY   => 'Z-A',
                                      WHERE     => "RUNNING_TIME > (time - 1800)",
                                      RANGE     => $First." to ".($perpage + $First)
                                    );

    #XXX Build hash table index of the forums

    my %all_forums = map {
                           $_->{'FORUM_ID'} => { FORUM_NAME         => $_->{'FORUM_NAME'},
                                                 FORUM_VIEW_THREADS => $_->{'FORUM_VIEW_THREADS'},
                                                 FORUM_PROTECT      => $_->{'FORUM_PROTECT'}
                                               }
                         } @{$forums};

    #XXX Build hash table index of the categories

    my %all_cats   = map {
                           $_->{'CAT_ID'}   => { CAT_NAME         => $_->{'CAT_NAME'},
                                                 VIEW             => $_->{'VIEW'},
                                               }
                         } @{$categories};


    $html = OnlineView::Page_header();

    my $where = $Online::lang->{'WHERE'}; 

    for my $session (@{$total_sessions}) {
        my $line;
        if ($session->{'LOCATION'}) {
            my ($act, $q_string) = split (/\|&\|/, $session->{'LOCATION'});
            if ($act) {
                $line = exists $where->{ $act } ? $where->{ $act } : $Online::lang->{'board_index'}; 
            }
            my ($sub_act, $number);
            if ( $q_string =~ m{[&;\?](f|c)=(\d)[&;\|\Z]} ) {
                $sub_act = $1;
                $number  = $2;
                if ($act and $number and $sub_act) {
                    if ($sub_act eq 'f') {
                        $line .= $all_forums{$number}->{'FORUM_VIEW_THREADS'} eq '*'
                                 ? ' '.$all_forums{$number}->{'FORUM_NAME'}
                                 : (
                                     (grep { $_ == $iB::MEMBER->{'MEMBER_GROUP'} } (split (/,/, $all_forums{$number}->{'FORUM_VIEW_THREADS'})))
                                     ? (' '.$all_forums{$number}->{'FORUM_NAME'})
                                     : ('')
                                   );
                    } elsif
                       ($sub_act eq 'c') {
                        $line .= $all_cats{$number}->{'VIEW'} eq '*'
                                 ? ' '.$all_cats{$number}->{'CAT_NAME'}
                                 : (
                                     (grep { $_ == $iB::MEMBER->{'MEMBER_GROUP'} } (split (/,/, $all_cats{$number}->{'VIEW'})))
                                     ? (' '.$all_cats{$number}->{'CAT_NAME'})
                                     : ('')
                                   );
                    }
                }
                        
            } else {
                $line = $Online::lang->{'board_index'};
            }
        
        $session->{'WHERE_LINE'} = $line;

        } else {
            $line = $Online::lang->{'board_index'};
        }
            
        if ($session->{'MEMBER_NAME'}) {

            # XXX Remove Dupes (this occurs if a user is on a proxy, and their IP changes).

            next if exists $obj->{'seen_name'}->{ $session->{'MEMBER_NAME'} };
            $obj->{'seen_name'}->{ $session->{'MEMBER_NAME'} } = 1;
        }
        $html .= $obj->do_entry(  DB => $db, SESSION => $session);
    }

    $html .= OnlineView::Page_end();

    $output->print_ikonboard( DB         => $db,
                              STD        => $std,
                              OUTPUT     => $html,
                              JAVASCRIPT => 1,
                              TITLE      => "iB::".$Online::lang->{'page_title'},
                              NAV        => [ "$Online::lang->{'page_title'}" ]
                            );
}



#+------------------------------------------------------------------------------------------------------

sub do_entry  {
    my $obj = shift;
    my %IN  = ( DB => "", SESSION => "", @_, );
    my $session = $IN{'SESSION'};

    if ($session->{'MEMBER_NAME'} and $session->{'MEMBER_ID'}) {
        $session->{'MESSAGE_ICON'} = qq[<a href='$iB::INFO->{'BOARD_URL'}/ikonboard.$iB::INFO->{'CGI_EXT'}?s=$iB::SESSION;act=Msg;CODE=04;MID=$session->{'MEMBER_ID'}'><img src="$iB::INFO->{'IMAGES_URL'}/images/pb_message.gif" border='0'></a>&nbsp;];
        $session->{'PROFILE_ICON'} = qq!<a href="$iB::INFO->{'BOARD_URL'}/ikonboard.$iB::INFO->{'CGI_EXT'}?s=$iB::SESSION;act=Profile;CODE=03;MID=$session->{'MEMBER_ID'}"><img src="$iB::INFO->{'IMAGES_URL'}/images/pb_profile.gif" border='0'></a>&nbsp;!;
    }
    else {
        $session->{'MEMBER_NAME'}  = $Online::lang->{'guest'};
        $session->{'MESSAGE_ICON'} = $Online::lang->{'n_a'};
        $session->{'PROFILE_ICON'} = $Online::lang->{'n_a'};
    }
    $session->{'RUNNING_TIME'} = $std->get_date( TIME => $session->{'RUNNING_TIME'}, METHOD => 'LONG' );

    return OnlineView::show_row($session);
}



sub Process {
    my ($obj, $db) = @_;
    my $CodeNo = $iB::IN{'CODE'};
    return unless $iB::INFO->{'ALLOW_ONLINE_LIST'};
    #+-----------------------------------------------------------------------------------
    require $iB::SKIN->{'DIR'} . '/OnlineView.pm' or die $!;
    #+-----------------------------------------------------------------------------------
    my %Mode = ( 'listall'     => \&list_all,
                 'forum'       => \&list_forum,
               );
    $Mode{$CodeNo} ? $Mode{$CodeNo}->($obj,$db) : OnlineError();
} 

sub OnlineError { }

1;

__END__
