package Register;
use strict;
#################################################################################
# Ikonboard v3 by Jarvis Entertainment Group, Inc.
#
# No parts of this script can be used outside Ikonboard without prior consent.
#
# More information available from <ib-license@jarvisgroup.net>
# (c)2001 Jarvis Entertainment Group, Inc.
# 
# http://www.ikonboard.com
#
# Please Read the license for more information
#+-----------------------------------------------------------------+
#
# Register: Registration Fucntions.
#
#################################################################################

BEGIN {
   require 'Lib/FUNC.pm';
}

my $mail        = FUNC::Mailer->new();
my $mem         = FUNC::Member->new();
my $std         = FUNC::STD->new();
my $output      = FUNC::Output->new();
$Register::lang = $std->LoadLanguage('RegisterWords');


sub new {
  my $pkg = shift;
  my $obj = {};
  bless $obj, $pkg;
  return $obj;
}



sub CreateAccount {
    my ($obj, $db) = @_;
    
    $std->Error(DB=>$db,LEVEL=>'1',MESSAGE=>'no_username')     unless $iB::IN{'UserName'};
    $std->Error(DB=>$db,LEVEL=>'1',MESSAGE=>'username_short')  unless length($iB::IN{'UserName'}) >= 3;
    $std->Error(DB=>$db,LEVEL=>'1',MESSAGE=>'username_long')   unless length($iB::IN{'UserName'}) <= 32;
    $std->Error(DB=>$db,LEVEL=>'1',MESSAGE=>'pass_blank')      unless $iB::IN{'PassWord'};
    $std->Error(DB=>$db,LEVEL=>'1',MESSAGE=>'pass_blank')      unless $iB::IN{'PassWord_Check'};
    $std->Error(DB=>$db,LEVEL=>'1',MESSAGE=>'pass_no_match')   unless $iB::IN{'PassWord_Check'} eq $iB::IN{'PassWord'};
    $std->Error(DB=>$db,LEVEL=>'1',MESSAGE=>'pass_too_short')  unless length($iB::IN{'PassWord'}) >= 3;
    $std->Error(DB=>$db,LEVEL=>'1',MESSAGE=>'pass_too_long')   unless length($iB::IN{'PassWord'}) <= 32;
    $std->Error(DB=>$db,LEVEL=>'1',MESSAGE=>'invalid_email')   unless $iB::IN{'EmailAddress'};

    my $name_check  = $mem->CheckName( DB =>$db, NAME =>$iB::IN{'UserName'} );
    $std->Error(DB=>$db,LEVEL=>'1',MESSAGE=>"user_exists")   if $name_check->{'MEMBER_NAME'};
    
    my $validate_e  = $std->CheckEmail($iB::IN{'EmailAddress'});
    $std->Error(DB=>$db,LEVEL=>'2',MESSAGE=>'invalid_email') if $validate_e != 1;


    unless ($iB::INFO->{'ALLOW_MULT_EMAIL'}) {
        my $email_check = $mem->Check_Mem_Email( DB =>$db, EMAIL =>$iB::IN{'EmailAddress'} );
        $std->Error( DB      => $db,
                     LEVEL   => 1,
                     MESSAGE =>'email_exists'
                   )  if $email_check->{'MEMBER_EMAIL'};
    }
    

    my %Member;
    $Member{'MEMBER_NAME'}     = $iB::IN{'UserName'};
    $Member{'MEMBER_PASSWORD'} = $iB::IN{'PassWord'};
    $Member{'MEMBER_GROUP'}    = $iB::INFO->{'VALIDATE_REGISTER'} ? $iB::INFO->{'AUTHORISE_GROUP'} : $iB::INFO->{'MEMBER_GROUP'};
    $Member{'MEMBER_POSTS'}    = 0;
    $Member{'MEMBER_EMAIL'}    = $iB::IN{'EmailAddress'};
    $Member{'MEMBER_AVATAR'}   = 'noavatar';
    $Member{'MEMBER_LEVEL'}    = 1;
    $Member{'MEMBER_JOINED'}   = time;
    $Member{'MEMBER_IP'}       = $iB::IN{'IP_ADDRESS'};
    $Member{'TIME_ADJUST'}     = 0;
    $Member{'VIEW_SIGS'}       = 1;
    $Member{'VIEW_IMG'}        = 1;
    $Member{'VIEW_AVS'}        = 1;
    $Member{'ALLOW_POST'}      = 1;
    my $member_id = $mem->AddMember(DB => $db, STD=> $std, MEMBER=>\%Member);

    $obj->clean_registrations($db);

    if ($iB::INFO->{'VALIDATE_REGISTER'}) {
        my $unique_id = $mail->my_gen_id();
        my $time      = time;


        my $new_id = $db->insert( TABLE   => 'authorisation',
                                  VALUES  => {  UNIQUE_CODE   =>  $unique_id,
                                                DATE_ENTERED  =>  $time,
                                                MEMBER_ID     =>  $member_id,
                                                MEMBER_NAME   =>  $Member{'MEMBER_NAME'},
                                                THIS_IP       =>  $iB::IN{'IP_ADDRESS'},
                                                MEMBER_EMAIL  =>  $iB::IN{'EmailAddress'},
                                                WHERE         =>  'register',
                                              },
                                );

        my $message = $mail->parse_template( ID     => 'REG',
                                             DB     => $db,
                                             VALUES => { THE_LINK    =>  "$iB::INFO->{'BOARD_URL'}/ikonboard.$iB::INFO->{'CGI_EXT'}?act=Reg&CODE=03&SID=$unique_id",
                                                         MEMBER_NAME =>  $Member{'MEMBER_NAME'},
                                                         PASSWORD    =>  $iB::IN{'PassWord'},
                                                         UNTIL       =>  $iB::INFO->{'AUTHORISE_PRUNE'}
                                                       }
                                            );

        $mail->Send( TO      => $iB::IN{'EmailAddress'},
                     FROM    => '',
                     SUBJECT => "Registration at $iB::INFO->{'BOARDNAME'}",
                     MESSAGE => $message
                  );

        my $print = RegisterView::show_authorise(\%Member);

        $output->print_ikonboard( DB      => $db,
                                  STD     => $std,
                                  TITLE   => "iB::"."Registration Succesful",
                                  NAV_ONE => "Registration",
                                  OUTPUT  => $print,
                                );

    } else {

        my $stats = $db->select( TABLE => 'board_statistics',KEY => 'MAIN');
        $stats->{'TOTAL_MEMBERS'}++;
        $stats->{'LAST_REG_MEMBER_N'}  = $Member{'MEMBER_NAME'};
        $stats->{'LAST_REG_MEMBER_ID'} = $member_id;

        $db->update( TABLE  => 'board_statistics',
                     KEY    => 'MAIN',
                     VALUES => $stats
                   );

        my $time = $std->get_date( TIME => time, METHOD => 'LONG');

        if ($iB::INFO->{'USER_NOTIFY'}) {

            my $message = $mail->parse_template( ID     => 'USER_NOTIFY',
                                                 DB     => $db,
                                                 VALUES => { 
                                                             MEMBER_NAME =>  $Member{'MEMBER_NAME'},
                                                             DATE        =>  $time,
                                                           }
                                               );

            $mail->Send( TO      => $iB::INFO->{'ADMIN_EMAIL_IN'},
                         FROM    => '',
                         SUBJECT => "New Registration at $iB::INFO->{'BOARDNAME'}",
                         MESSAGE => $message
                      );
        }

        my $text = $iB::INFO->{'SHOW_BOARD_RULES'} ? 'Your account has been activated! Proceeding to the board rules'
                                                   : 'Your account has been activated! Proceeding to log in';

        my $url  = $iB::INFO->{'SHOW_BOARD_RULES'} ? 'act=Reg;CODE=04' : 'act=Login;CODE=00';


        $output->redirect_screen( TEXT      => $text,
                                  URL       => $url
                                );
    }
}


sub clean_registrations {
    my ($obj, $db) = @_;

    my $t_q = time - $iB::INFO{'AUTHORISE_PRUNE'} * 60 * 60 * 24;

    my $old_reg = $db->query( TABLE   => 'authorisation',
                              WHERE   => qq[DATE_ENTERED < "$t_q"],
                              COLUMNS => ['ID', 'MEMBER_ID', 'MEMBER_NAME', 'MEMBER_EMAIL', 'WHERE'],
                            );

    return unless scalar @{$old_reg} > 0;

    for my $i (@{$old_reg}) {
        if ($i->{'WHERE'} eq 'register') {
            $db->delete( TABLE  => 'member_profiles',
                         ID     => $i->{'MEMBER_ID'},
                         KEY    => $i->{'MEMBER_ID'}
                       );
        }

        #Delete from Name index

        $db->update_index(  TABLE     => 'member_profiles',
                            INDEX_KEY => 'MEMBER_NAME',
                            R_KEY     => $i->{'MEMBER_NAME'},
                            REMOVE    => 1
                         );

        #Delete from Email index

        $db->update_index(  TABLE     => 'member_profiles',
                            INDEX_KEY => 'MEMBER_EMAIL',
                            R_KEY     => $i->{'MEMBER_EMAIL'},
                            REMOVE    => 1
                         );

        $db->delete( TABLE  => 'authorisation',
                     KEY    => $i->{'ID'},
                   );
    }
}


sub validate_user {
    my ($obj, $db) = @_;


    $std->Error( DB      => $db,
                 LEVEL   =>'1',
                 MESSAGE =>'data_incorrect'
               ) unless $iB::IN{'SID'} =~ /[\d\w]/;


    my $time = time - ($iB::INFO->{'AUTHORISE_PRUNE'} * 60 * 60 * 24);

    my $db_entry = $db->query( TABLE   => 'authorisation',
                               MATCH   => 'ONE',
                               WHERE   => qq[WHERE eq "register" and UNIQUE_CODE eq "$iB::IN{'SID'}" and DATE_ENTERED > "$time"],
                             );          

    $std->Error(DB=>$db,LEVEL=>'1', MESSAGE=>'request_passed') unless $db_entry->{'MEMBER_ID'};

    my $member = $db->select( TABLE    => 'member_profiles',
                              KEY      => $db_entry->{'MEMBER_ID'},
                              ID       => $db_entry->{'MEMBER_ID'},
                            );

    $std->Error(DB=>$db,LEVEL=>'1', MESSAGE=>'request_error') unless $member->{'MEMBER_ID'};

    $member->{'MEMBER_GROUP'} = $iB::INFO->{'MEMBER_GROUP'};

    $db->update(              TABLE    => 'member_profiles',
                              KEY      => $db_entry->{'MEMBER_ID'},
                              ID       => $db_entry->{'MEMBER_ID'},
                              VALUES   => $member
               );


    $db->delete(             TABLE     => 'authorisation',
                             KEY       => $db_entry->{'ID'},
               );

    my $stats = $db->select( TABLE     => 'board_statistics',
                             KEY       => 'MAIN'
                           );

    $stats->{'TOTAL_MEMBERS'}++;
    $stats->{'LAST_REG_MEMBER_N'}  = $db_entry->{'MEMBER_NAME'};
    $stats->{'LAST_REG_MEMBER_ID'} = $db_entry->{'MEMBER_ID'};

    $db->update(            TABLE  => 'board_statistics',
                            KEY    => 'MAIN',
                            VALUES => $stats
               );

    if ($iB::INFO->{'USER_NOTIFY'}) {

        my $time = $std->get_date( TIME => time, METHOD => 'LONG');

        my $message = $mail->parse_template( ID     => 'USER_NOTIFY',
                                             DB     => $db,
                                             VALUES => { 
                                                         MEMBER_NAME =>  $db_entry->{'MEMBER_NAME'},
                                                         DATE        =>  $time,
                                                        }
                                            );

        $mail->Send( TO      => $iB::INFO->{'ADMIN_EMAIL_IN'},
                     FROM    => '',
                     SUBJECT => "New Registration at $iB::INFO->{'BOARDNAME'}",
                     MESSAGE => $message
                   );
    }

    my $text = $iB::INFO->{'SHOW_BOARD_RULES'} ? 'Your account has been activated! Proceeding to the board rules'
                                               : 'Your account has been activated! Proceeding to log in';

    my $url  = $iB::INFO->{'SHOW_BOARD_RULES'} ? 'act=Reg;CODE=04' : 'act=Login;CODE=00';


    $output->redirect_screen( TEXT      => $text,
                              URL       => $url
                            );
}




sub ShowForm {
    my ($obj, $db) = @_;
    my $text = $Register::lang->{'std_text'};
    $text .= "<br>". $Register::lang->{'email_validate_text'} if $iB::INFO->{'VALIDATE_REGISTER'};
    $output->print_ikonboard(
                              DB      => $db,
                              STD     => $std,
                              OUTPUT  => &RegisterView::ShowForm($text),
                              TITLE   => $Register::lang->{'registration_form'},
                              NAV_ONE => $Register::lang->{'registration_form'}
                            );
}



sub show_board_rules {
    my ($obj, $db) = @_;
    my $rules = $db->select(  TABLE  => 'forum_rules',
                              KEY    => '00',
                           );
    return unless $rules;

    $rules->{'RULES_TEXT'} = $std->TextTidy($rules->{'RULES_TEXT'});

    $output->print_ikonboard(
                              DB      => $db,
                              STD     => $std,
                              OUTPUT  => &RegisterView::show_rules($rules),
                              TITLE   => $Register::lang->{'board_rules'},
                              NAV_ONE => $Register::lang->{'board_rules'}
                           );
}




sub ShowAgreement  {
    my ($obj, $db) = @_;
    my $print;
    $print = RegisterView::AgreementHeader();
    local $/ = undef;
    open FH, $iB::INFO->{'HTML_DIR'} . $iB::SKIN->{'FULL_DIR'}  . '/Templates/register.html' or die $!;
    while (<FH>) { $print .= $std->TextTidy($_) }
    close FH or die $!;
    $print .= RegisterView::AgreementFooter();
    $output->print_ikonboard(
                              DB      => $db,
                              STD     => $std,
                              OUTPUT  => $print,
                              TITLE   => $Register::lang->{'registration_agree'},
                              NAV_ONE => $Register::lang->{'registration_agree'}
                            );
}




sub Process {
    my ($obj, $db) = @_;
    my $CodeNo = $std->CheckCodeNo($iB::IN{'CODE'});
    $std->Error(DB => $db, LEVEL=>'1', MESSAGE=>'no_register') unless $iB::INFO->{'ALLOW_REGISTER'};
    require $iB::SKIN->{'DIR'} . '/RegisterView.pm' or die $!;
    my %Mode = ( '02'     => \&CreateAccount,
                 '01'     => \&ShowForm,
                 '00'     => \&ShowAgreement,
                 '03'     => \&validate_user,
                 '04'     => \&show_board_rules,
               );
    $Mode{$CodeNo} ? $Mode{$CodeNo}->($obj, $db) : RegisterError($obj, $db);   
} 

sub RegisterError  { my ($obj, $db) = @_; $std->Error(DB=>$db,LEVEL=>'1',MESSAGE=>'no_action'); }

1;


__END__
