package Sessions;
use strict;
#+------------------------------------------------------------------------------------------------------
#| Ikonboard by Matthew Mecham [ v3.0 ]
#|
#| No parts of this script can be used outside Ikonboard without prior consent.
#| You must keep this header intact and all copyright links visable.
#| (c)2001 Ikonboard.com <http://www.ikonboard.com>
#|
#| Please Read the licence for more information.
#+------------------------------------------------------------------------------------------------------

BEGIN {
    require 'Lib/FUNC.pm';
}
my $mem    = FUNC::Member->new();
my $std    = FUNC::STD->new();


#+------------------------------------------------------------------------------------------------------

sub new {
  my $pkg = shift;
  my $obj = { 'total_guests'  => 0,
              'total_members' => 0,
              'active_forums' => {},
              'member_names'  => [],
              'anon_members'  => 0,
              'member_added'  => 0,
              'seen_name'     => {},
            }; 
  bless $obj, $pkg;
  return $obj;
}

#+------------------------------------------------------------------------------------------------------



sub active_users {
    my ($obj, $db) = @_;
   
    my $total_sessions = $db->query(  TABLE     => 'active_sessions',
                                      MATCH     => 'ALL',
                                      SORT_KEY  => 'RUNNING_TIME',
                                      SORT_BY   => 'Z-A',
                                      WHERE     => "RUNNING_TIME > (time - 1800)",
                                    );

    for my $session (@{$total_sessions}) {

        if ($session->{'MEMBER_NAME'}) {

            # XXX Remove Dupes (this occurs if a user is on a proxy, and their IP changes).

            next if exists $obj->{'seen_name'}->{ $session->{'MEMBER_NAME'} };
            $obj->{'seen_name'}->{ $session->{'MEMBER_NAME'} } = 1;

            $session->{'LOG_IN_TYPE'} ? $obj->{'anon_members'}++
                                      : push @{$obj->{'member_names'}}, { NAME => $session->{'MEMBER_NAME'}, ID => $session->{'MEMBER_ID'} };
        }
        else {
            $obj->{'total_guests'}++;
        }
        
        if ($session->{'LOCATION'}) {
            my ($act, $q_string) = split (/\|&\|/, $session->{'LOCATION'});
            if ( $q_string =~ m{[&;\?]f=(\d)[&;|\Z]} ) {
                $obj->{'active_forums'}->{$1}++;
            }
        }

    }

    $obj->{'total_members'} = scalar @{$obj->{'member_names'}} || 0;
    
    return { FORUMS   => $obj->{'active_forums'},
             MEMBERS  => $obj->{'total_members'},
             GUESTS   => $obj->{'total_guests'},
             NAMES    => $obj->{'member_names'},
             ANON     => $obj->{'anon_members'}
           };

}



sub authenticate {

    my ($obj, $db) = @_;

    $ENV{'HTTP_USER_AGENT'} =~ s!\n!!;

    #XXX Are they banned?

    for my $ip (split /\|&\|/,$iB::INFO->{'IP_FILTER'}) {
        $ip =~ s!\*!\(\.\+\?\)!g;
        $std->Error( DB       => $db,
                     LEVEL    => 5,
                     MESSAGE  => 'you_are_banned'
                   ) if $iB::IN{'IP_ADDRESS'} =~ m#^$ip+$#;
    }
        

    my ($this_member, $in_member, $in_password, $method, $this_session, $member_name, $sess_id, $last_post);

    delete $iB::COOKIES->{$iB::INFO->{'COOKIE_ID'}.'iBSessionID'} if $iB::COOKIES->{$iB::INFO->{'COOKIE_ID'}.'iBSessionID'} eq '-';
    delete $iB::COOKIES->{$iB::INFO->{'COOKIE_ID'}.'iBMemberID'}  if $iB::COOKIES->{$iB::INFO->{'COOKIE_ID'}.'iBMemberID'}  eq '-';
    delete $iB::COOKIES->{$iB::INFO->{'COOKIE_ID'}.'iBPassWord'}  if $iB::COOKIES->{$iB::INFO->{'COOKIE_ID'}.'iBPassWord'}  eq '-';

    my $session_cookie = $iB::COOKIES->{$iB::INFO->{'COOKIE_ID'}.'iBSessionID'};

    $std->Error( DB       => $db,
                 LEVEL    => 5,
                 MESSAGE  => 'poss_hack'
               ) if $session_cookie && $session_cookie !~ /\A[\d\w\S]+\Z/;
  

	$std->Error( DB      => $db,
                 LEVEL   => 5,
                 MESSAGE => 'poss_hack'
               ) if $ENV{'HTTP_USER_AGENT'} =~ /\Ateleport/i;

    $std->Error( DB      => $db,
                 LEVEL   => 5,
                 MESSAGE => 'poss_hack'
               ) unless $ENV{'HTTP_USER_AGENT'};

    
    if ($iB::IN{'UserName'} ne '' and $iB::IN{'PassWord'} ne '') {
        $iB::SESSION = $session_cookie || $iB::IN{'s'} || 0;
        $std->Error( DB      => $db, 
                     LEVEL   => 5,
                     MESSAGE => 'pass_too_long'
                   ) if length($iB::IN{'PassWord'}) > 32;

        $std->Error( DB      => $db,
                     LEVEL   => 5,
                     MESSAGE => 'username_long'
                   ) if length($iB::IN{'UserName'}) > 32;
        $in_member   = $iB::IN{'UserName'};
        $in_password = $mem->Crypt($iB::IN{'UserName'}, $iB::IN{'PassWord'});
        $method      = 'by name';
        goto AUTHENTICATE;
    } elsif
        ($session_cookie) {
            $this_session = $obj->get_session( DB=> $db, ID => $session_cookie);
        goto CHECK;
    } elsif
        ($iB::IN{'s'}) {
            $this_session = $obj->get_session( DB=> $db, ID => $iB::IN{'s'});
        goto CHECK;
    }

CHECK:

    $iB::SESSION = $this_session->{'ID'}                 || undef;
    $in_member   = $this_session->{'MEMBER_ID'}          || $iB::COOKIES->{$iB::INFO->{'COOKIE_ID'}.'iBMemberID'} || undef;
    $in_password = $this_session->{'MEMBER_PASSWORD'}    || $iB::COOKIES->{$iB::INFO->{'COOKIE_ID'}.'iBPassWord'} || undef;
    $member_name = $this_session->{'MEMBER_NAME'}        || undef;
    $method      = ($in_member and $in_password) ? 'by id' : undef;

AUTHENTICATE:

    if ($in_member and $in_password) {
        $this_member = $mem->LoadMember( DB => $db, KEY => $in_member, METHOD => $method );
        unless ( $this_member->{'MEMBER_ID'} ) {
            $obj->my_bash_cookies();
            $iB::IN{'AD'} ? $obj->invalid_admin($db) : $std->Error( LEVEL => 2, MESSAGE => 'invalid_login');
        }
        unless ($in_password eq $this_member->{'MEMBER_PASSWORD'}) {
            $obj->my_bash_cookies();
            $iB::IN{'AD'} ? $obj->invalid_admin($db) : $std->Error( LEVEL => 2, MESSAGE => 'invalid_login');
        }

        if ($iB::IN{'CookieDate'}) {
            push @{$iB::COOKIES_OUT}, $iB::CGI->cookie( NAME => $iB::INFO->{'COOKIE_ID'}.'iBPassWord', VALUE => $this_member->{'MEMBER_PASSWORD'}, EXPIRES => '+30d', PATH => $iB::INFO->{'COOKIE_PATH'} );
            push @{$iB::COOKIES_OUT}, $iB::CGI->cookie( NAME => $iB::INFO->{'COOKIE_ID'}.'iBMemberID', VALUE => $this_member->{'MEMBER_ID'},       EXPIRES => '+30d', PATH => $iB::INFO->{'COOKIE_PATH'} );
        }

        $iB::SESSION ?  $db->update( TABLE  => 'active_sessions',
                                     KEY    => $iB::SESSION,
                                     VALUES => { 
                                                 MEMBER_NAME      =>  $this_member->{'MEMBER_NAME'},
                                                 MEMBER_PASSWORD  =>  $this_member->{'MEMBER_PASSWORD'},
                                                 MEMBER_ID        =>  $this_member->{'MEMBER_ID'},
                                                 THIS_IP          =>  $iB::IN{'IP_ADDRESS'},
                                                 USER_AGENT       =>  $ENV{'HTTP_USER_AGENT'},
                                                 RUNNING_TIME     =>  time,
                                                 MEMBER_LOGSTATE  =>  1,
                                                 LOCATION         =>  $iB::IN{'act'}."|&|".$ENV{'QUERY_STRING'},
                                                }
                                    )
            
                     :   $obj->create_session( DB => $db, MEMBER => $this_member, DELETE => 1);
            
       
    } else {

        $iB::SESSION ?  $db->update( TABLE  => 'active_sessions',
                                     KEY    => $iB::SESSION,
                                     VALUES => { 
                                                 MEMBER_NAME      =>  "",
                                                 MEMBER_PASSWORD  =>  "",
                                                 MEMBER_ID        =>  "",
                                                 THIS_IP          =>  $iB::IN{'IP_ADDRESS'},
                                                 USER_AGENT       =>  $ENV{'HTTP_USER_AGENT'},
                                                 RUNNING_TIME     =>  time,
                                                 MEMBER_LOGSTATE  =>  1,
                                                 LOCATION         =>  $iB::IN{'act'}."|&|".$ENV{'QUERY_STRING'},
                                               }
                                   )
         
                    :   $obj->create_session( DB => $db, MEMBER => undef, DELETE => 1);
         
    }

    push @{$iB::COOKIES_OUT}, $iB::CGI->cookie( NAME => $iB::INFO->{'COOKIE_ID'}.'iBSessionID', VALUE => $iB::SESSION, EXPIRES => '+1d', PATH => $iB::INFO->{'COOKIE_PATH'});

    $this_member = $mem->SetUpGuest() unless $this_member->{'MEMBER_ID'};

    $iB::MEMBER_GROUP = $db->select( TABLE  => 'mem_groups',
                                     KEY    => $this_member->{'MEMBER_GROUP'},
                                   );

    unless ($iB::MEMBER_GROUP->{'VIEW_BOARD'} or $iB::IN{'act'} eq 'Login' or $iB::IN{'act'} eq 'LostPass') {
        $std->Error( DB => $db, LEVEL => 1, MESSAGE => 'no_view_board');
    }

    #X Is their email addy banned?

    for my $em (split /\|&\|/,$iB::INFO->{'EMAIL_FILTER'}) {
        $em =~ s!\*!\(\.\+\?\)!g;
        $std->Error( DB       => $db,
                     LEVEL    => 5,
                     MESSAGE  => 'you_are_banned'
                   ) if $this_member->{'MEMBER_EMAIL'} =~ m#^$em+$#;
    }

    return $this_member;

}


sub invalid_admin {
    my ($obj, $db) = @_;

    my @log;

    if (-e $iB::INFO->{'DB_DIR'}."Temp/log-$iB::IN{'IP_ADDRESS'}.cgi") {
        open LOG, "<".$iB::INFO->{'DB_DIR'}."Temp/log-$iB::IN{'IP_ADDRESS'}.cgi" or die $!;
        @log = <LOG>;
        close LOG or die $!;
    
        if (scalar (@log) > 5) {
            $std->Error( DB        => $db,
                         LEVEL     => 1,
                         MESSAGE   => 'too_many_logins'
                         );
        }
    }

    open LOG, ">>".$iB::INFO->{'DB_DIR'}."Temp/log-$iB::IN{'IP_ADDRESS'}.cgi" or die $!;
    print LOG time."\n";
    close LOG or die $!;

    my $num = 5 - (scalar @log + 1);
    
    $std->Error( DB      => $db,
                 STD     => $std,
                 MESSAGE => 'invalid_login'
               );
    
}



sub get_session {
    my $obj = shift;

    $ENV{'HTTP_USER_AGENT'} =~ s!\n!!;

    my $IN  = { DB     => "",
                ID     => "",
                @_,
              };

    my $session = $IN->{'DB'}->select( TABLE => 'active_sessions', KEY => $IN->{'ID'} );

    return {} unless $session->{'ID'};
    
    if ($session->{'MEMBER_ID'}) {

        if ($iB::IN{'IP_ADDRESS'} ne $session->{'THIS_IP'}) {
            return {};
        }
       
        if ($iB::INFO->{'CHECK_USER_AGENT'}) {
            return {} unless $ENV{'HTTP_USER_AGENT'} eq $session->{'USER_AGENT'};
        }
    }
    return $session;
}




sub create_session {
    my $obj = shift;

    $ENV{'HTTP_USER_AGENT'} =~ s!\n!!;

    my $IN  = { DB     => "",
                MEMBER => "",
                DELETE => "",
                @_,
              };

    my $db         = $IN->{'DB'};
    my $member     = $IN->{'MEMBER'};
    $iB::SESSION   = $obj->my_gen_id();

    my $logstate   = $member->{'MEMBER_ID'} ? 1 : 0;

    $obj->clean_sessions( DB => $db, DELETE => $IN->{'DELETE'});

    $db->insert( TABLE   => 'active_sessions',
                 VALUES  =>  { ID               =>  $iB::SESSION,
                               MEMBER_NAME      =>  $member->{'MEMBER_NAME'},
                               MEMBER_PASSWORD  =>  $member->{'MEMBER_PASSWORD'},
                               MEMBER_ID        =>  $member->{'MEMBER_ID'},
                               THIS_IP          =>  $iB::IN{'IP_ADDRESS'},
                               LAST_LOG_IN      =>  time,
                               USER_AGENT       =>  $ENV{'HTTP_USER_AGENT'},
                               RUNNING_TIME     =>  time,
                               MEMBER_LOGSTATE  =>  $logstate,
                               LOCATION         =>  $iB::IN{'act'}."|&|".$ENV{'QUERY_STRING'},
                               LOG_IN_TYPE      =>  $iB::IN{'Privacy'}
                             }
                );

    $member->{'LAST_LOG_IN'} = time;
    $mem->UpdateMember( DB => $db, MEMBER=> $member) if $member->{'MEMBER_ID'};
    
}


sub clean_sessions {
    my $obj = shift;
    my $IN  = { DB => "", DELETE => "", @_, };

    my $db = $IN->{'DB'};

    $IN->{'DELETE'} = " or THIS_IP eq '$iB::IN{'IP_ADDRESS'}'" if $IN->{'DELETE'} == 1;

    my $delete_keys = $db->query( TABLE    => 'active_sessions',
                                  COLUMNS  => ['RUNNING_TIME', 'ID', 'THIS_IP'],
                                  WHERE    => "RUNNING_TIME < (time - $iB::INFO->{'SESSION_EXPIRATION'})$IN->{'DELETE'}",
                                  SORT_KEY => 'RUNNING_TIME',
                                );

    my @delete_ids = map { $_->{'ID'} } @{ $delete_keys };

    $db->delete( TABLE  => 'active_sessions',
                 KEY    => \@delete_ids
               );
    return 1;
}


sub my_gen_id {
    my $obj = shift;
    srand($$|time);
    my $session = int(rand(60000000));
    return unpack("H*", pack("Nnn", time, $$, $session));

}



sub my_bash_cookies {
    my $obj = shift;
    push @{$iB::SETCOOKIE},$iB::CGI->cookie( NAME => $iB::INFO->{'COOKIE_ID'}.'iBSessionID', VALUE => '-', EXPIRES=>'-1d', PATH => $iB::INFO->{'COOKIE_PATH'} );
    push @{$iB::SETCOOKIE},$iB::CGI->cookie( NAME => $iB::INFO->{'COOKIE_ID'}.'iBMemberID',  VALUE => '-', EXPIRES=>'-1d', PATH => $iB::INFO->{'COOKIE_PATH'} );
    push @{$iB::SETCOOKIE},$iB::CGI->cookie( NAME => $iB::INFO->{'COOKIE_ID'}.'iBPassWord',  VALUE => '-', EXPIRES=>'-1d', PATH => $iB::INFO->{'COOKIE_PATH'} );
}




1;

__END__
