package Topic;
use strict;
#################################################################################
# Ikonboard v3 by Jarvis Entertainment Group, Inc.
#
# No parts of this script can be used outside Ikonboard without prior consent.
#
# More information available from <ib-license@jarvisgroup.net>
# (c)2001 Jarvis Entertainment Group, Inc.
# 
# http://www.ikonboard.com
#
# Please Read the license for more information
#+-----------------------------------------------------------------+
#
# TOPIC: Display the topic.
#
#################################################################################

BEGIN {
    require 'Lib/FUNC.pm';
    require 'iTextparser.pm';
    require 'iPoll.pm';
}

my $std      = FUNC::STD->new();
my $mem      = FUNC::Member->new();
my $output   = FUNC::Output->new();
my $poll     = iPoll->new();
my $psr      = iTextparser->new();
$Topic::lang = $std->LoadLanguage('TopicWords');
 

sub new {
    my $pkg = shift;
    my $obj = {};
    bless $obj, $pkg;
    return $obj;
}


#+------------------------------------------------------------------------------------------------------


sub ShowTopic {
    my ($obj, $db) = @_;
    
    return unless ((defined $iB::IN{'t'}) and (defined $iB::IN{'f'}));

    my $First = $std->IsNumber($iB::IN{'st'}) || 0;

    require $iB::SKIN->{'DIR'} . '/TopicView.pm' or die $!;
    $iB::INFO->{'AVATAR_URL'} = $iB::INFO->{'IMAGES_URL'};

    $obj->{'.forum_id'} = $std->IsNumber($iB::IN{'f'}) || 0;
    $obj->{'.topic_id'} = $std->IsNumber($iB::IN{'t'}) || 0;

    $obj->{'FORUM'} = $db->select( TABLE => 'forum_info',
                                   KEY   => $obj->{'.forum_id'},
                                 );

    $obj->{'TOPIC'} = $db->select( TABLE => 'forum_topics',
                                   ID    => $obj->{'.forum_id'},
                                   KEY   => $obj->{'.topic_id'}
                                 );

    unless ($obj->{'TOPIC'}->{'PIN_STATE'} or $iB::MEMBER_GROUP->{'OTHER_TOPICS'}) {
        $std->Error( DB      => $db,
                     LEVEL   => 1,
                     MESSAGE =>'no_view_topic'
                   ) unless $obj->{'TOPIC'}->{'TOPIC_STARTER'} eq $iB::MEMBER->{'MEMBER_ID'};
    }

    my $check = $obj->Check_access($db);
    return if $check == 1;

    ++$obj->{'TOPIC'}->{'TOPIC_VIEWS'};

    $db->update( TABLE  => 'forum_topics',
                 ID     => $obj->{'.forum_id'},
                 KEY    => $obj->{'.topic_id'},
                 VALUES => { TOPIC_VIEWS => $obj->{'TOPIC'}->{'TOPIC_VIEWS'} }
               );

    $obj->{'FORUM'}->{'JUMP'} = $std->ForumJump();

    my $mem_groups = $db->query( TABLE      => 'mem_groups',
                                 COLUMNS    => ['ID', 'TITLE'],
                                 SORT_KEY   => 'TITLE',
                                 SORT_BY    => 'A-Z',
                               );

    my %temp_table = map { $_->{'ID'} => $_->{'TITLE'} } @{$mem_groups};
    $obj->{'group_table'} = \%temp_table;

    unless( !$iB::MEMBER->{'ID'} or $iB::MEMBER_GROUP->{'IS_SUPMOD'} ) {

        $obj->{'moderator'} = $db->query( TABLE      => 'forum_moderators',
                                          MATCH      => 'ONE',
                                          WHERE      => qq!FORUM_ID == "$obj->{'.forum_id'}" and MEMBER_ID eq "$iB::MEMBER->{'MEMBER_ID'}"!
                                        );
        $obj->{'moderator'} ||= { };
    }


    my $sort_by      = $iB::IN{'sort_by'} || $iB::INFO->{'TOPIC_SORT_ORDER'};

    my $sort_by_keys = { 'Z-A'  => 'descending_order',
                         'A-Z'  => 'ascending_order',
                       };

    $std->Error( DB      => $db,
                 LEVEL   => 5,
                 MESSAGE =>'illegal sort use'
               ) unless (exists $sort_by_keys->{$sort_by});

 
    $obj->{'TOPIC'}->{'REPLY_BUTTON'}
        = $obj->get_t_button();

    $obj->{'TOPIC'}->{'POLL_BUTTON'}
        = $iB::INFO->{'ALLOW_POLLS'} ? qq[<a href='$iB::INFO->{'BOARD_URL'}/ikonboard.$iB::INFO->{'CGI_EXT'}?s=$iB::SESSION;act=Poll;CODE=01;f=$iB::IN{'f'}' title="$Topic::lang->{'start_new_poll'}"><img src="$iB::INFO->{'IMAGES_URL'}/images/t_poll.gif" border='0'></a>]
                                     : '';


    my $Pages = $std->ib_int(
                              ($obj->{'TOPIC'}->{'TOPIC_POSTS'} + 1),
                              $iB::INFO->{'DISPLAY_MAX_POSTS'}
                            );

    $obj->{'TOPIC'}->{'TOTAL_PAGE'} = $Pages;
    $obj->{'CUR_PAGE'} = $First > 0 ? ($First / $iB::INFO->{'DISPLAY_MAX_POSTS'}) + 1
                                    : 1;
    if ($Pages > 1) {
        $obj->{'TOPIC'}->{'FIRST_PAGE'}
            = qq[$Topic::lang->{'multi_page_topic'}:: <a href='$iB::INFO->{'BOARD_URL'}/ikonboard.$iB::INFO->{'CGI_EXT'}?s=$iB::SESSION;act=ST;f=$obj->{'FORUM'}->{'FORUM_ID'};t=$obj->{'TOPIC'}->{'TOPIC_ID'};st=0' class='misc'>&lt;&lt;</a>];
        my $i = 0;
        my $end_dots;
        my $start_dots;
        for(0 .. $Pages-1) {
            my $RealNo = $i * $iB::INFO->{'DISPLAY_MAX_POSTS'};
            my $PageNo = $i+1;
            if ($RealNo == $First) {
                $obj->{'TOPIC'}->{'PAGE_SPAN'} .= qq!&nbsp;&nbsp;&nbsp;<font class='misc'><b>[ $PageNo ]</b><font>!;
            } else {
                if ($PageNo < ($obj->{'CUR_PAGE'} - 5) and ($obj->{'CUR_PAGE'} >= 6)) {
                    $start_dots = '&nbsp;&nbsp;&nbsp;...';
                    ++$i;
                    next;
                }
                $obj->{'TOPIC'}->{'PAGE_SPAN'}
                    .= qq[&nbsp;&nbsp;&nbsp;<a href='$iB::INFO->{'BOARD_URL'}/ikonboard.$iB::INFO->{'CGI_EXT'}?s=$iB::SESSION;act=ST;f=$obj->{'FORUM'}->{'FORUM_ID'};t=$obj->{'TOPIC'}->{'TOPIC_ID'};st=$RealNo' class='misc'>$PageNo</a> ];
                if ($PageNo == ($obj->{'CUR_PAGE'} + 5) and ($Pages > 6)) {
                    $end_dots = '...&nbsp;&nbsp;&nbsp;';
                    last;
                }
            }
            ++$i;
        }
        $obj->{'TOPIC'}->{'LAST_PAGE'}
            = qq[<a href='$iB::INFO->{'BOARD_URL'}/ikonboard.$iB::INFO->{'CGI_EXT'}?s=$iB::SESSION;act=ST;f=$obj->{'FORUM'}->{'FORUM_ID'};t=$obj->{'TOPIC'}->{'TOPIC_ID'};st=].($Pages-1) * $iB::INFO->{'DISPLAY_MAX_POSTS'}.qq[' class='misc'>&gt;&gt;</a>];
        $obj->{'TOPIC'}->{'SHOW_PAGES'}
            = $obj->{'TOPIC'}->{'FIRST_PAGE'} . $start_dots . $obj->{'TOPIC'}->{'PAGE_SPAN'}. '&nbsp;&nbsp;&nbsp;' . $end_dots . $obj->{'TOPIC'}->{'LAST_PAGE'};
    } else {
        $obj->{'TOPIC'}->{'SHOW_PAGES'}
            = qq!<font class='misc'>$Topic::lang->{'single_page_topic'}</font>!;
    }
    $obj->{'TOPIC'}->{'TOPIC_START_DATE'} = $std->get_date( TIME   => $obj->{'TOPIC'}->{'TOPIC_START_DATE'},
                                                            METHOD => 'LONG'
                                                          );
    

    my $Print =  $poll->display_poll(  DB    => $db,
                                       ID    => $obj->{'.forum_id'},
                                       KEY   => $obj->{'.topic_id'}
                                    );


    $Topic::lang->{'topic_stats'}   =~ s!<#START#>!$obj->{'TOPIC'}->{'TOPIC_START_DATE'}!;
    $Topic::lang->{'topic_stats'}   =~ s!<#POSTS#>!$obj->{'TOPIC'}->{'TOPIC_POSTS'}!;
    $obj->{'TOPIC'}->{'TOPIC_DESC'} = ', '.$obj->{'TOPIC'}->{'TOPIC_DESC'} if $obj->{'TOPIC'}->{'TOPIC_DESC'};


    $Print .= TopicView::PageTop({ 
                                  TOPIC => $obj->{'TOPIC'},
                                  FORUM => $obj->{'FORUM'}
                                 }
                                );


    my $total_posts = $db->query( TABLE    => 'forum_posts',
                                  DBID     => 'f'.$obj->{'.forum_id'},
                                  ID       => $obj->{'.topic_id'},
                                  WHERE    => "QUEUED != '1'",
                                  RANGE    => $First.' to '.($iB::INFO->{'DISPLAY_MAX_POSTS'} + ($First - 1)),
                                  SORT_KEY => 'POST_DATE',
                                  SORT_BY  => $sort_by
                                 ) or $Print = $db->{'error'};



    my $Cnt = 0;

    #+------------------------------------------------------------------------------------------------------

    for my $Row (@{$total_posts}) {
       
        $obj->{'POSTER'} = $Row->{'AUTHOR_TYPE'} == 1 ? $mem->LoadMember( DB => $db, KEY => $Row->{'AUTHOR'}, METHOD => 'by id')
                                                      : $mem->SetUpGuest($Row->{'AUTHOR'});


        if ($obj->{'POSTER'}->{'MEMBER_ID'}) {
            $obj->do_member($Row);
            $Row->{'NAME_CSS'} = '<font class="normalname">';
        } else {
            $obj->do_guest();
            $Row->{'NAME_CSS'} = '<font class="unreg">';
        }
       
        $Cnt == 0 ? eval { $Row->{'POST_BACK_COL'} = $iB::SKIN->{'POST_COL_ONE'}; ++$Cnt;   }
                  : eval { $Row->{'POST_BACK_COL'} = $iB::SKIN->{'POST_COL_TWO'}; $Cnt = 0; };

        if ($iB::IN{'hl'}) {
            $Row->{'POST'} =~ s!(\s{1,3}|\A|<br>|\()($iB::IN{'hl'})(\s{1,3}|\Z|<br>|,|\.|\!|\?|\))!$1<font class='postcolor' style='color:#FF0000'><b>$2</b></font>$3!ig;
        }
        $iB::SKIN->{'EDIT_FONT_SIZE'} ||= 7;
        $Row->{'POST'}     =~ s#<!--EDIT\|(.+?)\|(.+?)-->#<span style='font-size:$iB::SKIN->{'EDIT_FONT_SIZE'}pt'>Edited by $1 on $2</span>#ig;

        unless ($iB::MEMBER->{'VIEW_IMG'}) {
            $Row->{'POST'} =~ s#<img src=["'](?!$iB::INFO->{'EMOTICONS_URL'})(\S+)["'].+?>#\(IMG:<a href="$1" target="_blank">$1</a>\)#isg; 
        } 
        
        $Row->{'DELETE_ICON'} = $obj->delete_button($Row->{'POST_ID'});        
        $Row->{'EDIT_ICON'}   = $obj->edit_button($Row->{'POST_ID'});
        $Row->{'POST_DATE'}   = $std->get_date( TIME => $Row->{'POST_DATE'}, METHOD => 'LONG');
        $Row->{'POST_ICON'}   = $Row->{'POST_ICON'} 
                              ? $iB::INFO->{'IMAGES_URL'}.'/PostIcons/icon'.$Row->{'POST_ICON'}.'.gif'
                              : $iB::INFO->{'IMAGES_URL'}.'/PostIcons/icon0.gif';

        $Row->{'USER_IP'}     = $obj->view_ip($Row);

        $Print .= TopicView::RenderRow( { POST => $Row, POSTER => $obj->{'POSTER'} } );
        $obj->{'POSTER'} = undef;
    }

    #+------------------------------------------------------------------------------------------------------

    $Print .= TopicView::TableFooter({ 
                                        TOPIC => $obj->{'TOPIC'},
                                        FORUM => $obj->{'FORUM'}
                                     }
                                    );

    $Print .= $obj->Moderation_panel($db);   

    my $cat = $db->select( TABLE   => 'categories',
                           KEY     => $obj->{'FORUM'}->{'CATEGORY'},
                           COLUMNS => ['CAT_ID', 'CAT_NAME']
                         );

    $output->print_ikonboard( DB         => $db,
                              STD        => $std,
                              OUTPUT     => $Print,
                              JAVASCRIPT => 1,
                              TITLE      => "iB::Topic::$obj->{'TOPIC'}->{'TOPIC_TITLE'}",
                              NAV        => [ 
                                              qq|<a href="$iB::INFO->{'BOARD_URL'}/ikonboard.$iB::INFO->{'CGI_EXT'}?s=$iB::SESSION;act=SC;c=$cat->{'CAT_ID'}" class='nav'>$cat->{'CAT_NAME'}</a>|,
                                              qq|<a href="$iB::INFO->{'BOARD_URL'}/ikonboard.$iB::INFO->{'CGI_EXT'}?s=$iB::SESSION;act=SF;f=$obj->{'FORUM'}->{'FORUM_ID'}" class='nav'>$obj->{'FORUM'}->{'FORUM_NAME'}</a>|,
                                              qq|$obj->{'TOPIC'}->{'TOPIC_TITLE'}|
                                            ]
                            );
}



#+------------------------------------------------------------------------------------------------------

sub do_member ($$) {
    my ($obj, $Row) = @_;

    $obj->{'POSTER'}->{'MEMBER_AVATAR'}
        = $obj->get_avatar();

    $obj->{'POSTER'}->{'MEMBER_TITLE'}
        = $obj->{'POSTER'}->{'MEMBER_TITLE'} ? $obj->{'POSTER'}->{'MEMBER_TITLE'}
                                             : 'Member';

    $obj->{'POSTER'}->{'MEMBER_PIPS'}
        = 4;

    $obj->{'POSTER'}->{'MEMBER_JOINED'}
        = 'Joined: '.$std->get_date( TIME => $obj->{'POSTER'}->{'MEMBER_JOINED'}, METHOD => 'JOINED');
  
    if (defined $obj->{'POSTER'}->{'MEMBER_PIPS'}) {
        for (1 .. $obj->{'POSTER'}->{'MEMBER_PIPS'}) {
            $obj->{'POSTER'}->{'MEMBER_PIPS_IMG'} .= qq!<img src="$iB::INFO->{'IMAGES_URL'}/images/star.gif" border='0'>!
        }
    }

    if ($obj->{'POSTER'}->{'SIGNATURE'} and $iB::MEMBER->{'VIEW_SIGS'}) {
        $Row->{'SIGNATURE'} = $Row->{'ENABLE_SIG'} eq 'yes'
                              ?  qq[<!--Signature--><br><br>--------------<br><font class='signature'>$obj->{'POSTER'}->{'SIGNATURE'}</font><!--E Signature-->]
                              : ();
    }

    $obj->{'POSTER'}->{'MEMBER_GROUP'}
        = 'Group: '.$obj->{'group_table'}->{ $obj->{'POSTER'}->{'MEMBER_GROUP'} };
    $obj->{'POSTER'}->{'MEMBER_POSTS'}
        = 'Posts: '.$obj->{'POSTER'}->{'MEMBER_POSTS'};

    $obj->{'POSTER'}->{'PROFILE_ICON'}
        = qq!<a href="$iB::INFO->{'BOARD_URL'}/ikonboard.$iB::INFO->{'CGI_EXT'}?s=$iB::SESSION;act=Profile;CODE=03;MID=$obj->{'POSTER'}->{'MEMBER_ID'}"><img src="$iB::INFO->{'IMAGES_URL'}/images/pb_profile.gif" border='0'></a>&nbsp;!;

    $obj->{'POSTER'}->{'MESSAGE_ICON'}
        = qq[<a href='$iB::INFO->{'BOARD_URL'}/ikonboard.$iB::INFO->{'CGI_EXT'}?s=$iB::SESSION;act=Msg;CODE=04;MID=$obj->{'POSTER'}->{'MEMBER_ID'}'><img src="$iB::INFO->{'IMAGES_URL'}/images/pb_message.gif" border='0'></a>&nbsp;];

    $obj->{'POSTER'}->{'EMAIL_ICON'}
        = $obj->{'MEMBER'}->{'HIDE_EMAIL'} ? ''
                                           : qq[<a href="$iB::INFO->{'BOARD_URL'}/ikonboard.$iB::INFO->{'CGI_EXT'}?s=$iB::SESSION;act=Mail;CODE=00;MID=$obj->{'POSTER'}->{'MEMBER_ID'}"><img src="$iB::INFO->{'IMAGES_URL'}/images/pb_email.gif" border='0'></a>&nbsp;];

    $obj->{'POSTER'}->{'WEBSITE_ICON'}
        = ($obj->{'POSTER'}->{'WEBSITE'} and $obj->{'POSTER'}->{'WEBSITE'} =~ m#\Ahttp://.+?\S\Z#i)
                                           ? (qq[<a href='$obj->{'POSTER'}->{'WEBSITE'}'><img src="$iB::INFO->{'IMAGES_URL'}/images/pb_website.gif" border='0'></a>&nbsp;])
                                           : ('');

    $obj->{'POSTER'}->{'ICQ_ICON'}
        = $obj->{'MEMBER'}->{'ICQNUMBER'} ? ''
                                           : qq[<a href="javascript:PopUp('$iB::INFO->{'BOARD_URL'}/ikonboard.$iB::INFO->{'CGI_EXT'}?s=$iB::SESSION&act=ICQ&MID=$obj->{'POSTER'}->{'MEMBER_ID'}','Pager','450','330','0','1','1','1')"><img src="$iB::INFO->{'IMAGES_URL'}/images/pb_icq.gif" border='0'></a>&nbsp;];
    $obj->{'POSTER'}->{'AOL_ICON'}
        = $obj->{'MEMBER'}->{'AOLNAME'} ? ''
                                           : qq[<a href="javascript:PopUp('$iB::INFO->{'BOARD_URL'}/ikonboard.$iB::INFO->{'CGI_EXT'}?s=$iB::SESSION&act=AOL&MID=$obj->{'POSTER'}->{'MEMBER_ID'}','Pager','450','330','0','1','1','1')"><img src="$iB::INFO->{'IMAGES_URL'}/images/pb_aol.gif" border='0'></a>&nbsp;];

}

sub do_guest ($) {
    my $obj = shift;

    $obj->{'POSTER'}->{'MEMBER_AVATAR'} = undef;
    $obj->{'POSTER'}->{'MEMBER_TITLE'}  = 'Unregistered';
    $obj->{'POSTER'}->{'MEMBER_PIPS'}   = undef;
    $obj->{'POSTER'}->{'MEMBER_JOINED'} = undef;
    $obj->{'POSTER'}->{'SIGNATURE'}     = undef;
    $obj->{'POSTER'}->{'PROFILE'}       = undef;
    $obj->{'POSTER'}->{'MEMBER_POSTS'}  = undef;
    $obj->{'POSTER'}->{'MEMBER_GROUP'}  = undef;
    $obj->{'POSTER'}->{'MEMBER_JOINED'} = undef;
}

sub Check_access ($) {
    my ($obj, $db) = @_;

    if ($obj->{'FORUM'}->{'FORUM_PROTECT'}) {
        if (exists $iB::COOKIES->{ $iB::INFO->{'COOKIE_ID'}.'iBForum' . $obj->{'FORUM'}->{'FORUM_ID'} }) {
            return if $iB::COOKIES->{ $iB::INFO->{'COOKIE_ID'}.'iBForum' . $obj->{'FORUM'}->{'FORUM_ID'} } eq $obj->{'FORUM'}->{'FORUM_PROTECT'};
        }
        $output->redirect_screen( TEXT => "$Topic::lang->{'please_log_in'}", URL => "?act=SF;f=$iB::IN{'f'}");
        return 1;
    }

    if ($obj->{'FORUM'}->{'FORUM_VIEW_THREADS'} ne '*') {
        unless (grep { $_ == $iB::MEMBER->{'MEMBER_GROUP'} } (split /,/,$obj->{'FORUM'}->{'FORUM_VIEW_THREADS'}) ) {
            $std->Error(     DB      => $db,
                             LEVEL   => '2',
                             MESSAGE =>'forum_no_access'
                       );
        }
    }
    return 0;
}



#+------------------------------------------------------------------------------------------------------

sub view_ip {
    my ($obj,$Row) = @_;
    if ($iB::MEMBER_GROUP->{'IS_SUPMOD'} or $obj->{'moderator'}->{'VIEW_IP'}) {

        $Row->{'IP_ADDR'} = $obj->{'POSTER'}->{'MEMBER_GROUP'} == $iB::INFO->{'SUPAD_GROUP'}
                          ? qq~[ -------- ]~
                          : qq~[ <a href='http://www.nic.com/cgi-bin/whois.cgi?query=$Row->{'IP_ADDR'}' class='postcolor' target='blank'>$Row->{'IP_ADDR'}</a> ]~;

        return TopicView::ip_show($Row->{'IP_ADDR'});
    } else {
        return undef;
    }
}

#+------------------------------------------------------------------------------------------------------
my $action = { 'CLOSE_TOPIC'  => '00',
               'OPEN_TOPIC'   => '01',
               'MOVE_TOPIC'   => '02',
               'DELETE_TOPIC' => '03',
               'EDIT_TOPIC'   => '05',
               'PIN_TOPIC'    => 15,
               'UNPIN_TOPIC'  => 16
             };

sub Moderation_panel {
    my ($obj, $db) = @_;
    return unless $iB::MEMBER->{'MEMBER_ID'}
               or ($iB::MEMBER_GROUP->{'OPEN_CLOSE_TOPICS'} and $iB::MEMBER->{'MEMBER_ID'} eq $obj->{'TOPIC'}->{'TOPIC_STARTER'})
               or ($iB::MEMBER_GROUP->{'DELETE_OWN_TOPICS'} and $iB::MEMBER->{'MEMBER_ID'} eq $obj->{'TOPIC'}->{'TOPIC_STARTER'})
               or $iB::MEMBER_GROUP->{'IS_SUPMOD'}
               or $obj->{'moderator'}->{'MODERATOR_ID'};
               
    for my $key (qw[MOVE_TOPIC CLOSE_TOPIC OPEN_TOPIC DELETE_TOPIC EDIT_TOPIC PIN_TOPIC UNPIN_TOPIC]) {
        if    ($iB::MEMBER_GROUP->{'IS_SUPMOD'}) {
            $obj->{'.can_do'} .= $obj->_append($key);
        }
        elsif ($obj->{'moderator'}->{'MODERATOR_ID'}) {
            $obj->{'.can_do'} .= $obj->_append($key) if $obj->{'moderator'}->{ $key };
        }
    }

    return TopicView::Mod_Panel($obj->{'.can_do'}) if $obj->{'.can_do'};
}


sub _append {
    my ($obj, $moderate) = @_;
    return if $obj->{'TOPIC'}->{'TOPIC_STATE'} eq 'open'   and $moderate eq 'OPEN_TOPIC';
    return if $obj->{'TOPIC'}->{'TOPIC_STATE'} eq 'closed' and $moderate eq 'CLOSE_TOPIC';
    return if $obj->{'TOPIC'}->{'TOPIC_STATE'} eq 'moved'  and ($moderate eq 'CLOSE_TOPIC' or $moderate eq 'MOVE_TOPIC');
    return if $obj->{'TOPIC'}->{'PIN_STATE'}   and $moderate eq 'PIN_TOPIC';
    return if $obj->{'TOPIC'}->{'PIN_STATE'} < 1  and $moderate eq 'UNPIN_TOPIC';
    return  qq{[ <a href='$iB::INFO->{'BOARD_URL'}/ikonboard.$iB::INFO->{'CGI_EXT'}?s=$iB::SESSION;act=Mod;CODE=$action->{$moderate};f=$iB::IN{'f'};t=$iB::IN{'t'}' class='misc'>$Topic::lang->{ $moderate }</a> ] };
}

#+------------------------------------------------------------------------------------------------------

sub get_avatar {
    my $obj = shift;
    return unless $iB::INFO->{'AVATARS'}
              and $obj->{'POSTER'}->{'MEMBER_AVATAR'}
              and $iB::MEMBER->{'VIEW_AVS'};

    return if $obj->{'POSTER'}->{'MEMBER_AVATAR'} eq 'noavatar';
    return '' if $obj->{'POSTER'}->{'MEMBER_AVATAR'} =~ m#\.swf#i and $iB::INFO->{'ALLOW_FLASH'} != 1;
    if ($obj->{'POSTER'}->{'MEMBER_AVATAR'} =~ m#\Ahttp\://#i) {
        if ($iB::INFO->{'AV_ALLOW_URL'}) {
            my ($width  , $height)   = split "x", $obj->{'POSTER'}->{'AVATAR_DIMS'};
            my ($a_width, $a_height) = split "x", $iB::INFO->{'AV_DIMS'};
            $height ||= $a_height;
            $width  ||= $a_width;           
            return $obj->{'POSTER'}->{'MEMBER_AVATAR'} =~ m#\.swf\Z#i ? qq|<OBJECT CLASSID="clsid:D27CDB6E-AE6D-11cf-96B8-444553540000" WIDTH=$width HEIGHT=$height><PARAM NAME=MOVIE VALUE=$obj->{'POSTER'}->{'MEMBER_AVATAR'}><PARAM NAME=PLAY VALUE=TRUE><PARAM NAME=LOOP VALUE=TRUE><PARAM NAME=QUALITY VALUE=HIGH><EMBED SRC=$obj->{'POSTER'}->{'MEMBER_AVATAR'} WIDTH=$width HEIGHT=$height PLAY=TRUE LOOP=TRUE QUALITY=HIGH></EMBED></OBJECT>|
                                                                      : qq|<img src='$obj->{'POSTER'}->{'MEMBER_AVATAR'}' border='0' width='$width' height='$height'>|;
        }
    }
    return qq|<img src='$iB::INFO->{'AVATAR_URL'}/avatars/$obj->{'POSTER'}->{'MEMBER_AVATAR'}' border='0' width='$iB::INFO->{'AV_WIDTH'}' height='$iB::INFO->{'AV_HEIGHT'}'>| unless $obj->{'POSTER'}->{'MEMBER_AVATAR'} =~ m#\Ahttp\://#i;
}



#+------------------------------------------------------------------------------------------------------

sub edit_button {
    my ($obj, $post_number) = @_;
    return unless $iB::MEMBER->{'MEMBER_ID'};
    my $edit_button =  qq[<a href='$iB::INFO->{'BOARD_URL'}/ikonboard.$iB::INFO->{'CGI_EXT'}?s=$iB::SESSION;act=Post;CODE=08;f=$iB::IN{'f'};t=$iB::IN{'t'};p=$post_number' class='postcolor'><img src="$iB::INFO->{'IMAGES_URL'}/images/pb_edit.gif" border='0' alt='Edit your post'></a>];
    return $edit_button if $iB::MEMBER_GROUP->{'IS_SUPMOD'};
    return $edit_button if $obj->{'moderator'}->{'EDIT_POST'};
    return $edit_button if $obj->{'POSTER'}->{'MEMBER_ID'} eq $iB::MEMBER->{'MEMBER_ID'} and $iB::MEMBER_GROUP->{'EDIT_OWN_POSTS'};
    return;
}



#+------------------------------------------------------------------------------------------------------



sub delete_button {
    my ($obj, $post_number) = @_;
    return unless $iB::MEMBER->{'MEMBER_ID'};
    return if $post_number == 1;
    my $button = qq[<a href='#' onClick='IBCcheck_delete("$iB::INFO->{'BOARD_URL'}/ikonboard.$iB::INFO->{'CGI_EXT'}?s=$iB::SESSION;act=Mod;CODE=04;f=$iB::IN{'f'};t=$iB::IN{'t'};p=$post_number")' class='postcolor'><img src="$iB::INFO->{'IMAGES_URL'}/images/pb_delete.gif" border='0' alt='Remove This Post'></a>];
    return $button if $iB::MEMBER_GROUP->{'IS_SUPMOD'};
    return $button if $obj->{'moderator'}->{'DELETE_POST'};
    return;

}


#+------------------------------------------------------------------------------------------------------

sub get_t_button ($) {
    my $obj = shift;
    return qq!<img src="$iB::INFO->{'IMAGES_URL'}/images/t_locked.gif" border="0" alt="Topic Closed">! if $obj->{'TOPIC'}->{'TOPIC_STATE'} eq 'closed';
    return qq!<img src="$iB::INFO->{'IMAGES_URL'}/images/t_moved.gif" border="0" alt="Topic Moved">!   if $obj->{'TOPIC'}->{'TOPIC_STATE'} eq 'moved';
    return qq!<img src="$iB::INFO->{'IMAGES_URL'}/images/t_pollonly.gif" border="0" alt="Poll Only">!  if $obj->{'TOPIC'}->{'POLL_STATE'} eq 'closed';
    return qq!<a href="$iB::INFO->{'BOARD_URL'}/ikonboard.$iB::INFO->{'CGI_EXT'}?s=$iB::SESSION;act=Post;CODE=02;f=$obj->{'FORUM'}->{'FORUM_ID'};t=$obj->{'TOPIC'}->{'TOPIC_ID'}" title='$Topic::lang->{'reply_to_topic'}'><img src='$iB::INFO->{'IMAGES_URL'}/images/t_reply.gif' border='0'></a>! if $obj->{'TOPIC'}->{'TOPIC_STATE'} eq 'open';
}


1;

__END__
