package UserCP::Lostpass;
use strict;
#################################################################################
# Ikonboard v3 by Jarvis Entertainment Group, Inc.
#
# No parts of this script can be used outside Ikonboard without prior consent.
#
# More information available from <ib-license@jarvisgroup.net>
# (c)2001 Jarvis Entertainment Group, Inc.
# 
# http://www.ikonboard.com
#
# Please Read the license for more information
#+-----------------------------------------------------------------+
#
# Lostpass: Function for retrieving forgotten passwords.
#
#################################################################################

BEGIN {
   require 'Lib/FUNC.pm';
}

my $output = FUNC::Output->new();
my $mem    = FUNC::Member->new();
my $std    = FUNC::STD->new();
my $SEND   = FUNC::Mailer->new();
$Lostpass::lang = $std->LoadLanguage('LostpassWords');


sub new {
    my $pkg = shift;
    my $obj = {};
    bless $obj, $pkg;
    return $obj;
}

#+------------------------------------------------------------------------------------------------------

sub Splash {
    my ($obj, $db) = @_;

    my $print = &LostpassView::splash();

    $output->print_ikonboard( DB           => $db,
                              STD          => $std,
                              NAV_ONE      => $Lostpass::lang->{'nav_title'},
                              OUTPUT       => $print,
                              JAVASCRIPT   => '1',
                              TITLE        => "iB::" . $Lostpass::lang->{'nav_title'}
                            );
}


sub step_b ($) {
    my ($obj, $db) = @_;

    $std->Error( DB      => $db,
                 LEVEL   =>'1',
                 MESSAGE =>'no_email'
               ) unless $iB::IN{'u_emailaddress'};


    my $email_check = $mem->Check_Mem_Email( DB    => $db,
                                             EMAIL => $iB::IN{'u_emailaddress'}
                                           );

    $std->Error( DB      => $db,
                 LEVEL   =>'1',
                 MESSAGE =>'no_email_stored'
               ) unless $email_check->{'MEMBER_EMAIL'};


    $obj->{'MEMBER'} = $mem->LoadMember( DB     => $db,
                                         KEY    => $email_check->{'MEMBER_ID'},
                                         METHOD => 'by id'
                                        );


    $std->Error( DB      => $db,
                 LEVEL   =>'1',
                 MESSAGE =>'no_email_stored'
               ) unless $obj->{'MEMBER'}->{'MEMBER_ID'};


    my $unique_id = $SEND->my_gen_id();
    my $time      = time;

    my $new_id = $db->insert( TABLE   => 'authorisation',
                              VALUES  => {  UNIQUE_CODE   =>  $unique_id,
                                            DATE_ENTERED  =>  $time,
                                            MEMBER_ID     =>  $obj->{'MEMBER'}->{'MEMBER_ID'},
                                            MEMBER_NAME   =>  $obj->{'MEMBER'}->{'MEMBER_NAME'},
                                            THIS_IP       =>  $ENV{'REMOTE_ADDR'},
                                            MEMBER_EMAIL  =>  $obj->{'MEMBER'}->{'MEMBER_EMAIL'},
                                            WHERE         =>  'lostpass',
                                          },
                                );

    my $message = $SEND->parse_template( ID     => 'LOST_PASS_ONE',
                                         DB     => $db,
                                         VALUES =>  { THE_LINK    =>  "$iB::INFO->{'BOARD_URL'}/ikonboard.$iB::INFO->{'CGI_EXT'}?act=LostPass&CODE=02&SID=$unique_id&ID=$new_id",
                                                      MEMBER_NAME =>  $obj->{'MEMBER'}->{'MEMBER_NAME'},
                                                    }
                                            );

    $SEND->Send( TO      => $obj->{'MEMBER'}->{'MEMBER_EMAIL'},
                 FROM    => '',
                 SUBJECT => "Lost Password Request at $iB::INFO->{'BOARDNAME'}",
                 MESSAGE => $message
               );

    # Delete Out of Date requests.

    my $t_q = time - $iB::INFO{'AUTHORISE_PRUNE'} * 60 * 60 * 24;

    $db->delete( TABLE   => 'authorisation',
                 WHERE   => qq[WHERE eq 'lostpass' and DATE_ENTERED < "$t_q"],
              );

    $output->print_ikonboard( DB           => $db,
                              STD          => $std,
                              NAV_ONE      => $Lostpass::lang->{'nav_title'},
                              OUTPUT       => &LostpassView::email_sent($Lostpass::lang->{'first_email'},$Lostpass::lang->{'first_email_txt'}),
                              JAVASCRIPT   => '1',
                              TITLE        => "iB::" . $Lostpass::lang->{'nav_title'}
                            );

}


sub step_c ($) {
    my ($obj, $db) = @_;


    $std->Error( DB      => $db,
                 LEVEL   =>'1',
                 MESSAGE =>'data_incorrect'
               ) unless $iB::IN{'SID'};

    $std->Error( DB      => $db,
                 LEVEL   =>'1',
                 MESSAGE =>'data_incorrect'
               ) unless $iB::IN{'ID'};


    my $time = (time - ($iB::INFO->{'AUTHORISE_PRUNE'} * 60 * 60 * 24));

    my $db_entry = $db->select( TABLE   => 'authorisation',
                                KEY     => $iB::IN{'ID'}
                              );

    $std->Error( DB      => $db,
                 LEVEL   => '1',
                 MESSAGE => 'request_error'
               ) unless $db_entry->{'MEMBER_ID'};

    $std->Error( DB      => $db,
                 LEVEL   => '1',
                 MESSAGE =>'request_error'
               ) unless $db_entry->{'WHERE'} eq 'lostpass';

    $std->Error( DB      => $db,
                 LEVEL   => '1',
                 MESSAGE =>'request_error'
               ) unless $db_entry->{'UNIQUE_CODE'} eq $iB::IN{'SID'};

    $std->Error( DB      => $db,
                 LEVEL   => '1',
                 MESSAGE =>'request_passed'
               ) unless $db_entry->{'DATE_ENTERED'} > $time;


    my $member = $db->select( TABLE    => 'member_profiles',
                              KEY      => $db_entry->{'MEMBER_ID'},
                              ID       => $db_entry->{'MEMBER_ID'},
                            );


    $std->Error( DB      => $db,
                 LEVEL   => '1',
                 MESSAGE =>'request_error'
               ) unless $member->{'MEMBER_NAME'};



    my $new_pass   = $mem->RandomPassword();
    my $c_new_pass = $mem->Crypt($member->{'MEMBER_NAME'},$new_pass);

    $db->update(              TABLE    => 'member_profiles',
                              KEY      => $db_entry->{'MEMBER_ID'},
                              ID       => $db_entry->{'MEMBER_ID'},
                              VALUES   => { MEMBER_PASSWORD => $c_new_pass }
               );


    $db->delete(             TABLE     => 'authorisation',
                             KEY       => $db_entry->{'ID'},
               );



    my $message = $SEND->parse_template( ID     => 'LOST_PASS_TWO',
                                         DB     => $db,
                                         VALUES => { U_NAME      =>  $member->{'MEMBER_NAME'},
                                                     U_PASS      =>  $new_pass,
                                                   }
                                       );

    $SEND->Send( TO      => $member->{'MEMBER_EMAIL'},
                 FROM    => '',
                 SUBJECT => $Lostpass::lang->{'email_subject_b'},
                 MESSAGE => $message
               );

    $output->print_ikonboard( DB           => $db,
                              STD          => $std,
                              NAV_ONE      => $Lostpass::lang->{'nav_title'},
                              OUTPUT       => &LostpassView::email_sent($Lostpass::lang->{'second_email'},$Lostpass::lang->{'second_email_txt'}),
                              JAVASCRIPT   => 1,
                              TITLE        => 'iB::'.$Lostpass::lang->{'nav_title'}
                            );

}




sub Process {
    my ($obj, $db) = @_;
    $std->Error(LEVEL=>'1',MESSAGE=>'Wha.....?') unless (defined $iB::IN{'CODE'});
    my $CodeNo = $std->CheckCodeNo($iB::IN{'CODE'});
    require $iB::SKIN->{'DIR'} . '/UserCP/LostpassView.pm' or die $!;
    my %Mode = ( '00'     => \&Splash,
                 '01'     => \&step_b,
                 '02'     => \&step_c,

               );
    $Mode{$CodeNo} ? $Mode{$CodeNo}->($obj, $db) : UserCPError();
} 



#+------------------------------------------------------------------------------------------------------

sub UserCPError  { my ($obj, $db) = @_; $std->Error( DB => $db, LEVEL=>'1',MESSAGE=>'incorrect_use') }


#+------------------------------------------------------------------------------------------------------
#+------------------------------------------------------------------------------------------------------

1;

__END__
