#!/usr/bin/perl
package iB;
#+------------------------------------------------------------------------------------------------------
#| Ikonboard by Matthew Mecham [ v3.0 ]
#|
#| No parts of this script can be used outside Ikonboard without prior consent.
#| You must keep this header intact and all copyright links visable.
#| (c)2001 Ikonboard.com <http://www.ikonboard.com>
#|
#| Please Read the licence for more information.
#+------------------------------------------------------------------------------------------------------

$| = 1;
use strict;

BEGIN {
    $iB::PTH = '.';
    my $pgm = $0;
    $pgm =~s!\\!/!g;
    $pgm =~s/\A.*\.(cgi|pl)\Z/$1/g;
    unless (-e $iB::PTH.'/ikonboard.'.$pgm) {
        foreach ($0, $ENV{'PATH_TRANSLATED'}, $ENV{'DOCUMENT_ROOT'}) {
            $_ =~ s!\\!/!g;
            $_ =~ s!ikonboard\.(cgi|pl)!!i;
            if (-e $_ . '/ikonboard.' .$pgm) { $iB::PTH = $_; last; }
        }
    }
    die "Cannot find path: $iB::PTH/ikonboard.$pgm" unless (-e $iB::PTH.'/ikonboard.'.$pgm);
    unshift (@INC, "$iB::PTH");
    unshift (@INC, "$iB::PTH/Data");
    unshift (@INC, "$iB::PTH/Sources");
    unshift (@INC, "$iB::PTH/Skin");
    unshift (@INC, "$iB::PTH/Languages");
    unshift (@INC, "$iB::PTH/Sources/Lib");
    use Benchmark;
    use CGI::Carp "fatalsToBrowser";
}
#+------------------------------------------------------------------------------------------------------
use Lib::iCGI;

use Boardinfo;
$iB::INFO = Boardinfo->new();

require 'Lib/FUNC.pm';
require 'Sessions.pm';
require 'iDatabase/'.$iB::INFO->{'DB_DRIVER'}.'.pm';

my $db    = iDatabase->new( DATABASE  => $iB::INFO->{'DB_NAME'},
                            DB_DIR    => $iB::INFO->{'DB_DIR'},
                            IP        => $iB::INFO->{'DB_IP'},
                            PORT      => $iB::INFO->{'DB_PORT'},
                            USERNAME  => $iB::INFO->{'DB_USER'},
                            PASSWORD  => $iB::INFO->{'PASSWORD'},
                          );

my $std   = FUNC::STD->new();
my $sess  = Sessions->new();
$iB::TT0  = new Benchmark;
$iB::CGI  = new iCGI;
%iB::IN   = map { $std->CleanKey($_) => $std->CleanValue($iB::CGI->param($_)) } $iB::CGI->param();

# Server Workaround, f2s.com and some others don't use $ENV{'REMOTE_ADDR'}...
$iB::IN{'IP_ADDRESS'} = $ENV{'HTTP_X_FORWARDED_FOR'} || $ENV{'REMOTE_ADDR'};

$std->ValidateEntry();

$iB::COOKIES_OUT = [];
$iB::SESSION     = undef;
$iB::VERSION     = '3.0 BETA :: Build 3.2';
$iB::CONTENT     = { 'HTTP' => '0' };
$iB::COOKIES     = $iB::CGI->cookie();

$iB::MEMBER = $sess->authenticate($db) unless $iB::IN{'act'} eq 'Reg';
$iB::ACTIVE = $sess->active_users($db) if (( !$iB::IN{'act'}) or (defined $iB::IN{'c'} ));

$iB::SKIN   = $std->LoadSkin();

$iB::INFO->{'AVATARS_URL'}       = $iB::INFO->{'IMAGES_URL'} . '/avatars';
$iB::INFO->{'EMOTICONS_URL'}     = $iB::INFO->{'IMAGES_URL'} . '/emoticons';
$iB::INFO->{'IMAGES_URL'}       .= '/' . $iB::SKIN->{'FULL_DIR'};

eval { iB::Action($db) }; $std->cgi_error($@) if $@;

#+------------------------------------------------------------------------------------------------------


sub Action {
    my $db = shift;

    if ($iB::IN{'AD'}) {
        require 'Admin/Functions.pm' or die $!;
        my $ad = Admin::Functions->new();
        $ad->process($db);
        exit;
    }

    
    unless ($iB::INFO->{'B_ONLINE'}) {
        unless ($iB::MEMBER_GROUP->{'ACCESS_OFFLINE'}) {
            my $output = FUNC::Output->new();
            $output->board_offline( DB    => $db,
                                    STD   => $std,
                                  );
        exit;
        }
    }

    my %Mode = (  ST        => ['Topic'              , 'ShowTopic'   ],
                  SF        => ['Forum'              , 'ShowForum'   ],
                  SR        => ['Forum'              , 'ShowRules'   ],
                  SC        => ['Boards'             , 'ShowStart'   ],
                  Search    => ['Search'             , 'Process'     ],
                  Online    => ['Online'             , 'Process'     ],
                  Legends   => ['Legends'            , 'Process'     ],
                  Help      => ['Help'               , 'Process'     ],
                  Members   => ['Memberlist'         , 'Process'     ],
                  Reg       => ['Register'           , 'Process'     ],
                  Post      => ['Post'               , 'Process'     ],
                  Login     => ['LogInOut'           , 'Process'     ],
                  Profile   => ['Profile'            , 'Process'     ],
                  UserCP    => ['UserCP::Menu'       , 'Process'     ],
                  Mod       => ['Moderate'           , 'Process'     ],
                  Poll      => ['iPoll'              , 'Process'     ],
                  Print     => ['PrintPage'          , 'Process'     ],
                  Invite    => ['Misc::Invite'       , 'Process'     ],
                  Mail      => ['Misc::MailMember'   , 'Process'     ],
                  Cookies   => ['Misc::Cookies'      , 'Process'     ],
                  PMarkers  => ['Misc::PMarkers'     , 'Process'     ],
                  AOL       => ['Misc::AOL'          , 'Process'     ],
                  ICQ       => ['Misc::ICQ'          , 'Process'     ],
                  Msg       => ['UserCP::Messenger'  , 'Process'     ],
                  #Track     => ['UserCP::Track'      , 'Process'     ],
                  LostPass  => ['UserCP::Lostpass'   , 'Process'     ],
                  BoardIdx  => ['Boards'             , 'ShowStart'   ],
                 
               );

    $iB::IN{'act'} = 'BoardIdx' if $iB::IN{'act'} eq '';
    $iB::IN{'act'} = 'BoardIdx' unless exists $Mode{ $iB::IN{'act'} };

    # Nice little hack to save writing loads of subroutines for each action.
    # It builds the code from the %Mode hash, depending on the contents of 'act'
    # For example, the eval'd code may look like:

    #      use Topic;
    #      my $idx = Topic->new();
    #         $idx->ShowTopic($db);


    my $code = 'use '.$Mode{ $iB::IN{'act'} }[0].';'.
               'my $idx = '.$Mode{ $iB::IN{'act'} }[0].'->new();'.
                  '$idx->' .$Mode{ $iB::IN{'act'} }[1].'($db);';

    eval $code or $std->cgi_error($@); 
}       
    

exit (0);

__END__
